@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define _GNU_SOURCE
@@ -39,7 +39,6 @@
 #include <string.h>
 #include <pk-backend.h>
 #include <egg-debug.h>
-#include <packagekit-glib/packagekit.h>
 
 #include <alpm.h>
 #include <alpm_list.h>
@@ -54,12 +53,16 @@ PkBackend *backend_instance = NULL;
 GHashTable *group_map;
 
 alpm_list_t *syncfirst = NULL;
+alpm_list_t *holdpkg = NULL;
+
 alpm_list_t *downloaded_files = NULL;
 gchar *current_file = NULL;
 
 off_t trans_xfered;
 off_t trans_total;
 
+int trans_subprogress;
+
 typedef enum {
 	PK_ALPM_SEARCH_TYPE_NULL,
 	PK_ALPM_SEARCH_TYPE_RESOLVE,
@@ -69,46 +72,6 @@ typedef enum {
 	PK_ALPM_SEARCH_TYPE_PROVIDES
 } PkAlpmSearchType;
 
-static gchar *
-pkg_to_package_id_str (pmpkg_t *pkg, const gchar *repo)
-{
-	gchar *arch = (gchar *) alpm_pkg_get_arch (pkg);
-	if (arch == NULL)
-		arch = (gchar *) "unknown";
-
-	return pk_package_id_build (alpm_pkg_get_name (pkg), alpm_pkg_get_version (pkg), arch, repo);
-}
-
-static pmpkg_t *
-pkg_from_package_id_str (const gchar *package_id_str)
-{
-	pmdb_t *repo = NULL;
-	pmpkg_t *pkg;
-	PkPackageId *pkg_id = pk_package_id_new_from_string (package_id_str);
-
-	/* do all this fancy stuff */
-	if (egg_strequal (ALPM_LOCAL_DB_ALIAS, pk_package_id_get_data (pkg_id)))
-		repo = alpm_option_get_localdb ();
-	else {
-		alpm_list_t *iterator;
-		for (iterator = alpm_option_get_syncdbs (); iterator; iterator = alpm_list_next (iterator)) {
-			repo = alpm_list_getdata (iterator);
-			if (egg_strequal (alpm_db_get_name (repo), pk_package_id_get_data (pkg_id)))
-				break;
-		}
-	}
-
-	if (repo != NULL)
-		pkg = alpm_db_get_pkg (repo, pk_package_id_get_name (pkg_id));
-	else
-		pkg = NULL;
-
-	/* free package id as we no longer need it */
-	pk_package_id_free (pkg_id);
-
-	return pkg;
-}
-
 static int
 pkg_cmp (pmpkg_t *pkg1, pmpkg_t *pkg2) {
 	int comparison;
@@ -140,10 +103,13 @@ pkg_equal (pmpkg_t *p1, pmpkg_t *p2)
 		return FALSE;
 	return TRUE;
 }
+*/
 
 static gboolean
 pkg_equals_to (pmpkg_t *pkg, const gchar *name, const gchar *version)
 {
+	if (pkg == NULL)
+		return FALSE;
 	if (g_strcmp0 (alpm_pkg_get_name (pkg), name) != 0)
 		return FALSE;
 	if (version != NULL)
@@ -151,56 +117,112 @@ pkg_equals_to (pmpkg_t *pkg, const gchar *name, const gchar *version)
 			return FALSE;
 	return TRUE;
 }
-*/
+
+static gchar *
+pkg_to_package_id_str (pmpkg_t *pkg, const gchar *repo)
+{
+	gchar *arch = (gchar *) alpm_pkg_get_arch (pkg);
+	if (arch == NULL)
+		arch = (gchar *) "unknown";
+
+	return pk_package_id_build (alpm_pkg_get_name (pkg), alpm_pkg_get_version (pkg), arch, repo);
+}
+
+static pmpkg_t *
+pkg_from_package_id (const gchar *package_id)
+{
+	pmdb_t *repo = NULL;
+	pmpkg_t *result;
+	gchar **package_id_data = pk_package_id_split (package_id);
+
+	/* do all this fancy stuff */
+	if (g_strcmp0 (ALPM_LOCAL_DB_ALIAS, package_id_data[PK_PACKAGE_ID_DATA]) == 0)
+		repo = alpm_option_get_localdb ();
+	else {
+		alpm_list_t *iterator;
+		for (iterator = alpm_option_get_syncdbs (); iterator; iterator = alpm_list_next (iterator)) {
+			repo = alpm_list_getdata (iterator);
+			if (g_strcmp0 (alpm_db_get_name(repo), package_id_data[PK_PACKAGE_ID_DATA]) == 0)
+				break;
+		}
+	}
+
+	if (repo != NULL) {
+		pmpkg_t *pkg = alpm_db_get_pkg (repo, package_id_data[PK_PACKAGE_ID_NAME]);
+		if (pkg_equals_to (pkg, package_id_data[PK_PACKAGE_ID_NAME], package_id_data[PK_PACKAGE_ID_VERSION]))
+			result = pkg;
+		else
+			result = NULL;
+	} else
+		result = NULL;
+
+	g_strfreev (package_id_data);
+
+	return result;
+}
+
+static void
+emit_package (PkBackend *backend, pmpkg_t *pkg, const gchar *repo, PkInfoEnum info)
+{
+	gchar *package_id_str;
+
+	egg_debug ("alpm: emitting package with name %s", alpm_pkg_get_name (pkg));
+
+	package_id_str = pkg_to_package_id_str (pkg, repo);
+	pk_backend_package (backend, info, package_id_str, alpm_pkg_get_desc (pkg));
+	g_free (package_id_str);
+}
 
 static void
 cb_trans_evt (pmtransevt_t event, void *data1, void *data2)
 {
-	// TODO: Add more code here
 	gchar **package_ids;
-	gchar *package_id_needle;
-	gchar *package_id_str;
-	GString *package_id_builder;
 
+	/* TODO: add more code here */
 	switch (event) {
 		case PM_TRANS_EVT_REMOVE_START:
 			pk_backend_set_allow_cancel (backend_instance, FALSE);
 
-			package_id_str = pkg_to_package_id_str (data1, ALPM_LOCAL_DB_ALIAS);
-			pk_backend_package (backend_instance, PK_INFO_ENUM_REMOVING, package_id_str, alpm_pkg_get_desc (data1));
-			g_free (package_id_str);
+			/* reset transaction subprogress */
+			trans_subprogress = -1;
+
+			emit_package (backend_instance, data1, ALPM_LOCAL_DB_ALIAS, PK_INFO_ENUM_REMOVING);
 			break;
 		case PM_TRANS_EVT_ADD_START:
 			pk_backend_set_allow_cancel (backend_instance, FALSE);
 
-			pk_backend_set_status (backend_instance, PK_STATUS_ENUM_INSTALL);
-			package_id_needle = pkg_to_package_id_str (data1, "");
-			egg_debug ("needle is %s", package_id_needle);
-			package_ids = pk_backend_get_strv (backend_instance, "package_ids");
+			/* reset transaction subprogress */
+			trans_subprogress = -1;
 
+			pk_backend_set_status (backend_instance, PK_STATUS_ENUM_INSTALL);
+
+			package_ids = pk_backend_get_strv (backend_instance, "package_ids");
 			if (package_ids != NULL) {
-				/* search for this package in package_ids */
 				unsigned int iterator;
+
+				/* search for package in package_ids */
+				gchar *package_id_needle = pkg_to_package_id_str (data1, "");
+
+				egg_debug ("needle is %s", package_id_needle);
 				for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator)
 					if (strstr (package_ids[iterator], package_id_needle) != NULL) {
 						pk_backend_package (backend_instance, PK_INFO_ENUM_INSTALLING, package_ids[iterator], alpm_pkg_get_desc (data1));
 						break;
 					}
-			} else {
-				/* we are installing a local file */
-				package_id_builder = g_string_new (package_id_needle);
-				g_string_append (package_id_builder, "local");
-				package_id_str = g_string_free (package_id_builder, FALSE);
-				pk_backend_package (backend_instance, PK_INFO_ENUM_INSTALLING, package_id_str, alpm_pkg_get_desc (data1));
-				g_free (package_id_str);
-			}
 
-			g_free (package_id_needle);
+				g_free (package_id_needle);
+			} else
+				/* we are installing a local file */
+				emit_package (backend_instance, data1, "local", PK_INFO_ENUM_INSTALLING);
+
 			break;
 		case PM_TRANS_EVT_UPGRADE_START:
-			package_id_str = pkg_to_package_id_str (data1, "local");
-			pk_backend_package (backend_instance, PK_INFO_ENUM_UPDATING, package_id_str, alpm_pkg_get_desc (data1));
-			g_free (package_id_str);
+			pk_backend_set_allow_cancel (backend_instance, FALSE);
+
+			/* reset transaction subprogress */
+			trans_subprogress = -1;
+
+			emit_package (backend_instance, data1, ALPM_LOCAL_DB_ALIAS, PK_INFO_ENUM_UPDATING);
 			break;
 		default: egg_debug ("alpm: event %i happened", event);
 	}
@@ -209,19 +231,24 @@ cb_trans_evt (pmtransevt_t event, void *data1, void *data2)
 static void
 cb_trans_conv (pmtransconv_t conv, void *data1, void *data2, void *data3, int *response)
 {
-	// TODO: check if some code needs to be placed there
+	/* TODO: check if some code needs to be placed there */
 }
 
 static void
 cb_trans_progress (pmtransprog_t event, const char *pkgname, int percent, int howmany, int current)
 {
-	if (event == PM_TRANS_PROGRESS_ADD_START || event == PM_TRANS_PROGRESS_UPGRADE_START || event == PM_TRANS_PROGRESS_REMOVE_START) {
-		int trans_percent;
+	if (trans_subprogress != percent) {
+		/* avoid duplicates */
+		trans_subprogress = percent;
 
-		egg_debug ("alpm: transaction percentage for %s is %i", pkgname, percent);
-		trans_percent = (int) ((float) ((current - 1) * 100 + percent)) / ((float) (howmany * 100)) * 100;
-		pk_backend_set_sub_percentage ((PkBackend *) backend_instance, percent);
-		pk_backend_set_percentage ((PkBackend *) backend_instance, trans_percent);
+		if (event == PM_TRANS_PROGRESS_ADD_START || event == PM_TRANS_PROGRESS_UPGRADE_START || event == PM_TRANS_PROGRESS_REMOVE_START) {
+			int trans_percent;
+
+			egg_debug ("alpm: transaction percentage for %s is %i", pkgname, percent);
+			trans_percent = (int) ((float) ((current - 1) * 100 + percent)) / ((float) (howmany * 100)) * 100;
+			pk_backend_set_sub_percentage ((PkBackend *) backend_instance, percent);
+			pk_backend_set_percentage ((PkBackend *) backend_instance, trans_percent);
+		}
 	}
 }
 
@@ -232,29 +259,37 @@ cb_dl_progress (const char *filename, off_t file_xfered, off_t file_total)
 	int trans_percent;
 
 	if (g_str_has_suffix (filename, ALPM_PKG_EXT)) {
-		if (!egg_strequal (filename, current_file)) {
-			unsigned int iterator;
-			gchar *package_id = NULL;
-			gchar **package_ids = pk_backend_get_strv (backend_instance, "package_ids");
+		if (g_strcmp0 (filename, current_file) != 0) {
+			alpm_list_t *repos;
+			alpm_list_t *packages;
+			pmpkg_t *current_pkg = NULL;
+			const gchar *repo_name = NULL;
 
 			g_free (current_file);
 			current_file = g_strdup (filename);
 
-			/* search for this package in package_ids */
-			for (iterator = 0; package_id == NULL && iterator < g_strv_length (package_ids); ++iterator) {
-				PkPackageId *id = pk_package_id_new_from_string (package_ids[iterator]);
-				gchar *pkginfo = g_strjoin ("-", pk_package_id_get_name (id), pk_package_id_get_version (id), NULL);
-				if (g_str_has_prefix (filename, pkginfo))
-					package_id = package_ids[iterator];
-				g_free (pkginfo);
-				pk_package_id_free (id);
+			/* iterate repos */
+			for (repos = alpm_option_get_syncdbs (); current_pkg == NULL && repos; repos = alpm_list_next (repos)) {
+				pmdb_t *db = alpm_list_getdata (repos);
+
+				/* iterate pkgs */
+				for (packages = alpm_db_get_pkgcache (db); current_pkg == NULL && packages; packages = alpm_list_next (packages)) {
+					pmpkg_t *pkg = alpm_list_getdata (packages);
+
+					/* compare package information with file name */
+					gchar *needle = g_strjoin ("-", alpm_pkg_get_name (pkg), alpm_pkg_get_version (pkg), NULL);
+					if (needle != NULL && strcmp (needle, "") != 0)
+						egg_debug ("matching %s with %s", filename, needle);
+					if (g_str_has_prefix (filename, needle)) {
+						current_pkg = pkg;
+						repo_name = alpm_db_get_name (db);
+					}
+					g_free (needle);
+				}
 			}
 
-			/* emit package */
-			if (package_id != NULL) {
-				pmpkg_t *pkg = pkg_from_package_id_str (package_id);
-				pk_backend_package (backend_instance, PK_INFO_ENUM_DOWNLOADING, package_id, alpm_pkg_get_desc (pkg));
-			}
+			if (current_pkg != NULL)
+				emit_package (backend_instance, current_pkg, repo_name, PK_INFO_ENUM_DOWNLOADING);
 		}
 	}
 
@@ -278,18 +313,6 @@ cb_dl_total (off_t total)
 		trans_xfered = 0;
 }
 
-static void
-emit_package (PkBackend *backend, pmpkg_t *pkg, const gchar *repo, PkInfoEnum info)
-{
-	gchar *package_id_str;
-
-	egg_debug ("alpm: emitting package with name %s", alpm_pkg_get_name (pkg));
-
-	package_id_str = pkg_to_package_id_str (pkg, repo);
-	pk_backend_package (backend, info, package_id_str, alpm_pkg_get_desc (pkg));
-	g_free (package_id_str);
-}
-
 /**
  * strtrim:
  * Trim whitespaces and newlines from a string
@@ -402,10 +425,20 @@ set_repeating_option(const char *ptr, const char *option, void (*optionfunc) (co
  * @param name name of the package to be added
  */
 static void
-option_add_syncfirst(const char *name) {
+option_add_syncfirst (const char *name) {
 	syncfirst = alpm_list_add (syncfirst, strdup (name));
 }
 
+/**
+ * option_add_holdpkg:
+ * Add package name to HoldPkg list
+ * @param name name of the package to be added
+ */
+static void
+option_add_holdpkg (const char *name) {
+	holdpkg = alpm_list_add (holdpkg, strdup (name));
+}
+
 /**
  * parse_config:
  * Parse config file and set all the needed options
@@ -469,7 +502,7 @@ parse_config (const char *file, const char *givensection, pmdb_t * const givendb
 			}
 
 			/* if we are not looking at the options section, register a db */
-			if (!egg_strequal (section, "options"))
+			if (g_strcmp0 (section, "options") != 0)
 				db = alpm_db_register_sync (section);
 		} else {
 			/* directive */
@@ -490,15 +523,15 @@ parse_config (const char *file, const char *givensection, pmdb_t * const givendb
 				return 1;
 			}
 
-			if (ptr == NULL && egg_strequal (section, "options")) {
+			if (ptr == NULL && g_strcmp0 (section, "options") == 0) {
 				/* directives without settings, all in [options] */
-				if (egg_strequal (key, "NoPassiveFTP")) {
+				if (g_strcmp0 (key, "NoPassiveFTP") == 0) {
 					alpm_option_set_nopassiveftp (1);
 					egg_debug ("config: nopassiveftp");
-				} else if (egg_strequal (key, "UseSyslog")) {
+				} else if (g_strcmp0 (key, "UseSyslog") == 0) {
 					alpm_option_set_usesyslog (1);
 					egg_debug ("config: usesyslog");
-				} else if (egg_strequal (key, "UseDelta")) {
+				} else if (g_strcmp0 (key, "UseDelta") == 0) {
 					alpm_option_set_usedelta (1);
 					egg_debug ("config: usedelta");
 				} else {
@@ -507,45 +540,42 @@ parse_config (const char *file, const char *givensection, pmdb_t * const givendb
 				}
 			} else {
 				/* directives with settings */
-				if (egg_strequal (key, "Include")) {
+				if (g_strcmp0 (key, "Include") == 0) {
 					egg_debug ("config: including %s", ptr);
 					parse_config(ptr, section, db);
 					/* Ignore include failures... assume non-critical */
-				} else if (egg_strequal (section, "options")) {
-					if (egg_strequal (key, "NoUpgrade")) {
+				} else if (g_strcmp0 (section, "options") == 0) {
+					if (g_strcmp0 (key, "NoUpgrade") == 0) {
 						set_repeating_option (ptr, "NoUpgrade", alpm_option_add_noupgrade);
-					} else if (egg_strequal (key, "NoExtract")) {
+					} else if (g_strcmp0 (key, "NoExtract") == 0) {
 						set_repeating_option (ptr, "NoExtract", alpm_option_add_noextract);
-					} else if (egg_strequal (key, "IgnorePkg")) {
+					} else if (g_strcmp0 (key, "IgnorePkg") == 0) {
 						set_repeating_option (ptr, "IgnorePkg", alpm_option_add_ignorepkg);
-					} else if (egg_strequal (key, "IgnoreGroup")) {
+					} else if (g_strcmp0 (key, "IgnoreGroup") == 0) {
 						set_repeating_option (ptr, "IgnoreGroup", alpm_option_add_ignoregrp);
-					} else if (egg_strequal (key, "HoldPkg")) {
-						set_repeating_option (ptr, "HoldPkg", alpm_option_add_holdpkg);
-					} else if (egg_strequal (key, "SyncFirst")) {
+					} else if (g_strcmp0 (key, "HoldPkg") == 0) {
+						set_repeating_option (ptr, "HoldPkg", option_add_holdpkg);
+					} else if (g_strcmp0 (key, "SyncFirst") == 0) {
 						set_repeating_option (ptr, "SyncFirst", option_add_syncfirst);
-					} else if (egg_strequal (key, "DBPath")) {
+					} else if (g_strcmp0 (key, "DBPath") == 0) {
 						alpm_option_set_dbpath (ptr);
-					} else if (egg_strequal (key, "CacheDir")) {
+					} else if (g_strcmp0 (key, "CacheDir") == 0) {
 						if (alpm_option_add_cachedir(ptr) != 0) {
 							egg_error ("problem adding cachedir '%s' (%s)", ptr, alpm_strerrorlast ());
 							return 1;
 						}
 						egg_debug ("config: cachedir: %s", ptr);
-					} else if (egg_strequal (key, "RootDir")) {
+					} else if (g_strcmp0 (key, "RootDir") == 0) {
 						alpm_option_set_root (ptr);
 						egg_debug ("config: rootdir: %s", ptr);
-					} else if (egg_strequal (key, "LogFile")) {
+					} else if (g_strcmp0 (key, "LogFile") == 0) {
 						alpm_option_set_logfile (ptr);
 						egg_debug ("config: logfile: %s", ptr);
-					} else if (egg_strequal (key, "XferCommand")) {
-						alpm_option_set_xfercommand (ptr);
-						egg_debug ("config: xfercommand: %s", ptr);
 					} else {
 						egg_error ("config file %s, line %d: directive '%s' not recognized.", file, linenum, key);
 						return 1;
 					}
-				} else if (egg_strequal (key, "Server")) {
+				} else if (g_strcmp0 (key, "Server") == 0) {
 					/* let's attempt a replacement for the current repo */
 					char *server = strreplace (ptr, "$repo", section);
 
@@ -576,7 +606,7 @@ parse_config (const char *file, const char *givensection, pmdb_t * const givendb
 static void
 backend_initialize (PkBackend *backend)
 {
-	// initialize backend_instance for use in callback functions
+	/* initialize backend_instance for use in callback functions */
 	backend_instance = backend;
 
 	egg_debug ("alpm: initializing backend");
@@ -731,14 +761,16 @@ backend_download_packages_thread (PkBackend *backend)
 
 	/* add targets to the transaction */
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		PkPackageId *id = pk_package_id_new_from_string (package_ids[iterator]);
-		if (alpm_trans_addtarget ((char *) pk_package_id_get_name (id)) != 0) {
+		gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
+
+		if (alpm_trans_addtarget (package_id_data[PK_PACKAGE_ID_NAME]) != 0) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
 			alpm_trans_release ();
 			pk_backend_finished (backend);
 			return FALSE;
 		}
-		pk_package_id_free (id);
+
+		g_strfreev (package_id_data);
 	}
 
 	/* prepare and commit transaction */
@@ -751,11 +783,30 @@ backend_download_packages_thread (PkBackend *backend)
 
 	alpm_trans_release ();
 
-	/* emit/cleanup downloaded files list */
+	/* emit downloaded packages */
 	for (list_iterator = downloaded_files; list_iterator; list_iterator = alpm_list_next (list_iterator)) {
-		gchar *fullname = g_strjoin ("/", directory, alpm_list_getdata (list_iterator), NULL);
-		pk_backend_files (backend, NULL, fullname);
-		g_free (fullname);
+		gchar *package_id = NULL;
+		gchar *filename;
+
+		/* TODO: optimize this? split-then-join isn't good */
+		for (iterator = 0; package_id == NULL && iterator < g_strv_length (package_ids); ++iterator) {
+			gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
+			gchar *needle = g_strjoin ("-", package_id_data[PK_PACKAGE_ID_NAME], package_id_data[PK_PACKAGE_ID_VERSION], NULL);
+
+			if (needle != NULL && strcmp (needle, "") != 0)
+				egg_debug ("matching %s with %s", (char *) alpm_list_getdata (list_iterator), needle);
+			if (g_str_has_prefix ((char *) alpm_list_getdata (list_iterator), needle))
+				package_id = package_ids[iterator];
+
+			g_free (needle);
+			g_strfreev (package_id_data);
+		}
+
+		filename = g_build_filename (directory, alpm_list_getdata (list_iterator), NULL);
+		pk_backend_files (backend, package_id, filename);
+		g_free (filename);
+
+		/* clean up list data */
 		g_free (alpm_list_getdata (list_iterator));
 	}
 	alpm_list_free (downloaded_files);
@@ -793,9 +844,9 @@ backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
 		alpm_list_t *list_iterator;
 
-		pmpkg_t *pkg = pkg_from_package_id_str (package_ids[iterator]);
+		pmpkg_t *pkg = pkg_from_package_id (package_ids[iterator]);
 		if (pkg == NULL) {
-			pk_backend_error_code (backend, PK_ERROR_ENUM_REPO_NOT_FOUND, alpm_strerrorlast ());
+			pk_backend_error_code (backend, PK_ERROR_ENUM_PACKAGE_ID_INVALID, alpm_strerrorlast ());
 			pk_backend_finished (backend);
 			return;
 		}
@@ -831,12 +882,6 @@ backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids
 					emit_package (backend, dep_pkg, ALPM_LOCAL_DB_ALIAS, PK_INFO_ENUM_INSTALLED);
 				}
 			}
-
-			if (found == FALSE) {
-				pk_backend_error_code (backend, PK_ERROR_ENUM_REPO_NOT_FOUND, alpm_strerrorlast ());
-				pk_backend_finished (backend);
-				return;
-			}
 		}
 	}
 
@@ -859,7 +904,7 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 		GString *licenses_str;
 		gchar *licenses;
 
-		pmpkg_t *pkg = pkg_from_package_id_str (package_ids[iterator]);
+		pmpkg_t *pkg = pkg_from_package_id (package_ids[iterator]);
 		if (pkg == NULL) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_REPO_NOT_FOUND, alpm_strerrorlast ());
 			pk_backend_finished (backend);
@@ -880,13 +925,13 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 			}
 		}
 
-		// get licenses_str content to licenses array
+		/* get licenses_str content to licenses array */
 		licenses = g_string_free (licenses_str, FALSE);
 
-		// return details
+		/* return details */
 		pk_backend_details (backend, package_ids[iterator], licenses, PK_GROUP_ENUM_OTHER, alpm_pkg_get_desc (pkg), alpm_pkg_get_url(pkg), alpm_pkg_get_size (pkg));
 
-		// free licenses array as we no longer need it
+		/* free licenses array as we no longer need it */
 		g_free (licenses);
 	}
 
@@ -905,12 +950,11 @@ backend_get_files (PkBackend *backend, gchar **package_ids)
 	pk_backend_set_allow_cancel (backend, FALSE);
 
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		pmpkg_t *pkg;
 		alpm_list_t *files_list;
 		GString *files_str;
 		gchar *files;
 
-		pkg = pkg_from_package_id_str (package_ids[iterator]);
+		pmpkg_t *pkg = pkg_from_package_id (package_ids[iterator]);
 		if (pkg == NULL) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_REPO_NOT_FOUND, alpm_strerrorlast ());
 			pk_backend_finished (backend);
@@ -960,7 +1004,7 @@ backend_search (PkBackend *backend, pmdb_t *repo, const gchar *needle, PkAlpmSea
 	}
 
 	/* get package cache for specified repo */
-	pkg_cache = alpm_db_getpkgcache (repo);
+	pkg_cache = alpm_db_get_pkgcache (repo);
 
 	/* iterate package cache */
 	for (iterator = pkg_cache; iterator; iterator = alpm_list_next (iterator)) {
@@ -974,7 +1018,7 @@ backend_search (PkBackend *backend, pmdb_t *repo, const gchar *needle, PkAlpmSea
 				match = TRUE;
 				break;
 			case PK_ALPM_SEARCH_TYPE_RESOLVE:
-				match = egg_strequal (alpm_pkg_get_name (pkg), needle);
+				match = g_strcmp0 (alpm_pkg_get_name(pkg), needle) == 0;
 				break;
 			case PK_ALPM_SEARCH_TYPE_NAME:
 				match = strstr (alpm_pkg_get_name (pkg), needle) != NULL;
@@ -994,14 +1038,14 @@ backend_search (PkBackend *backend, pmdb_t *repo, const gchar *needle, PkAlpmSea
 					gchar *group = (gchar *) g_hash_table_lookup (group_map, (char *) alpm_list_getdata (groups));
 					if (group == NULL)
 						group = (gchar *) "other";
-					match = egg_strequal (group, needle);
+					match = (g_strcmp0 (group, needle) == 0);
 				}
 				break;
 			case PK_ALPM_SEARCH_TYPE_PROVIDES:
 				match = FALSE;
 				/* iterate provides */
 				for (provides = alpm_pkg_get_provides (pkg); provides && !match; provides = alpm_list_next (provides))
-					match = egg_strequal (needle, alpm_list_getdata (provides));
+					match = (g_strcmp0 (needle, alpm_list_getdata(provides)) == 0);
 				break;
 			default:
 				match = FALSE;
@@ -1086,10 +1130,10 @@ backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 	pk_backend_set_allow_cancel (backend, FALSE);
 
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		// TODO: add changelog code here
-		PkPackageId *id = pk_package_id_new_from_string (package_ids[iterator]);
+		/* TODO: add changelog code here */
+		gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
 
-		pmpkg_t *installed_pkg = alpm_db_get_pkg (alpm_option_get_localdb (), pk_package_id_get_name (id));
+		pmpkg_t *installed_pkg = alpm_db_get_pkg (alpm_option_get_localdb (), package_id_data[PK_PACKAGE_ID_NAME]);
 
 		gchar *installed_package_id = installed_pkg ? pkg_to_package_id_str (installed_pkg, ALPM_LOCAL_DB_ALIAS) : NULL;
 		pk_backend_update_detail (backend, package_ids[iterator], installed_package_id, "", "", "", "", PK_RESTART_ENUM_NONE,
@@ -1097,7 +1141,7 @@ backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 			NULL, PK_UPDATE_STATE_ENUM_UNKNOWN, NULL, NULL);
 		g_free (installed_package_id);
 
-		pk_package_id_free (id);
+		g_strfreev (package_id_data);
 	}
 
 	pk_backend_finished (backend);
@@ -1115,7 +1159,7 @@ backend_get_updates (PkBackend *backend, PkBitfield filters)
 	pk_backend_set_allow_cancel (backend, FALSE);
 
 	/* iterate through list of installed packages to find update for each */
-	for (list_iterator = alpm_db_getpkgcache (alpm_option_get_localdb ()); list_iterator; list_iterator = alpm_list_next (list_iterator)) {
+	for (list_iterator = alpm_db_get_pkgcache (alpm_option_get_localdb ()); list_iterator; list_iterator = alpm_list_next (list_iterator)) {
 		alpm_list_t *db_iterator;
 
 		pmpkg_t *pkg = alpm_list_getdata (list_iterator);
@@ -1184,7 +1228,7 @@ backend_install_files_thread (PkBackend *backend)
  * backend_install_files:
  */
 static void
-backend_install_files (PkBackend *backend, gboolean trusted, gchar **full_paths)
+backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
@@ -1201,10 +1245,11 @@ backend_install_packages_thread (PkBackend *backend)
 	unsigned int iterator;
 	alpm_list_t *data = NULL;
 
+	/* FIXME: support only_trusted */
 	gchar **package_ids = pk_backend_get_strv (backend, "package_ids");
 
 	/* create a new transaction */
-	if (alpm_trans_init (PM_TRANS_TYPE_SYNC, PM_TRANS_FLAG_NODEPS, cb_trans_evt, cb_trans_conv, cb_trans_progress) != 0) {
+	if (alpm_trans_init (PM_TRANS_TYPE_SYNC, 0, cb_trans_evt, cb_trans_conv, cb_trans_progress) != 0) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
 		pk_backend_finished (backend);
 		return FALSE;
@@ -1212,14 +1257,16 @@ backend_install_packages_thread (PkBackend *backend)
 
 	/* add targets to the transaction */
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		PkPackageId *id = pk_package_id_new_from_string (package_ids[iterator]);
-		if (alpm_trans_addtarget ((char *) pk_package_id_get_name (id)) != 0) {
+		gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
+
+		if (alpm_trans_addtarget (package_id_data[PK_PACKAGE_ID_NAME]) != 0) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
 			alpm_trans_release ();
 			pk_backend_finished (backend);
 			return FALSE;
 		}
-		pk_package_id_free (id);
+
+		g_strfreev (package_id_data);
 	}
 
 	/* prepare and commit transaction */
@@ -1240,7 +1287,7 @@ backend_install_packages_thread (PkBackend *backend)
  * backend_install_packages:
  */
 static void
-backend_install_packages (PkBackend *backend, gchar **package_ids)
+backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 
@@ -1319,14 +1366,16 @@ backend_remove_packages_thread (PkBackend *backend)
 
 	/* add targets to the transaction */
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		PkPackageId *id = pk_package_id_new_from_string (package_ids[iterator]);
-		if (alpm_trans_addtarget ((char *) pk_package_id_get_name (id)) != 0) {
+		gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
+
+		if (alpm_trans_addtarget (package_id_data[PK_PACKAGE_ID_NAME]) != 0) {
 			pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
 			alpm_trans_release ();
 			pk_backend_finished (backend);
 			return FALSE;
 		}
-		pk_package_id_free (id);
+
+		g_strfreev (package_id_data);
 	}
 
 	/* prepare and commit transaction */
@@ -1366,21 +1415,39 @@ backend_resolve_thread (PkBackend *backend)
 	gchar **package_ids = pk_backend_get_strv (backend, "package_ids");
 	PkBitfield filters = pk_backend_get_uint (backend, "filters");
 
+	gboolean search_installed = pk_bitfield_contain (filters, PK_FILTER_ENUM_INSTALLED);
+	gboolean search_not_installed = pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_INSTALLED);
+
 	for (iterator = 0; iterator < g_strv_length (package_ids); ++iterator) {
-		gboolean search_installed = pk_bitfield_contain (filters, PK_FILTER_ENUM_INSTALLED);
-		gboolean search_not_installed = pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_INSTALLED);
+		if (pk_package_id_check (package_ids[iterator])) {
+			/* skip all the db iterations and so on - we already know everything */
+			pmpkg_t *pkg = pkg_from_package_id (package_ids[iterator]);
 
-		if (!search_not_installed) {
-			/* search in local db */
-			backend_search (backend, alpm_option_get_localdb (), package_ids[iterator], PK_ALPM_SEARCH_TYPE_RESOLVE);
-		}
+			if (pkg != NULL) {
+				gchar **package_id_data = pk_package_id_split (package_ids[iterator]);
 
-		if (!search_installed) {
-			/* search in sync repos */
-			alpm_list_t *repos;
-			/* iterate repos */
-			for (repos = alpm_option_get_syncdbs (); repos; repos = alpm_list_next (repos))
-				backend_search (backend, alpm_list_getdata (repos), package_ids[iterator], PK_ALPM_SEARCH_TYPE_RESOLVE);
+				if (!search_not_installed && g_strcmp0 (package_id_data[PK_PACKAGE_ID_DATA], ALPM_LOCAL_DB_ALIAS) == 0)
+					emit_package (backend, pkg, ALPM_LOCAL_DB_ALIAS, PK_INFO_ENUM_INSTALLED);
+
+				if (!search_installed && g_strcmp0 (package_id_data[PK_PACKAGE_ID_DATA], ALPM_LOCAL_DB_ALIAS) != 0)
+					emit_package (backend, pkg, package_id_data[PK_PACKAGE_ID_DATA], PK_INFO_ENUM_INSTALLED);
+
+				g_strfreev (package_id_data);
+			}
+		} else {
+			/* good old way with backend_search */
+			if (!search_not_installed) {
+				/* search in local db */
+				backend_search (backend, alpm_option_get_localdb (), package_ids[iterator], PK_ALPM_SEARCH_TYPE_RESOLVE);
+			}
+
+			if (!search_installed) {
+				/* search in sync repos */
+				alpm_list_t *repos;
+				/* iterate repos */
+				for (repos = alpm_option_get_syncdbs (); repos; repos = alpm_list_next (repos))
+					backend_search (backend, alpm_list_getdata (repos), package_ids[iterator], PK_ALPM_SEARCH_TYPE_RESOLVE);
+			}
 		}
 	}
 
@@ -1473,13 +1540,56 @@ backend_search_name (PkBackend *backend, PkBitfield filters, const gchar *search
  * backend_update_packages:
  */
 static void
-backend_update_packages (PkBackend *backend, gchar **package_ids)
+backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 
 	pk_backend_thread_create (backend, backend_install_packages_thread);
 }
 
+/**
+ * backend_update_system_thread:
+ */
+static gboolean
+backend_update_system_thread (PkBackend *backend)
+{
+	alpm_list_t *data = NULL;
+
+	/* FIXME: support only_trusted */
+
+	/* don't specify any flags for now */
+	pmtransflag_t flags = 0;
+
+	/* create a new transaction */
+	if (alpm_trans_init (PM_TRANS_TYPE_SYNC, flags, cb_trans_evt, cb_trans_conv, cb_trans_progress) != 0) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+
+	/* set action, prepare and commit transaction */
+	if (alpm_trans_sysupgrade (FALSE) != 0 || alpm_trans_prepare (&data) != 0 || alpm_trans_commit (&data) != 0) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, alpm_strerrorlast ());
+		alpm_trans_release ();
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+
+	alpm_trans_release ();
+
+	pk_backend_finished (backend);
+	return TRUE;
+}
+
+/**
+ * backend_update_system:
+ */
+static void
+backend_update_system (PkBackend *backend, gboolean only_trusted)
+{
+	pk_backend_thread_create (backend, backend_update_system_thread);
+}
+
 /**
  * backend_what_provides:
  */
@@ -1500,6 +1610,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,				/* destroy */
 	backend_get_groups,				/* get_groups */
 	backend_get_filters,				/* get_filters */
+	NULL,						/* get_roles */
 	backend_get_mime_types,				/* get_mime_types */
 	backend_cancel,					/* cancel */
 	backend_download_packages,			/* download_packages */
@@ -1527,6 +1638,10 @@ PK_BACKEND_OPTIONS (
 	backend_search_group,				/* search_group */
 	backend_search_name,				/* search_name */
 	backend_update_packages,			/* update_packages */
-	NULL,						/* update_system */
-	backend_what_provides				/* what_provides */
+	backend_update_system,				/* update_system */
+	backend_what_provides,				/* what_provides */
+	NULL,						/* simulate_install_files */
+	NULL,						/* simulate_install_packages */
+	NULL,						/* simulate_remove_packages */
+	NULL						/* simulate_update_packages */
 );
