@@ -36,30 +36,47 @@ using namespace std;
 /**
 *  Emits files of packages
 */
-void emit_files (PkBackend *backend, const PkPackageId *pi);
+void emit_files (PkBackend *backend, const gchar *pi);
 
 /**
 *  returns a list of packages names
 */
 vector<string> search_file (PkBackend *backend, const string &file_name, bool &_cancel);
 
+/**
+*  returns a list of packages names
+*/
+vector<string> searchMimeType (PkBackend *backend, gchar **values, bool &error, bool &_cancel);
+
+class pkgProblemResolver;
 class aptcc
 {
 //     typedef int user_tag_reference;
 public:
-	aptcc(PkBackend *backend, bool &cancel, pkgSourceList &apt_source_list);
+	aptcc(PkBackend *backend, bool &cancel);
 	~aptcc();
 
-	bool init(const char *locale);
+	bool init();
+	void cancel();
 
+	// Check the returned VerIterator.end()
+	// if it's true we could not find it
+	pair<pkgCache::PkgIterator, pkgCache::VerIterator>
+			find_package_id(const gchar *package_id);
 	pkgCache::VerIterator find_ver(const pkgCache::PkgIterator &pkg);
 	pkgCache::VerIterator find_candidate_ver(const pkgCache::PkgIterator &pkg);
-	bool is_held(const pkgCache::PkgIterator &pkg);
 
 	/**
-	 *  get the state cache of the package
+	 *  runs a transaction to install/remove/update packages
+	 *  - for install and update, \p remove should be set to false
+	 *  - if you are going to remove, \p remove should be true
+	 *  - if you don't want to actually install/update/remove
+	 *    \p simulate should be true, in this case packages with
+	 *    what's going to happen will be emitted.
 	 */
-	pkgDepCache::StateCache get_state(const pkgCache::PkgIterator &pkg);
+	bool runTransaction(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &pkgs,
+			    bool simulate,
+			    bool remove);
 
 	/**
 	 *  Get depends
@@ -84,7 +101,11 @@ public:
 			  PkInfoEnum state = PK_INFO_ENUM_UNKNOWN);
 
 	void emit_packages(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
-			   PkBitfield filters = PK_FILTER_ENUM_NONE);
+			   PkBitfield filters = PK_FILTER_ENUM_NONE,
+			   PkInfoEnum state = PK_INFO_ENUM_UNKNOWN);
+
+	void emitUpdates(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
+			 PkBitfield filters = PK_FILTER_ENUM_NONE);
 
 	/**
 	 *  Emits details
@@ -99,43 +120,48 @@ public:
 	/**
 	 *  seems to install packages
 	 */
-	bool installPackages(pkgDepCache &Cache,
-			     bool ShwKept,
-			     bool Ask = true,
-			     bool Safety = true);
+	bool installPackages(pkgCacheFile &Cache);
 
-	/** Marks all upgradable and non-held packages for upgrade.
-	 *
-	 *  \param with_autoinst if \b true, the dependencies of packages
-	 *  begin upgraded will automatically be installed.
-	 *
-	 *  \param ignore_selections if \b false, all upgradable packages
-	 *  that are not held back will be upgraded; otherwise, packages
-	 *  that are going to be removed will be ignored.
-	 *
-	 *  \param undo an undo group with which the actions taken by this
-	 *  routine will be registered, or \b NULL.
+	/**
+	 *  check if the package provides the codec
 	 */
-	void mark_all_upgradable(bool with_autoinst,
-				 bool ignore_removed/*,
-				 undo_group *undo*/);
+	void povidesCodec(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
+			  gchar **values);
 
 	pkgRecords    *packageRecords;
 	pkgCache      *packageCache;
 	pkgDepCache   *packageDepCache;
+	pkgSourceList *packageSourceList;
 
 private:
 	MMap       *Map;
 	OpProgress Progress;
 	pkgPolicy  *Policy;
 	PkBackend  *m_backend;
-	bool &_cancel;
-	pkgSourceList &m_pkgSourceList;
+	bool       &_cancel;
 
-	/** This flag is \b true iff the persistent state has changed (ie, we
-	 *  need to save the cache).
-	 */
-	bool dirty;
+	bool TryToInstall(pkgCache::PkgIterator Pkg,
+			  pkgDepCache &Cache,
+			  pkgProblemResolver &Fix,
+			  bool Remove,
+			  bool BrokenFix,
+			  unsigned int &ExpectedInst);
+	/**
+	 *  interprets dpkg status fd
+	*/
+	void updateInterface(int readFd, int writeFd);
+	bool DoAutomaticRemove(pkgCacheFile &Cache);
+	void emitChangedPackages(pkgCacheFile &Cache);
+	bool removingEssentialPackages(pkgCacheFile &Cache);
+
+	vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > m_pkgs;
+	void populateInternalPackages(pkgCacheFile &Cache);
+	void emitTransactionPackage(string name, PkInfoEnum state);
+	time_t m_lastTermAction;
+	bool m_startCounting;
+	// when the internal terminal timesout after no activity
+	int m_terminalTimeout;
+	pid_t m_child_pid;
 };
 
 #endif
