@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gmodule.h>
@@ -192,6 +192,8 @@ backend_get_updates_thread (PkBackend *backend)
 static gboolean
 backend_update_system_thread (PkBackend *backend)
 {
+	/* FIXME: support only_trusted */
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
 	box_upgrade_dist(ROOT_DIRECTORY, common_progress, backend);
@@ -208,6 +210,8 @@ backend_install_packages_thread (PkBackend *backend)
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
+	/* FIXME: support only_trusted */
+
 	package_id = pk_backend_get_string (backend, "package_id");
 	pi = pk_package_id_new_from_string (package_id);
 	if (pi == NULL) {
@@ -231,6 +235,7 @@ backend_update_packages_thread (PkBackend *backend)
 	gint i;
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
+	/* FIXME: support only_trusted */
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 
 	for (i = 0; i < g_strv_length (package_ids); i++)
@@ -499,7 +504,7 @@ backend_get_updates (PkBackend *backend, PkBitfield filters)
  * backend_install_packages:
  */
 static void
-backend_install_packages (PkBackend *backend, gchar **package_ids)
+backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	/* check network state */
 	if (!pk_backend_is_online (backend)) {
@@ -515,7 +520,7 @@ backend_install_packages (PkBackend *backend, gchar **package_ids)
  * backend_install_files:
  */
 static void
-backend_install_files (PkBackend *backend, gboolean trusted, gchar **files)
+backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **files)
 {
 	pk_backend_thread_create (backend, backend_install_files_thread);
 }
@@ -589,7 +594,7 @@ backend_search_name (PkBackend *backend, PkBitfield filters, const gchar *search
  * backend_update_packages:
  */
 static void
-backend_update_packages (PkBackend *backend, gchar **package_ids)
+backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	/* check network state */
 	if (!pk_backend_is_online (backend)) {
@@ -604,7 +609,7 @@ backend_update_packages (PkBackend *backend, gchar **package_ids)
  * backend_update_system:
  */
 static void
-backend_update_system (PkBackend *backend)
+backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	pk_backend_thread_create (backend, backend_update_system_thread);
 }
@@ -667,6 +672,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,			/* destroy */
 	NULL,					/* get_groups */
 	backend_get_filters,			/* get_filters */
+	NULL,					/* get_roles */
 	NULL,					/* get_mime_types */
 	NULL,					/* cancel */
 	NULL,					/* download_packages */
@@ -695,6 +701,10 @@ PK_BACKEND_OPTIONS (
 	backend_search_name,			/* search_name */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
-	NULL					/* what_provides */
+	NULL,					/* what_provides */
+	NULL,					/* simulate_install_files */
+	NULL,					/* simulate_install_packages */
+	NULL,					/* simulate_remove_packages */
+	NULL					/* simulate_update_packages */
 );
 
