@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Copyright (C) 2007 Ken VanDine <ken@vandine.org>
 # Copyright (C) 2008 Richard Hughes <richard@hughsie.com>
@@ -539,7 +539,10 @@ class PackageKitConaryBackend(PackageKitBaseBackend):
             self.files(package_id, ';'.join(files))
 
     @ExceptionHandler
-    def update_system(self):
+    def update_system(self, only_trusted):
+
+        # FIXME: use only_trusted
+
         self.allow_cancel(True)
         self.status(STATUS_UPDATE)
         self.client.setUpdateCallback( UpdateSystemCallback(self, self.cfg) )
@@ -556,7 +559,9 @@ class PackageKitConaryBackend(PackageKitBaseBackend):
         self.client.setUpdateCallback(self.callback )
 
 #    @ExceptionHandler
-    def refresh_cache(self):
+    def refresh_cache(self, force):
+        # TODO: use force ?
+
         #log.debug("refresh-cache command ")
     #    self.percentage()
 
@@ -566,18 +571,23 @@ class PackageKitConaryBackend(PackageKitBaseBackend):
         cache = Cache()
         cache.refresh()
 
-    def install_packages(self, package_ids):
+    def install_packages(self, only_trusted, package_ids):
         """
             alias of update_packages
         """
-        self.update_packages(package_ids)
+
+        # FIXME: use only_trusted
+
+        self.update_packages(only_trusted, package_ids)
 
     @ExceptionHandler
-    def update_packages(self, package_ids):
+    def update_packages(self, only_trusted, package_ids):
         '''
         Implement the {backend}-{install, update}-packages functionality
         '''
 
+        # FIXME: use only_trusted
+
         for package_id in package_ids:
             name, version, flavor, installed = self._findPackage(package_id)
             log.info((name, version, flavor, installed ))
@@ -600,10 +610,11 @@ class PackageKitConaryBackend(PackageKitBaseBackend):
 
         
     @ExceptionHandler
-    def remove_packages(self, allowDeps, package_ids):
+    def remove_packages(self, allowDeps, autoremove, package_ids):
         '''
         Implement the {backend}-remove-packages functionality
         '''
+        # TODO: use autoremove
         self.allow_cancel(True)
         self.percentage(0)
         self.status(STATUS_RUNNING)
@@ -928,7 +939,7 @@ class PackageKitConaryBackend(PackageKitBaseBackend):
         for repo in labels:
             repo_name = repo.split("@")[0]
             repo_branch  = repo.split("@")[1]
-            self.repo_detail(repo,repo,"true")
+            self.repo_detail(repo,repo,True)
 
     def repo_enable(self, repoid, enable):
         '''
