@@ -16,14 +16,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gmodule.h>
 #include <glib.h>
 #include <string.h>
 #include <stdlib.h>
-#include <packagekit-glib/packagekit.h>
 
 #include <pk-backend.h>
 
@@ -31,7 +30,7 @@
 static guint _progress_percentage = 0;
 static gulong _signal_timeout = 0;
 static gchar **_package_ids;
-static const gchar *_search;
+static const gchar *_values;
 static guint _package_current = 0;
 static gboolean _repo_enabled_local = FALSE;
 static gboolean _repo_enabled_fedora = TRUE;
@@ -45,7 +44,9 @@ static gboolean _use_blocked = FALSE;
 static gboolean _use_eula = FALSE;
 static gboolean _use_media = FALSE;
 static gboolean _use_gpg = FALSE;
+static gboolean _use_trusted = TRUE;
 static gboolean _use_distro_upgrade = FALSE;
+static PkBitfield _filters = 0;
 
 /**
  * backend_initialize:
@@ -138,7 +139,7 @@ backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
-	if (egg_strequal (package_ids[0], "scribus;1.3.4-1.fc8;i386;fedora")) {
+	if (g_strcmp0 (package_ids[0], "scribus;1.3.4-1.fc8;i386;fedora") == 0) {
 		pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
 				    "scribus-clipart;1.3.4-1.fc8;i386;fedora", "Clipart for scribus");
 	} else {
@@ -161,30 +162,31 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 	const gchar *package_id;
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
+	pk_backend_set_percentage (backend, 0);
 
 	/* each one has a different detail for testing */
 	len = g_strv_length (package_ids);
 	for (i=0; i<len; i++) {
 		package_id = package_ids[i];
-		if (egg_strequal (package_id, "powertop;1.8-1.fc8;i386;fedora")) {
+		if (g_strcmp0 (package_id, "powertop;1.8-1.fc8;i386;fedora") == 0) {
 			pk_backend_details (backend, "powertop;1.8-1.fc8;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
 					    "PowerTOP is a tool that finds the software component(s) that make your "
 					    "computer use more power than necessary while it is idle.", "http://live.gnome.org/powertop", 101*1024);
-		} else if (egg_strequal (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed")) {
+		} else if (g_strcmp0 (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed") == 0) {
 			pk_backend_details (backend, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
 					    "The kernel package contains the Linux kernel (vmlinuz), the core of any "
 					    "Linux operating system.  The kernel handles the basic functions of the "
 					    "operating system: memory allocation, process allocation, device input "
 					    "and output, etc.", "http://www.kernel.org", 33*1024*1024);
-		} else if (egg_strequal (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora")) {
+		} else if (g_strcmp0 (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora") == 0) {
 			pk_backend_details (backend, "gtkhtml2;2.19.1-4.fc8;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
 					    "GtkHTML2 (sometimes called libgtkhtml) is a widget for displaying html "
 					    "pages.", "http://live.gnome.org/gtkhtml", 133*1024);
-		} else if (egg_strequal (package_id, "vino;2.24.2.fc9;i386;fedora")) {
+		} else if (g_strcmp0 (package_id, "vino;2.24.2.fc9;i386;fedora") == 0) {
 			pk_backend_details (backend, "vino;2.24.2.fc9;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
 					    "Vino is a VNC server for GNOME. It allows remote users to "
 					    "connect to a running GNOME session using VNC.", "http://live.gnome.org/powertop", 3*1024*1024);
-		} else if (egg_strequal (package_id, "gnome-power-manager;2.6.19;i386;fedora")) {
+		} else if (g_strcmp0 (package_id, "gnome-power-manager;2.6.19;i386;fedora") == 0) {
 			pk_backend_details (backend, "gnome-power-manager;2.6.19;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
 					    "GNOME Power Manager uses the information and facilities provided by HAL "
 					    "displaying icons and handling user callbacks in an interactive GNOME session.\n"
@@ -203,6 +205,7 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 					    "import/export and creation of color separations.", "http://live.gnome.org/scribus", 44*1024*1024);
 		}
 	}
+	pk_backend_set_percentage (backend, 100);
 	pk_backend_finished (backend);
 }
 
@@ -238,12 +241,12 @@ backend_get_files (PkBackend *backend, gchar **package_ids)
 	len = g_strv_length (package_ids);
 	for (i=0; i<len; i++) {
 		package_id = package_ids[i];
-		if (egg_strequal (package_id, "powertop;1.8-1.fc8;i386;fedora"))
+		if (g_strcmp0 (package_id, "powertop;1.8-1.fc8;i386;fedora") == 0)
 			pk_backend_files (backend, package_id, "/usr/share/man/man1/boo;/usr/bin/xchat-gnome");
-		else if (egg_strequal (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed"))
-			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/share/man/man1/gnome-power-manager.1.gz");
-		else if (egg_strequal (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora"))
-			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/bin/ck-xinit-session");
+		else if (g_strcmp0 (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed") == 0)
+			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/share/man/man1/gnome-power-manager.1.gz;/usr/lib/firefox-3.5.7/firefox");
+		else if (g_strcmp0 (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora") == 0)
+			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/bin/ck-xinit-session;/lib/libselinux.so.1");
 		else
 			pk_backend_files (backend, package_id, "/usr/share/gnome-power-manager;/usr/bin/ck-xinit-session");
 	}
@@ -296,17 +299,18 @@ backend_get_update_detail_timeout (gpointer data)
 		    "- xserver-1.6.0-primary.patch: Really, only look at VGA devices. (#488869)\n";
 
 	/* each one has a different detail for testing */
+	pk_backend_set_percentage (backend, 0);
 	len = g_strv_length (_package_ids);
 	for (i=0; i<len; i++) {
 		package_id = _package_ids[i];
-		if (egg_strequal (package_id, "powertop;1.8-1.fc8;i386;fedora")) {
+		if (g_strcmp0 (package_id, "powertop;1.8-1.fc8;i386;fedora") == 0) {
 			pk_backend_update_detail (backend, package_id,
 						  "powertop;1.7-1.fc8;i386;installed", "",
 						  "http://www.distro-update.org/page?moo;Bugfix release for powertop",
 						  "http://bgzilla.fd.org/result.php?#12344;Freedesktop Bugzilla #12344",
 						  "", PK_RESTART_ENUM_NONE, "Update to newest upstream source",
-						  changelog, PK_UPDATE_STATE_ENUM_STABLE, "2008-07-31", NULL);
-		} else if (egg_strequal (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed")) {
+						  changelog, PK_UPDATE_STATE_ENUM_STABLE, "2009-11-17T09:19:00", "2009-11-19T09:19:00");
+		} else if (g_strcmp0 (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed") == 0) {
 			pk_backend_update_detail (backend, package_id,
 						  "kernel;2.6.22-0.104.rc3.git6.fc8;i386;installed"
 						  PK_PACKAGE_IDS_DELIM
@@ -319,8 +323,8 @@ backend_get_update_detail_timeout (gpointer data)
 						  "Update to newest upstream version.\n"
 						  "* This should fix many driver bugs when using nouveau\n"
 						  " * This also introduces the new `frobnicator` driver for *vibrating* rabbit hardware.",
-						  changelog, PK_UPDATE_STATE_ENUM_UNSTABLE, "2008-06-28", NULL);
-		} else if (egg_strequal (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora")) {
+						  changelog, PK_UPDATE_STATE_ENUM_UNSTABLE, "2008-06-28T09:19:00", NULL);
+		} else if (g_strcmp0 (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora") == 0) {
 			pk_backend_update_detail (backend, package_id,
 						  "gtkhtml2;2.18.1-22.fc8;i386;installed", "",
 						  "http://www.distro-update.org/page?moo;Bugfix release for gtkhtml",
@@ -330,9 +334,9 @@ backend_get_update_detail_timeout (gpointer data)
 						  "* support this new thing\n"
 						  "* something else\n"
 						  "- and that new thing",
-						  changelog, PK_UPDATE_STATE_ENUM_UNKNOWN, "2008-07-25", NULL);
+						  changelog, PK_UPDATE_STATE_ENUM_UNKNOWN, "2008-07-25T09:19:00", NULL);
 
-		} else if (egg_strequal (package_id, "vino;2.24.2.fc9;i386;fedora")) {
+		} else if (g_strcmp0 (package_id, "vino;2.24.2.fc9;i386;fedora") == 0) {
 			pk_backend_update_detail (backend, package_id,
 						  "vino;2.24.1.fc9;i386;fedora", "",
 						  "", "", NULL, PK_RESTART_ENUM_NONE,
@@ -343,6 +347,7 @@ backend_get_update_detail_timeout (gpointer data)
 			pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR, "the package update detail was not found for %s", package_id);
 		}
 	}
+	pk_backend_set_percentage (backend, 100);
 	pk_backend_finished (backend);
 	_signal_timeout = 0;
 	return FALSE;
@@ -452,13 +457,15 @@ backend_install_timeout (gpointer data)
  * backend_install_packages:
  */
 static void
-backend_install_packages (PkBackend *backend, gchar **package_ids)
+backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	const gchar *license_agreement;
 	const gchar *eula_id;
 	gboolean has_eula;
 
-	if (egg_strequal (package_ids[0], "vips-doc;7.12.4-2.fc8;noarch;linva")) {
+	/* FIXME: support only_trusted */
+
+	if (g_strcmp0 (package_ids[0], "vips-doc;7.12.4-2.fc8;noarch;linva") == 0) {
 		if (_use_gpg && !_has_signature) {
 			pk_backend_repo_signature_required (backend, package_ids[0], "updates",
 							    "http://example.com/gpgkey",
@@ -509,6 +516,13 @@ backend_install_packages (PkBackend *backend, gchar **package_ids)
 		}
 	}
 
+	if (_use_trusted && only_trusted) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED,
+				       "Can't install as untrusted");
+		pk_backend_finished (backend);
+		return;
+	}
+
 	pk_backend_set_allow_cancel (backend, TRUE);
 	_progress_percentage = 0;
 	pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
@@ -527,7 +541,7 @@ backend_install_signature (PkBackend *backend, PkSigTypeEnum type,
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
 	if (type == PK_SIGTYPE_ENUM_GPG &&
 	    /* egg_strequal (package_id, "vips-doc;7.12.4-2.fc8;noarch;linva") && */
-	    egg_strequal (key_id, "BB7576AC")) {
+	    g_strcmp0 (key_id, "BB7576AC") == 0) {
 		egg_debug ("installed signature %s for %s", key_id, package_id);
 		_has_signature = TRUE;
 	} else {
@@ -553,7 +567,7 @@ backend_install_files_timeout (gpointer data)
  * backend_install_files:
  */
 static void
-backend_install_files (PkBackend *backend, gboolean trusted, gchar **full_paths)
+backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
 	pk_backend_set_percentage (backend, 101);
@@ -596,37 +610,59 @@ backend_refresh_cache (PkBackend *backend, gboolean force)
 	_signal_timeout = g_timeout_add (500, backend_refresh_cache_timeout, backend);
 }
 
+/**
+ * backend_resolve_timeout:
+ */
+static gboolean
+backend_resolve_timeout (gpointer data)
+{
+	PkBackend *backend = (PkBackend *) data;
+	guint i;
+	guint len;
+	gchar **packages = _package_ids;
+
+	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
+	pk_backend_set_percentage (backend, 0);
+
+	/* each one has a different detail for testing */
+	len = g_strv_length (packages);
+	for (i=0; i<len; i++) {
+		if (g_strcmp0 (packages[i], "vips-doc") == 0 || g_strcmp0 (packages[i], "vips-doc;7.12.4-2.fc8;noarch;linva") == 0) {
+			if (!pk_bitfield_contain (_filters, PK_FILTER_ENUM_INSTALLED)) {
+				pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
+						    "vips-doc;7.12.4-2.fc8;noarch;linva", "The vips documentation package.");
+			}
+		} else if (g_strcmp0 (packages[i], "glib2") == 0 || g_strcmp0 (packages[i], "glib2;2.14.0;i386;fedora") == 0) {
+			if (!pk_bitfield_contain (_filters, PK_FILTER_ENUM_NOT_INSTALLED)) {
+				pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+						    "glib2;2.14.0;i386;fedora", "The GLib library");
+			}
+		} else if (g_strcmp0 (packages[i], "powertop") == 0 || g_strcmp0 (packages[i], "powertop;1.8-1.fc8;i386;fedora") == 0)
+			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+					    "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor");
+		else if (g_strcmp0 (packages[i], "kernel") == 0 || g_strcmp0 (packages[i], "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed") == 0)
+			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+					    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "The Linux kernel (the core of the Linux operating system)");
+		else if (g_strcmp0 (packages[i], "gtkhtml2") == 0 || g_strcmp0 (packages[i], "gtkhtml2;2.19.1-4.fc8;i386;fedora") == 0)
+			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+					    "gtkhtml2;2.19.1-4.fc8;i386;fedora", "An HTML widget for GTK+ 2.0");
+	}
+	pk_backend_set_percentage (backend, 100);
+	pk_backend_finished (backend);
+
+	/* never repeat */
+	return FALSE;
+}
+
 /**
  * backend_resolve:
  */
 static void
 backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
 {
-	guint i;
-	guint len;
-
-	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-
-	/* each one has a different detail for testing */
-	len = g_strv_length (packages);
-	for (i=0; i<len; i++) {
-		if (egg_strequal (packages[i], "vips-doc"))
-			pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
-					    "vips-doc;7.12.4-2.fc8;noarch;linva", "The vips documentation package.");
-		else if (egg_strequal (packages[i], "glib2"))
-			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
-					    "glib2;2.14.0;i386;fedora", "The GLib library");
-		else if (egg_strequal (packages[i], "powertop"))
-			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
-					    "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor");
-		else if (egg_strequal (packages[i], "kernel"))
-			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
-					    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "The Linux kernel (the core of the Linux operating system)");
-		else if (egg_strequal (packages[i], "gtkhtml2"))
-			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
-					    "gtkhtml2;2.19.1-4.fc8;i386;fedora", "An HTML widget for GTK+ 2.0");
-	}
-	pk_backend_finished (backend);
+	_filters = filters;
+	_package_ids = packages;
+	_signal_timeout = g_timeout_add (20, backend_resolve_timeout, backend);
 }
 
 /**
@@ -661,7 +697,7 @@ static void
 backend_rollback (PkBackend *backend, const gchar *transaction_id)
 {
 	/* allow testing error condition */
-	if (egg_strequal (transaction_id, "/397_eeecadad_data")) {
+	if (g_strcmp0 (transaction_id, "/397_eeecadad_data") == 0) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_ERROR, "invalid transaction_id");
 		pk_backend_finished (backend);
 		return;
@@ -688,7 +724,7 @@ backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow
  * backend_search_details:
  */
 static void
-backend_search_details (PkBackend *backend, PkBitfield filters, const gchar *search)
+backend_search_details (PkBackend *backend, PkBitfield filters, const gchar *values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -702,7 +738,7 @@ backend_search_details (PkBackend *backend, PkBitfield filters, const gchar *sea
  * backend_search_file:
  */
 static void
-backend_search_file (PkBackend *backend, PkBitfield filters, const gchar *search)
+backend_search_file (PkBackend *backend, PkBitfield filters, const gchar *values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -721,7 +757,7 @@ backend_search_file (PkBackend *backend, PkBitfield filters, const gchar *search
  * backend_search_group:
  */
 static void
-backend_search_group (PkBackend *backend, PkBitfield filters, const gchar *search)
+backend_search_group (PkBackend *backend, PkBitfield filters, const gchar *values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -745,7 +781,7 @@ backend_search_name_timeout (gpointer data)
 	locale = pk_backend_get_locale (backend);
 
 	egg_debug ("locale is %s", locale);
-	if (!egg_strequal (locale, "en_GB.utf8")) {
+	if (g_strcmp0 (locale, "en_GB.utf8") != 0) {
 		pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
 				    "evince;0.9.3-5.fc8;i386;installed",
 				    "PDF Dokument Ƥrŏgrȃɱ");
@@ -771,7 +807,7 @@ backend_search_name_timeout (gpointer data)
  * backend_search_name:
  */
 static void
-backend_search_name (PkBackend *backend, PkBitfield filters, const gchar *search)
+backend_search_name (PkBackend *backend, PkBitfield filters, const gchar *values)
 {
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -864,11 +900,14 @@ backend_update_packages_download_timeout (gpointer data)
  * backend_update_packages:
  */
 static void
-backend_update_packages (PkBackend *backend, gchar **package_ids)
+backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	const gchar *eula_id;
 	const gchar *license_agreement;
 	gboolean has_eula;
+
+	/* FIXME: support only_trusted */
+
 	if (_use_gpg && !_has_signature) {
 		pk_backend_repo_signature_required (backend, package_ids[0], "updates",
 						    "http://example.com/gpgkey",
@@ -984,11 +1023,14 @@ backend_update_system_timeout (gpointer data)
  * backend_update_system:
  */
 static void
-backend_update_system (PkBackend *backend)
+backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD);
 	pk_backend_set_allow_cancel (backend, TRUE);
 	_progress_percentage = 0;
+
+	/* FIXME: support only_trusted */
+
 	pk_backend_require_restart (backend, PK_RESTART_ENUM_SYSTEM, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed");
 	_signal_timeout = g_timeout_add (100, backend_update_system_timeout, backend);
 }
@@ -1019,16 +1061,16 @@ backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
 
-	if (egg_strequal (rid, "local")) {
+	if (g_strcmp0 (rid, "local") == 0) {
 		egg_debug ("local repo: %i", enabled);
 		_repo_enabled_local = enabled;
-	} else if (egg_strequal (rid, "development")) {
+	} else if (g_strcmp0 (rid, "development") == 0) {
 		egg_debug ("devel repo: %i", enabled);
 		_repo_enabled_devel = enabled;
-	} else if (egg_strequal (rid, "fedora")) {
+	} else if (g_strcmp0 (rid, "fedora") == 0) {
 		egg_debug ("fedora repo: %i", enabled);
 		_repo_enabled_fedora = enabled;
-	} else if (egg_strequal (rid, "livna-development")) {
+	} else if (g_strcmp0 (rid, "livna-development") == 0) {
 		egg_debug ("livna repo: %i", enabled);
 		_repo_enabled_livna = enabled;
 	} else {
@@ -1054,6 +1096,8 @@ backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parame
 		_use_media = atoi (value);
 	else if (g_strcmp0 (parameter, "use-gpg") == 0)
 		_use_gpg = atoi (value);
+	else if (g_strcmp0 (parameter, "use-trusted") == 0)
+		_use_trusted = atoi (value);
 	else if (g_strcmp0 (parameter, "use-distro-upgrade") == 0)
 		_use_distro_upgrade = atoi (value);
 	else
@@ -1069,21 +1113,28 @@ backend_what_provides_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	if (_progress_percentage == 100) {
-		if (egg_strequal (_search, "gstreamer0.10(decoder-audio/x-wma)(wmaversion=3)")) {
+		if (g_strcmp0 (_values, "gstreamer0.10(decoder-audio/x-wma)(wmaversion=3)") == 0) {
 			pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
 					    "gstreamer-plugins-bad;0.10.3-5.lvn;i386;available",
 					    "GStreamer streaming media framework \"bad\" plug-ins");
-		} else if (egg_strequal (_search, "gstreamer0.10(decoder-video/x-wma)(wmaversion=3)")) {
+		} else if (g_strcmp0 (_values, "gstreamer0.10(decoder-video/x-wma)(wmaversion=3)") == 0) {
 			pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
 					    "gstreamer-plugins-flumpegdemux;0.10.15-5.lvn;i386;available",
 					    "MPEG demuxer for GStreamer");
 		} else {
-			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
-					    "evince;0.9.3-5.fc8;i386;installed",
-					    "PDF Document viewer");
-			pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
-					    "scribus;1.3.4-1.fc8;i386;fedora",
-					    "Scribus is an desktop open source page layout program");
+			/* pkcon install vips-doc says it's installed cause evince is INSTALLED */
+			if (g_strcmp0 (_values, "vips-doc") != 0) {
+				if (!pk_bitfield_contain (_filters, PK_FILTER_ENUM_NOT_INSTALLED)) {
+					pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+							    "evince;0.9.3-5.fc8;i386;installed",
+							    "PDF Document viewer");
+				}
+				if (!pk_bitfield_contain (_filters, PK_FILTER_ENUM_INSTALLED)) {
+					pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
+							    "scribus;1.3.4-1.fc8;i386;fedora",
+							    "Scribus is an desktop open source page layout program");
+				}
+			}
 		}
 		pk_backend_finished (backend);
 		return FALSE;
@@ -1097,11 +1148,12 @@ backend_what_provides_timeout (gpointer data)
  * backend_what_provides:
  */
 static void
-backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provides, const gchar *search)
+backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provides, const gchar *values)
 {
 	_progress_percentage = 0;
-	_search = search;
+	_values = values;
 	_signal_timeout = g_timeout_add (200, backend_what_provides_timeout, backend);
+	_filters = filters;
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
 	pk_backend_set_allow_cancel (backend, TRUE);
 	pk_backend_set_percentage (backend, _progress_percentage);
@@ -1126,28 +1178,60 @@ backend_get_packages (PkBackend *backend, PkBitfield filters)
 static void
 backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar *directory)
 {
-	gchar *filename1;
-	gchar *filename2;
-	gchar *filelist;
+	gchar *filename;
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD);
 
-	filename1 = g_build_filename (directory, "powertop-1.8-1.fc8.rpm", NULL);
-	g_file_set_contents (filename1, "hello dave", -1, NULL);
+	/* first package */
+	filename = g_build_filename (directory, "powertop-1.8-1.fc8.rpm", NULL);
+	g_file_set_contents (filename, "powertop data", -1, NULL);
 	pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
 			    "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor");
+	pk_backend_files (backend, "powertop;1.8-1.fc8;i386;fedora", filename);
+	g_free (filename);
 
-	filename2 = g_build_filename (directory, "gtk2-2.11.6-6.fc8.rpm", NULL);
-	g_file_set_contents (filename2, "hello brian", -1, NULL);
+	/* second package */
+	filename = g_build_filename (directory, "powertop-common-1.8-1.fc8.rpm", NULL);
+	g_file_set_contents (filename, "powertop-common data", -1, NULL);
 	pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+			    "powertop-common;1.8-1.fc8;i386;fedora", "Power consumption monitor");
+	pk_backend_files (backend, "powertop-common;1.8-1.fc8;i386;fedora", filename);
+	g_free (filename);
+
+	pk_backend_finished (backend);
+}
+
+/**
+ * backend_simulate_install_packages:
+ */
+static void
+backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
+{
+	pk_backend_set_status (backend, PK_STATUS_ENUM_DEP_RESOLVE);
+
+	pk_backend_package (backend, PK_INFO_ENUM_REMOVING,
+			    "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor");
+
+	pk_backend_package (backend, PK_INFO_ENUM_INSTALLING,
 			    "gtk2;2.11.6-6.fc8;i386;fedora", "GTK+ Libraries for GIMP");
 
-	/* send the filelist */
-	filelist = g_strjoin (";", filename1, filename2, NULL);
-	pk_backend_files (backend, NULL, filelist);
+	pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
+			    "lib7;7.0.1-6.fc13;i386;fedora", "C Libraries");
 
-	g_free (filename1);
-	g_free (filename2);
-	g_free (filelist);
+	pk_backend_package (backend, PK_INFO_ENUM_REINSTALLING,
+			    "libssl;3.5.7-2.fc13;i386;fedora", "SSL Libraries");
+
+	pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
+			    "vips-doc;7.12.4-2.fc8;noarch;linva", "The vips documentation package.");
+
+	pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+			    "glib2;2.14.0;i386;fedora", "The GLib library");
+
+	pk_backend_package (backend, PK_INFO_ENUM_DOWNGRADING,
+			    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "The Linux kernel (the core of the Linux operating system)");
+
+	pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
+			    "gtkhtml2;2.19.1-4.fc8;i386;fedora", "An HTML widget for GTK+ 2.0");
 
 	pk_backend_finished (backend);
 }
@@ -1159,6 +1243,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,			/* destroy */
 	backend_get_groups,			/* get_groups */
 	backend_get_filters,			/* get_filters */
+	NULL,					/* get_roles */
 	backend_get_mime_types,			/* get_mime_types */
 	backend_cancel,				/* cancel */
 	backend_download_packages,		/* download_packages */
@@ -1187,6 +1272,10 @@ PK_BACKEND_OPTIONS (
 	backend_search_name,			/* search_name */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
-	backend_what_provides			/* what_provides */
+	backend_what_provides,			/* what_provides */
+	NULL,					/* simulate_install_files */
+	backend_simulate_install_packages,	/* simulate_install_packages */
+	NULL,					/* simulate_remove_packages */
+	NULL					/* simulate_update_packages */
 );
 
