@@ -2,6 +2,7 @@
  * vi: set noexpandtab sts=8 sw=8:
  *
  * Copyright (C) 2007 OpenMoko, Inc
+ * Copyright (C) 2009 Sebastian Krzyszkowiak <seba.dos1@gmail.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -17,15 +18,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gmodule.h>
 #include <glib.h>
 #include <string.h>
-#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
-#include <pk-backend-internal.h>
 #include <egg-debug.h>
 
 #include <libopkg/opkg.h>
@@ -423,9 +422,9 @@ backend_install_packages_thread (PkBackend *backend)
 
 	for (i = 0; package_ids[i]; i++)
 	{
-		pk_backend_package (backend, PK_INFO_ENUM_INSTALLING, package_ids[0], NULL);
+		pk_backend_package (backend, PK_INFO_ENUM_INSTALLING, package_ids[i], NULL);
 
-		pi = pk_package_id_new_from_string (package_ids[0]);
+		pi = pk_package_id_new_from_string (package_ids[i]);
 
 		err = opkg_install_package (opkg, pi->name, pk_opkg_progress_cb, backend);
 		if (err)
@@ -441,7 +440,7 @@ backend_install_packages_thread (PkBackend *backend)
 }
 
 static void
-backend_install_packages (PkBackend *backend, gchar **package_ids)
+backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
@@ -475,8 +474,8 @@ backend_remove_packages_thread (PkBackend *backend)
 
 	for (i = 0; package_ids[i]; i++)
 	{
-		pi = pk_package_id_new_from_string (package_ids[0]);
-		pk_backend_package (backend, PK_INFO_ENUM_REMOVING, package_ids[0], NULL);
+		pi = pk_package_id_new_from_string (package_ids[i]);
+		pk_backend_package (backend, PK_INFO_ENUM_REMOVING, package_ids[i], NULL);
 
 		err = opkg_remove_package (opkg, pi->name, pk_opkg_progress_cb, backend);
 
@@ -540,6 +539,7 @@ backend_update_system_thread (PkBackend *backend)
 {
 	gint err;
 
+	/* FIXME: support only_trusted */
 	err = opkg_upgrade_all (opkg, pk_opkg_progress_cb, backend);
 
 	if (err)
@@ -550,7 +550,7 @@ backend_update_system_thread (PkBackend *backend)
 }
 
 static void
-backend_update_system (PkBackend *backend)
+backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_UPDATE);
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
@@ -568,6 +568,7 @@ backend_update_package_thread (PkBackend *backend)
 	gint err = 0;
 	const gchar *package_id;
 
+	/* FIXME: support only_trusted */
 	package_id = pk_backend_get_string (backend, "pkgid");
 	pi = pk_package_id_new_from_string (package_id);
 
@@ -591,7 +592,7 @@ backend_update_package_thread (PkBackend *backend)
 }
 
 static void
-backend_update_packages (PkBackend *backend, gchar **package_ids)
+backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	gint i;
 
@@ -697,7 +698,7 @@ backend_get_details_thread (PkBackend *backend)
 	newid = g_strdup_printf ("%s;%s;%s;%s", pkg->name, pkg->version, pkg->architecture, pkg->repository);
 
 	if (pkg->tags) {
-		for (group_index = 0; group < PK_GROUP_ENUM_UNKNOWN; group_index++) {
+		for (group_index = 0; group < PK_GROUP_ENUM_LAST; group_index++) {
 			group = 1 << group_index;
 			if (!(group & backend_get_groups(backend))) continue;
 			if (opkg_check_tag(pkg, (const gchar *)pk_group_enum_to_text(group))) 
@@ -726,6 +727,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,			/* destroy */
 	backend_get_groups,			/* get_groups */
 	backend_get_filters,			/* get_filters */
+	NULL,					/* get_roles */
 	NULL,					/* get_mime_types */
 	NULL,					/* cancel */
 	NULL,					/* download_packages */
@@ -754,6 +756,10 @@ PK_BACKEND_OPTIONS (
 	backend_search_name,			/* search_name */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
-	NULL					/* what_provides */
+	NULL,					/* what_provides */
+	NULL,					/* simulate_install_files */
+	NULL,					/* simulate_install_packages */
+	NULL,					/* simulate_remove_packages */
+	NULL					/* simulate_update_packages */
 );
 
