@@ -16,10 +16,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
 
 #include <log.h>
@@ -43,13 +42,14 @@ static gint do_get_files_to_download (const struct poldek_ts *ts, const gchar *m
 static void pb_load_packages (PkBackend *backend);
 static void poldek_backend_set_allow_cancel (PkBackend *backend, gboolean allow_cancel, gboolean reset);
 
-static void pb_error_show (PkBackend *backend, PkErrorCodeEnum errorcode);
+static void pb_error_show (PkBackend *backend, PkErrorEnum errorcode);
 static void pb_error_clean (void);
 static void poldek_backend_percentage_data_destroy (PkBackend *backend);
 
 typedef enum {
 	TS_TYPE_ENUM_INSTALL,
 	TS_TYPE_ENUM_UPDATE,
+	TS_TYPE_ENUM_REMOVE,
 	TS_TYPE_ENUM_REFRESH_CACHE
 } TsType;
 
@@ -524,6 +524,78 @@ poldek_pkg_in_array (const struct pkg *pkg, const tn_array *array, tn_fn_cmp cmp
 		return TRUE;
 }
 
+static void
+get_ts_summary (TsType type, tn_array *ipkgs, tn_array *dpkgs, tn_array *rpkgs,
+		tn_array **install_pkgs, tn_array **update_pkgs, tn_array **remove_pkgs)
+{
+	guint  i;
+
+	if (type == TS_TYPE_ENUM_INSTALL || type == TS_TYPE_ENUM_UPDATE) {
+		*install_pkgs = n_array_new (2, (tn_fn_free)pkg_free, (tn_fn_cmp)pkg_cmp_name_evr);
+		*update_pkgs = n_array_new (2, (tn_fn_free)pkg_free, (tn_fn_cmp)pkg_cmp_name_evr);
+	}
+
+	*remove_pkgs = n_array_new (2, (tn_fn_free)pkg_free, (tn_fn_cmp)pkg_cmp_name_evr);
+
+	switch (type) {
+		case TS_TYPE_ENUM_INSTALL:
+		case TS_TYPE_ENUM_UPDATE:
+			if (rpkgs) {
+				for (i = 0; i < n_array_size (rpkgs); i++) {
+					struct pkg *rpkg = n_array_nth (rpkgs, i);
+
+					if (poldek_pkg_in_array (rpkg, ipkgs, (tn_fn_cmp)pkg_cmp_name) ||
+					    poldek_pkg_in_array (rpkg, dpkgs, (tn_fn_cmp)pkg_cmp_name)) {
+						n_array_push (*update_pkgs, pkg_link (rpkg));
+
+					} else {
+						n_array_push (*remove_pkgs, pkg_link (rpkg));
+					}
+				}
+			}
+
+			if (ipkgs) {
+				for (i = 0; i < n_array_size (ipkgs); i++) {
+					struct pkg *ipkg = n_array_nth (ipkgs, i);
+
+					if (poldek_pkg_in_array (ipkg, *update_pkgs, (tn_fn_cmp)pkg_cmp_name) == FALSE)
+						n_array_push (*install_pkgs, pkg_link (ipkg));
+				}
+			}
+
+			if (dpkgs) {
+				for (i = 0; i < n_array_size (dpkgs); i++) {
+					struct pkg *dpkg = n_array_nth (dpkgs, i);
+
+					if (poldek_pkg_in_array (dpkg, *update_pkgs, (tn_fn_cmp)pkg_cmp_name) == FALSE)
+						n_array_push (*install_pkgs, pkg_link (dpkg));
+				}
+			}
+			break;
+		case TS_TYPE_ENUM_REMOVE:
+			/* copy packages from rpkgs and dpkgs to remove_pkgs */
+			if (rpkgs)
+				n_array_concat_ex (*remove_pkgs, rpkgs, (tn_fn_dup)pkg_link);
+
+			if (dpkgs)
+				n_array_concat_ex (*remove_pkgs, dpkgs, (tn_fn_dup)pkg_link);
+
+			break;
+		default:
+			egg_error ("Unknown ts_type value: %d", type);
+	}
+
+	/* return sorted arrays */
+	if (*install_pkgs)
+		n_array_sort (*install_pkgs);
+
+	if (*update_pkgs)
+		n_array_sort (*update_pkgs);
+
+	if (*remove_pkgs)
+		n_array_sort (*remove_pkgs);
+}
+
 /**
  * ts_confirm:
  * Returns Yes - 1
@@ -537,8 +609,6 @@ ts_confirm (void *data, struct poldek_ts *ts)
 	size_t		i = 0;
 	gint		result = 1;
 
-	egg_debug ("START\n");
-
 	ipkgs = poldek_ts_get_summary (ts, "I");
 	dpkgs = poldek_ts_get_summary (ts, "D");
 	rpkgs = poldek_ts_get_summary (ts, "R");
@@ -908,18 +978,25 @@ poldek_get_vr_from_package_id_evr (const gchar *evr)
 static gchar*
 poldek_get_nvra_from_package_id (const gchar* package_id)
 {
-	PkPackageId	*pi;
-	gchar		*vr, *result;
+	gchar **parts = NULL;
+	gchar  *nvra = NULL;
 
-	pi = pk_package_id_new_from_string (package_id);
-	vr = poldek_get_vr_from_package_id_evr (pi->version);
+	g_return_val_if_fail (package_id != NULL, NULL);
 
-	result = g_strdup_printf ("%s-%s.%s", pi->name, vr, pi->arch);
+	if ((parts = pk_package_id_split (package_id))) {
+		gchar *vr = NULL;
 
-	g_free (vr);
-	pk_package_id_free (pi);
+		vr = poldek_get_vr_from_package_id_evr (parts[PK_PACKAGE_ID_VERSION]);
 
-	return result;
+		nvra = g_strdup_printf ("%s-%s.%s", parts[PK_PACKAGE_ID_NAME],
+						    vr,
+						    parts[PK_PACKAGE_ID_ARCH]);
+
+		g_free (vr);
+		g_strfreev (parts);
+	}
+
+	return nvra;
 }
 
 /**
@@ -1411,28 +1488,32 @@ poldek_backend_package (PkBackend *backend, struct pkg *pkg, PkInfoEnum infoenum
 static struct pkg*
 poldek_get_pkg_from_package_id (const gchar *package_id)
 {
-	PkPackageId		*pi;
-	struct pkg		*result = NULL;
-	gchar			*vr;
-	tn_array *packages = NULL;
+	struct pkg  *pkg = NULL;
+	gchar      **parts = NULL;
 
-	pi = pk_package_id_new_from_string (package_id);
+	g_return_val_if_fail (package_id != NULL, NULL);
 
-	vr = poldek_get_vr_from_package_id_evr (pi->version);
+	if ((parts = pk_package_id_split (package_id))) {
+		tn_array *packages = NULL;
+		gchar    *vr = NULL;
 
-	if ((packages = execute_packages_command ("cd /%s; ls -q %s-%s.%s", pi->data, pi->name, vr, pi->arch)) != NULL) {
-		if (n_array_size (packages) > 0) {
-			/* only one package is needed */
-			result = pkg_link (n_array_nth (packages, 0));
+		vr = poldek_get_vr_from_package_id_evr (parts[PK_PACKAGE_ID_VERSION]);
+
+		if ((packages = execute_packages_command ("cd /%s; ls -q %s-%s.%s", parts[PK_PACKAGE_ID_DATA],
+										    parts[PK_PACKAGE_ID_NAME],
+										    vr,
+										    parts[PK_PACKAGE_ID_ARCH]))) {
+			if (n_array_size (packages) > 0) {
+				/* only one package is needed */
+				pkg = pkg_link (n_array_nth (packages, 0));
+			}
 		}
-		n_array_free (packages);
+
+		g_free (vr);
+		g_strfreev (parts);
 	}
 
-	pk_package_id_free (pi);
-
-	g_free (vr);
-
-	return result;
+	return pkg;
 }
 
 /**
@@ -1635,6 +1716,7 @@ update_packages_thread (PkBackend *backend)
 	GString *cmd;
 
 	update_system = pk_backend_get_bool (backend, "update_system");
+	/* FIXME: support only_trusted */
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 
 	/* sth goes wrong. package_ids has to be set in UpdatePackages */
@@ -1722,20 +1804,20 @@ pb_load_packages (PkBackend *backend)
 }
 
 static void
-pb_error_show (PkBackend *backend, PkErrorCodeEnum errorcode)
+pb_error_show (PkBackend *backend, PkErrorEnum errorcode)
 {
 	if (sigint_reached()) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_TRANSACTION_CANCELLED, "Action cancelled.");
 		return;
 	}
 
-	/* Before emiting error_code try to find the most suitable PkErrorCodeEnum */
+	/* Before emiting error_code try to find the most suitable PkErrorEnum */
 	if (g_strrstr (pberror->tslog->str, " unresolved depend") != NULL)
 		errorcode = PK_ERROR_ENUM_DEP_RESOLUTION_FAILED;
 	else if (g_strrstr (pberror->tslog->str, " conflicts") != NULL)
 		errorcode = PK_ERROR_ENUM_FILE_CONFLICTS;
 
-	pk_backend_error_code (backend, errorcode, pberror->tslog->str);
+	pk_backend_error_code (backend, errorcode, "%s", pberror->tslog->str);
 }
 
 /**
@@ -1748,7 +1830,7 @@ pb_error_show (PkBackend *backend, PkErrorCodeEnum errorcode)
 static gboolean
 pb_error_check (PkBackend *backend)
 {
-	PkErrorCodeEnum	errorcode = PK_ERROR_ENUM_UNKNOWN;
+	PkErrorEnum	errorcode = PK_ERROR_ENUM_UNKNOWN;
 
 	if (g_strrstr (pberror->tslog->str, " version installed, skipped") != NULL)
 		errorcode = PK_ERROR_ENUM_PACKAGE_ALREADY_INSTALLED;
@@ -2570,7 +2652,7 @@ get_obsoletedby_pkg (struct pkg *pkg)
 static gboolean
 backend_get_update_detail_thread (PkBackend *backend)
 {
-	gchar **package_ids;
+	gchar **package_ids = NULL;
 	guint n;
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
@@ -2578,19 +2660,20 @@ backend_get_update_detail_thread (PkBackend *backend)
 	pb_load_packages (backend);
 
 	for (n = 0; n < g_strv_length (package_ids); n++) {
-		PkPackageId *pi = NULL;
-		tn_array *packages = NULL;
+		tn_array  *packages = NULL;
+		gchar    **parts = NULL;
 
-		pi = pk_package_id_new_from_string (package_ids[n]);
+		if ((parts = pk_package_id_split (package_ids[n])) == NULL)
+			continue;
 
-		if ((packages = execute_packages_command ("cd /installed; ls -q %s", pi->name)) != NULL) {
+		if ((packages = execute_packages_command ("cd /installed; ls -q %s", parts[PK_PACKAGE_ID_NAME])) != NULL) {
 			struct pkg *pkg = NULL;
 			struct pkg *upkg = NULL;
 
 			/* get one package */
 			pkg = n_array_nth (packages, 0);
 
-			if (strcmp (pkg->name, pi->name) == 0) {
+			if (strcmp (pkg->name, parts[PK_PACKAGE_ID_NAME]) == 0) {
 				gchar *updates = NULL;
 				gchar *obsoletes = NULL;
 				gchar *cve_url = NULL;
@@ -2658,7 +2741,7 @@ backend_get_update_detail_thread (PkBackend *backend)
 						  "", NULL, PK_UPDATE_STATE_ENUM_UNKNOWN, NULL, NULL);
 		}
 
-		pk_package_id_free (pi);
+		g_strfreev (parts);
 	}
 
 	pk_backend_finished (backend);
@@ -2743,6 +2826,8 @@ backend_install_packages_thread (PkBackend *backend)
 	size_t i;
 
 	pk_backend_set_uint (backend, "ts_type", TS_TYPE_ENUM_INSTALL);
+
+	/* FIXME: support only_trusted */
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 
 	setup_vf_progress (&vf_progress, backend);
@@ -2779,7 +2864,7 @@ backend_install_packages_thread (PkBackend *backend)
 }
 
 static void
-backend_install_packages (PkBackend *backend, gchar **package_ids)
+backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	if (!pk_backend_is_online (backend)) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_NO_NETWORK, "Cannot install package when offline!");
@@ -2985,7 +3070,7 @@ backend_search_name (PkBackend *backend, PkBitfield filters, const gchar *search
  * backend_update_packages:
  */
 static void
-backend_update_packages (PkBackend *backend, gchar **package_ids)
+backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	if (!pk_backend_is_online (backend)) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_NO_NETWORK, "Cannot update packages when offline!");
@@ -3005,7 +3090,7 @@ backend_update_packages (PkBackend *backend, gchar **package_ids)
  * backend_update_system:
  **/
 static void
-backend_update_system (PkBackend *backend)
+backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	if (!pk_backend_is_online (backend)) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_NO_NETWORK, "Cannot update system when offline!");
@@ -3069,6 +3154,131 @@ backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum pr
 	pk_backend_thread_create (backend, search_package_thread);
 }
 
+static gboolean do_simulate_packages (PkBackend *backend)
+{
+	struct poclidek_rcmd *rcmd = NULL;
+	struct poldek_ts     *ts = NULL;
+	GString      *buf = NULL;
+	gchar        *cmd = NULL;
+	gchar       **package_ids = NULL;
+	const gchar  *command = NULL;
+	guint         i;
+	guint         ts_type;
+
+	package_ids = pk_backend_get_strv (backend, "package_ids");
+	command = pk_backend_get_string (backend, "command");
+	ts_type = pk_backend_get_uint (backend, "ts_type");
+
+	pk_backend_set_status (backend, PK_STATUS_ENUM_DEP_RESOLVE);
+
+	buf = g_string_new (command);
+
+	for (i = 0; i < g_strv_length (package_ids); i++) {
+		gchar *nvra = poldek_get_nvra_from_package_id (package_ids[i]);
+
+		g_string_append_c (buf, ' ');
+		g_string_append (buf, nvra);
+
+		g_free (nvra);
+	}
+
+	cmd = g_string_free (buf, FALSE);
+
+	ts = poldek_ts_new (ctx, 0);
+	rcmd = poclidek_rcmd_new (cctx, ts);
+
+	ts->setop(ts, POLDEK_OP_PARTICLE, 0);
+
+	if (poclidek_rcmd_execline (rcmd, cmd)) {
+		tn_array *ipkgs = NULL, *dpkgs = NULL, *rpkgs = NULL;
+		tn_array *install_pkgs = NULL, *update_pkgs = NULL, *remove_pkgs = NULL;
+
+		ipkgs = poldek_ts_get_summary (ts, "I");
+		dpkgs = poldek_ts_get_summary (ts, "D");
+		rpkgs = poldek_ts_get_summary (ts, "R");
+
+		get_ts_summary (ts_type, ipkgs, dpkgs, rpkgs, &install_pkgs, &update_pkgs, &remove_pkgs);
+
+		if (install_pkgs) {
+			for (i = 0; i < n_array_size (install_pkgs); i++) {
+				struct pkg *pkg = n_array_nth (install_pkgs, i);
+
+				poldek_backend_package (backend, pkg, PK_INFO_ENUM_INSTALLING, PK_FILTER_ENUM_NONE);
+			}
+
+			n_array_free (install_pkgs);
+		}
+
+		if (update_pkgs) {
+			for (i = 0; i < n_array_size (update_pkgs); i++) {
+				struct pkg *pkg = n_array_nth (update_pkgs, i);
+
+				poldek_backend_package (backend, pkg, PK_INFO_ENUM_UPDATING, PK_FILTER_ENUM_NONE);
+			}
+
+			n_array_free (update_pkgs);
+		}
+
+		if (remove_pkgs) {
+			for (i = 0; i < n_array_size (remove_pkgs); i++) {
+				struct pkg *pkg = n_array_nth (remove_pkgs, i);
+
+				poldek_backend_package (backend, pkg, PK_INFO_ENUM_REMOVING, PK_FILTER_ENUM_NONE);
+			}
+
+			n_array_free (remove_pkgs);
+		}
+	}
+
+	g_free (cmd);
+
+	poclidek_rcmd_free (rcmd);
+	poldek_ts_free (ts);
+
+	pk_backend_finished (backend);
+
+	return TRUE;
+}
+
+/**
+ * backend_simulate_install_packages:
+ **/
+static void
+backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
+{
+	poldek_backend_set_allow_cancel (backend, TRUE, TRUE);
+	pb_error_clean ();
+	pk_backend_set_uint (backend, "ts_type", TS_TYPE_ENUM_INSTALL);
+	pk_backend_set_string (backend, "command", "cd /all-avail; install --test");
+	pk_backend_thread_create (backend, do_simulate_packages);
+}
+
+/**
+ * backend_simulate_remove_packages:
+ **/
+static void
+backend_simulate_remove_packages (PkBackend *backend, gchar **package_ids)
+{
+	poldek_backend_set_allow_cancel (backend, TRUE, TRUE);
+	pb_error_clean ();
+	pk_backend_set_uint (backend, "ts_type", TS_TYPE_ENUM_REMOVE);
+	pk_backend_set_string (backend, "command", "cd /all-avail; uninstall --test");
+	pk_backend_thread_create (backend, do_simulate_packages);
+}
+
+/**
+ * backend_simulate_update_packages:
+ **/
+static void
+backend_simulate_update_packages (PkBackend *backend, gchar **package_ids)
+{
+	poldek_backend_set_allow_cancel (backend, TRUE, TRUE);
+	pb_error_clean ();
+	pk_backend_set_uint (backend, "ts_type", TS_TYPE_ENUM_UPDATE);
+	pk_backend_set_string (backend, "command", "cd /all-avail; upgrade --test");
+	pk_backend_thread_create (backend, do_simulate_packages);
+}
+
 PK_BACKEND_OPTIONS (
 	"poldek",					/* description */
 	"Marcin Banasiak <megabajt@pld-linux.org>",	/* author */
@@ -3076,6 +3286,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,				/* destroy */
 	backend_get_groups,				/* get_groups */
 	backend_get_filters,				/* get_filters */
+	NULL,						/* get_roles */
 	backend_get_mime_types,				/* get_mime_types */
 	backend_get_cancel,				/* cancel */
 	backend_download_packages,			/* download_packages */
@@ -3104,6 +3315,10 @@ PK_BACKEND_OPTIONS (
 	backend_search_name,				/* search_name */
 	backend_update_packages,			/* update_packages */
 	backend_update_system,				/* update_system */
-	backend_what_provides				/* what_provides */
+	backend_what_provides,				/* what_provides */
+	NULL,						/* simulate_install_files */
+	backend_simulate_install_packages,		/* simulate_install_packages */
+	backend_simulate_remove_packages,		/* simulate_remove_packages */
+	backend_simulate_update_packages		/* simulate_update_packages */
 );
 
