@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # Copyright (C) 2007 James Bowes <jbowes@dangerouslyinc.com>
 # Copyright (C) 2008 Anders F Bjorklund <afb@users.sourceforge.net>
@@ -61,6 +61,7 @@ class PackageKitSmartInterface(Interface):
     def __init__(self, ctrl, backend):
         Interface.__init__(self, ctrl)
         smart.sysconf.set("max-active-downloads", 1, soft=True)
+        smart.sysconf.set("deb-non-interactive", True, soft=True)
         self._progress = PackageKitSmartProgress(True, backend)
 
     def getProgress(self, obj, hassub=False):
@@ -167,7 +168,10 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self._package_list = []
 
     @needs_cache
-    def install_packages(self, packageids):
+    def install_packages(self, only_trusted, packageids):
+        if only_trusted:
+            self.error(ERROR_MISSING_GPG_SIGNATURE, "Trusted packages not available.")
+            return
         packages = []
         for packageid in packageids:
             ratio, results, suggestions = self._search_packageid(packageid)
@@ -200,7 +204,10 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self.ctrl.commitTransaction(trans, confirm=False)
 
     @needs_cache
-    def install_files(self, trusted, paths):
+    def install_files(self, only_trusted, paths):
+        if only_trusted:
+            self.error(ERROR_MISSING_GPG_SIGNATURE, "Trusted packages not available.")
+            return
         for path in paths:
             self.ctrl.addFileChannel(path)
         self.ctrl.reloadChannels()
@@ -223,7 +230,8 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self.ctrl.commitTransaction(trans, confirm=False)
 
     @needs_cache
-    def remove_packages(self, allow_deps, packageids):
+    def remove_packages(self, allow_deps, autoremove, packageids):
+        # TODO: use autoremove
         packages = []
         for packageid in packageids:
             ratio, results, suggestions = self._search_packageid(packageid)
@@ -259,7 +267,10 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self.ctrl.commitTransaction(trans, confirm=False)
 
     @needs_cache
-    def update_packages(self, packageids):
+    def update_packages(self, only_trusted, packageids):
+        if only_trusted:
+            self.error(ERROR_MISSING_GPG_SIGNATURE, "Trusted packages not available.")
+            return
         packages = []
         for packageid in packageids:
             ratio, results, suggestions = self._search_packageid(packageid)
@@ -307,7 +318,10 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
             self.files(package, ";".join(files))
 
     @needs_cache
-    def update_system(self):
+    def update_system(self, only_trusted):
+        if only_trusted:
+            self.error(ERROR_MISSING_GPG_SIGNATURE, "Trusted packages not available.")
+            return
         self.status(STATUS_INFO)
         cache = self.ctrl.getCache()
 
@@ -422,8 +436,8 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
                 else:
                     vendor_urls.append(url)
             vendor_url = ';'.join(vendor_urls)
-            bugzilla_url = ';'.join(vendor_urls)
-            cve_url = ';'.join(vendor_urls)
+            bugzilla_url = ';'.join(bugzilla_urls)
+            cve_url = ';'.join(cve_urls)
 
             if errata.isRebootSuggested():
                 reboot = 'system'
@@ -518,23 +532,8 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self._post_process_package_list(filters)
         self._show_package_list()
 
-    @needs_cache
-    def what_provides(self, filters, provides_type, search):
-        self.status(STATUS_QUERY)
-        self.allow_cancel(True)
-        if provides_type != PROVIDES_ANY:
-            self.error(ERROR_NOT_SUPPORTED,
-                       "provide %s not supported" % provides_type)
-            return
-        providers = self.ctrl.getCache().getProvides(search)
-        for provider in providers:
-            for package in provider.packages:
-                if self._package_passes_filters(package, filters):
-                    self._add_package(package)
-        self._post_process_package_list(filters)
-        self._show_package_list()
-
-    def refresh_cache(self):
+    def refresh_cache(self, force):
+        # TODO: use force ?
         self.status(STATUS_REFRESH_CACHE)
         self.allow_cancel(True)
         self.ctrl.rebuildSysConfChannels()
@@ -803,13 +802,6 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
 
             self.files(packageid, ";".join(paths))
 
-    def _text_to_boolean(self, text):
-        if text == 'true' or text == 'TRUE':
-            return True
-        elif text == 'yes' or text == 'YES':
-            return True
-        return False
-
     def _best_package_from_list(self, package_list):
         for installed in (True, False):
             best = None
@@ -821,8 +813,7 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         return None
 
     @needs_cache
-    def get_depends(self, filters, packageids, recursive_text):
-        recursive = self._text_to_boolean(recursive_text)
+    def get_depends(self, filters, packageids, recursive):
         self.status(STATUS_INFO)
         self.allow_cancel(True)
         for packageid in packageids:
@@ -856,8 +847,7 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
             self._show_package_list()
 
     @needs_cache
-    def get_requires(self, filters, packageids, recursive_text):
-        recursive = self._text_to_boolean(recursive_text)
+    def get_requires(self, filters, packageids, recursive):
         self.status(STATUS_INFO)
         self.allow_cancel(True)
         for packageid in packageids:
@@ -898,9 +888,9 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
             channel = smart.sysconf.get(("channels", alias))
             name = channel.get("name", alias)
             parsed = smart.channel.parseChannelData(channel)
-            enabled = 'true'
+            enabled = True
             if channel.has_key('disabled') and channel['disabled'] == 'yes':
-                enabled = 'false'
+                enabled = False
             channel['alias'] = alias
             if self._channel_passes_filters(channel, filters):
                 self.repo_detail(alias, name, enabled)
@@ -909,7 +899,7 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         self.status(STATUS_INFO)
         self.allow_cancel(True)
         if smart.sysconf.has(("channels", repoid)):
-            if enable == "true":
+            if enable:
                 smart.sysconf.remove(("channels", repoid, "disabled"))
             else:
                 smart.sysconf.set(("channels", repoid, "disabled"), "yes")
