@@ -10,34 +10,12 @@
 # (at your option) any later version.
 #
 
-#
-# Dispatched backend implementation progress
-#
-# get-depends                   DONE
-# get-details                   DONE
-# get-distro-upgrades           DONE
-# get-files                     DONE
-# get-packages                  DONE
-# get-requires                  DONE
-# get-update-detail             DONE
-# get-updates                   DONE
-# install-packages		DONE
-# refresh-cache                 DONE
-# remove-packages               DONE
-# resolve                       DONE
-# search-details                DONE
-# search-file                   DONE
-# search-group                  DONE
-# search-name                   DONE
-# update-packages               DONE
-# update-system                 DONE
-#
-
 use strict;
 local $| = 1; # stdout autoflush
 
 use lib;
 use File::Basename;
+use File::Temp;
 
 BEGIN {
   push @INC, dirname($0);
@@ -92,6 +70,9 @@ sub dispatch_command {
   elsif($command eq "get-packages") {
     get_packages($urpm, $args);
   }
+  elsif($command eq "get-repo-list") {
+    get_repo_list($urpm, $args);
+  }
   elsif($command eq "get-requires") {
     get_requires($urpm, $args);
   }
@@ -116,6 +97,9 @@ sub dispatch_command {
     remove_packages($urpm, $args);
     urpm::media::configure($urpm);
   }
+  elsif($command eq "repo-enable") {
+    repo_enable($urpm, $args);
+  }
   elsif($command eq "resolve") {
     resolve($urpm, $args);
   }
@@ -133,7 +117,7 @@ sub dispatch_command {
     urpm::media::configure($urpm);
   }
   elsif($command eq "update-system") {
-    update_system($urpm);
+    update_system($urpm, $args);
     urpm::media::configure($urpm);
   }
   elsif($command eq "exit") {
@@ -146,10 +130,8 @@ sub get_depends {
   my ($urpm, $args) = @_;
   
   my @filterstab = split(/;/, @{$args}[0]);
-  shift @{$args};
-  my $recursive_text = pop @{$args};
-  my $recursive_option = $recursive_text eq "yes" ? 1 : 0;
-  my @packageidstab = @{$args};
+  my @packageidstab = split(/&/, @{$args}[1]);
+  my $recursive_option = @{$args}[2] eq "yes" ? 1 : 0;
   
   pk_print_status(PK_STATUS_ENUM_DEP_RESOLVE);
   
@@ -201,7 +183,7 @@ sub get_details {
 
   my ($urpm, $args) = @_;
   
-  my @packageidstab = @{$args};
+  my @packageidstab = split(/&/, @{$args}[0]);
   pk_print_status(PK_STATUS_ENUM_QUERY);
 
   foreach (@packageidstab) {
@@ -220,7 +202,7 @@ sub get_distro_upgrades {
   %product_id = _parse_line(<PRODUCT_FILE>);
   close(PRODUCT_FILE);
 
-  my $distribfile_path = "/tmp/distrib.list";
+  my (undef, $distribfile_path) = tempfile("packagekit_urpmi_XXXXXX", UNLINK => 1);
   _download_distrib_file($distribfile_path, \%product_id);
 
   -f $distribfile_path or goto finished;
@@ -256,7 +238,7 @@ sub get_files {
   
   my ($urpm, $args) = @_;
   
-  my @packageidstab = @{$args};
+  my @packageidstab = split(/&/, @{$args}[0]);
   pk_print_status(PK_STATUS_ENUM_QUERY);
   
   foreach (@packageidstab) {
@@ -298,15 +280,23 @@ sub get_packages {
   _finished();
 }
 
+sub get_repo_list {
+
+  my ($urpm, $args) = @_;
+  foreach my $media (@{$urpm->{media}}) {
+    pk_print_repo_details($media->{name}, $media->{name}, $media->{ignore});
+  }
+  _finished();
+}
+
+
 sub get_requires {
   
   my ($urpm, $args) = @_;
   
   my @filterstab = split(/;/, @{$args}[0]);
-  shift @{$args};
-  my $recursive_text = pop @{$args};
-  my $recursive_option = $recursive_text eq "yes" ? 1 : 0;
-  my @packageidstab = @{$args};
+  my @packageidstab = split(/&/, @{$args}[1]);
+  my $recursive_option = @{$args}[2] eq "yes" ? 1 : 0;
   
   my @pkgnames;
   foreach (@packageidstab) {
@@ -335,7 +325,7 @@ sub get_update_detail {
   my ($urpm, $args) = @_;
   
   pk_print_status(PK_STATUS_ENUM_QUERY);
-  my @packageidstab = @{$args};
+  my @packageidstab = split(/&/, @{$args}[0]);
   
   foreach (@packageidstab) {
     _print_package_update_details($urpm, $_);
@@ -377,7 +367,8 @@ sub install_packages {
 
   my ($urpm, $args) = @_;
 
-  my @packageidstab = @{$args};
+  my $only_trusted = @{$args}[0];
+  my @packageidstab = split(/&/, @{$args}[1]);
   
   my @names;
   foreach(@packageidstab) {
@@ -392,7 +383,7 @@ sub install_packages {
     caseinsensitive => 0,
     all => 0);
   eval {
-    perform_installation($urpm, \%requested);
+    perform_installation($urpm, \%requested, { only_trusted => $only_trusted });
   };
   _finished();
 }
@@ -476,9 +467,8 @@ sub remove_packages {
 
   my $urpmi_lock = urpm::lock::urpmi_db($urpm, 'exclusive', wait => 1);
 
-  my $allowdeps_text = shift @{$args};
-  my $allowdeps_option = $allowdeps_text eq "yes" ? 1 : 0;
-  my @packageidstab = @{$args};
+  my $allowdeps_option = @{$args}[0] eq "yes" ? 1 : 0;
+  my @packageidstab = split(/&/, @{$args}[1]);
 
   my @names;
   foreach(@packageidstab) {
@@ -525,13 +515,34 @@ sub remove_packages {
   _finished();
 }
 
+sub repo_enable {
+
+  my ($urpm, $args) = @_;
+
+  my $name = @{$args}[0];
+  my $enable = @{$args}[1] eq "yes" ? 1 : 0;
+
+  my @media = grep { $_->{name} eq $name } @{$urpm->{media}};
+  if ($#media == 0) {
+    if ($enable) {
+      delete @media[0]->{ignore};
+    } else {
+      $media[0]->{ignore} = 1;
+    }
+    urpm::media::write_config($urpm);
+  } else {
+    pk_print_error(PK_ERROR_ENUM_REPO_NOT_FOUND, qq(Repository named "$name" not found.\n));
+  }
+
+  _finished();
+}
+
 sub resolve {
 
   my ($urpm, $args) = @_;
 
   my @filters = split(/;/, @{$args}[0]);
-  shift @{$args};
-  my @patterns = @{$args};
+  my @patterns = split(/&/, @{$args}[1]);
 
   pk_print_status(PK_STATUS_ENUM_QUERY);
 
@@ -569,8 +580,7 @@ sub search_details {
 
   my ($urpm, $args) = @_;
   my @filters = split(/;/, @{$args}[0]);
-  shift @{$args};
-  my $search_term = pop @{$args};
+  my $search_term = @{$args}[1];
 
   pk_print_status(PK_STATUS_ENUM_QUERY);
 
@@ -669,8 +679,11 @@ sub update_packages {
 
   my ($urpm, $args) = @_;
 
+  my $only_trusted = @{$args}[0];
+  my @packageidstab = split(/&/, @{$args}[1]);
+
   my @names;
-  foreach(@{$args}) {
+  foreach(@packageidstab) {
     my @pkgid = split(/;/, $_);
     push @names, $pkgid[0];
   }
@@ -692,16 +705,18 @@ sub update_packages {
     tonext:
   }
   eval {
-    perform_installation($urpm, \%requested);
+    perform_installation($urpm, \%requested, only_trusted => $only_trusted);
   };
   _finished();
 }
 
 sub update_system {
   
-  my ($urpm) = @_;
+  my ($urpm, $args) = @_;
+
+  my $only_trusted = @{$args}[0];
   eval {
-    perform_installation($urpm, {}, auto_select => 1);
+    perform_installation($urpm, {}, { auto_select => 1, only_trusted => $only_trusted});
   };
   _finished();
 }
@@ -736,7 +751,7 @@ sub _print_package_details {
   $description =~ s/\n/;/g;
   $description =~ s/\t/ /g;
   
-  pk_print_details(get_package_id($pkg), "N/A", $pkg->group, ensure_utf8($description), "N/A", $pkg->size);
+  pk_print_details(get_package_id($pkg), "N/A", get_pk_group($pkg->group), ensure_utf8($description), $xml_info_pkgs{$name}{url}, $pkg->size);
 }
 
 sub _print_package_files {
@@ -795,7 +810,7 @@ sub _print_package_update_details {
     "http://qa.mandriva.com",
     "http://qa.mandriva.com",
     "http://qa.mandriva.com",
-    $restart ? PK_RESTART_ENUM_SYSTEM : PK_RESTART_ENUM_APPLICATION,
+    $restart ? PK_RESTART_ENUM_SYSTEM : PK_RESTART_ENUM_NONE,
     $desc);
 }
 
