@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # Copyright (C) 2008
 #    Richard Hughes <richard@hughsie.com>
@@ -29,6 +29,15 @@ GUI_KEYS = re.compile(r'(qt)|(gtk)')
 
 class YumFilter(PackagekitFilter):
 
+    def __init__(self, fltlist="none"):
+        PackagekitFilter.__init__(self, fltlist)
+        basearch = rpmUtils.arch.getBaseArch()
+        if basearch == 'i386':
+            self.basearch_list = ['i386', 'i486', 'i586', 'i686']
+        else:
+            self.basearch_list = [basearch]
+        self.basearch_list.append('noarch')
+
     def _is_main_package(self, repo):
         if repo.endswith('-debuginfo'):
             return False
@@ -157,6 +166,14 @@ class YumFilter(PackagekitFilter):
                 return True
         return False
 
+    def _pkg_is_arch(self, pkg):
+        '''
+        Return if the package is native arch.
+        '''
+        if pkg.arch in self.basearch_list:
+            return True
+        return False
+
     def _pkg_is_free(self, pkg):
         '''
         Return if the package is free software.
