@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <sstream>
@@ -561,7 +561,7 @@ zypp_emit_packages_in_list (PkBackend *backend, std::vector<zypp::sat::Solvable>
 		// iterate through the given filters
 		if (filters != 0){
 			gboolean print = TRUE;
-			for (guint i = 0; i < PK_FILTER_ENUM_UNKNOWN; i++) {
+			for (guint i = 0; i < PK_FILTER_ENUM_LAST; i++) {
 				if ((filters & pk_bitfield_value (i)) == 0)
 					continue;
 				if (i == PK_FILTER_ENUM_INSTALLED && !(it->isSystem ()))
