@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _ZYPP_UTILS_H_
@@ -173,7 +173,12 @@ std::set<zypp::PoolItem> * zypp_get_updates (std::string repo);
 /**
   * Returns a set of all patches the could be installed
   */
-std::set<zypp::PoolItem> * zypp_get_patches (PkRestartEnum restart = PK_RESTART_ENUM_NONE);
+std::set<zypp::PoolItem> * zypp_get_patches ();
+
+/**
+  * Sets the restart flag of a patch
+  */
+gboolean zypp_get_restart (PkRestartEnum &restart, zypp::Patch::constPtr patch);
 
 /**
   * perform changes in pool to the system
