@@ -17,18 +17,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
 
-#include <glib/gi18n-lib.h>
+#include <stdlib.h>
 #include <string.h>
+#include <math.h>
+
+#include <glib/gi18n-lib.h>
 #include <gio/gdesktopappinfo.h>
 #include <pango/pangocairo.h>
 #include <dbus/dbus-glib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+#include <math.h>
+#include <packagekit-glib2/packagekit.h>
 
 #include "pk-main.h"
 #include "pk-plugin-install.h"
@@ -55,9 +60,12 @@ struct PkPluginInstallPrivate
 	gchar			*display_name;
 	gchar			**package_names;
 	PangoLayout		*pango_layout;
-	PkClientPool		*client_pool;
+	PkClient		*client;
 	DBusGProxy		*install_package_proxy;
 	DBusGProxyCall		*install_package_call;
+	gint			timeout;
+	gint			current;
+	gint			update_spinner;
 };
 
 G_DEFINE_TYPE (PkPluginInstall, pk_plugin_install, PK_TYPE_PLUGIN)
@@ -85,6 +93,24 @@ pk_plugin_install_refresh (PkPluginInstall *self)
 	pk_plugin_request_refresh (PK_PLUGIN (self));
 }
 
+#define SPINNER_LINES 12
+#define SPINNER_SIZE 24
+
+static gboolean
+spinner_timeout (gpointer data)
+{
+	PkPluginInstall *self = data;
+
+	self->priv->current++;
+	if (self->priv->current >= SPINNER_LINES)
+		self->priv->current = 0;
+	self->priv->update_spinner = TRUE;
+
+	pk_plugin_install_refresh (self);
+
+	return TRUE;
+}
+
 /**
  * pk_plugin_install_set_status:
  **/
@@ -94,7 +120,16 @@ pk_plugin_install_set_status (PkPluginInstall *self, PkPluginInstallPackageStatu
 	if (self->priv->status != status) {
 		pk_debug ("setting status %u", status);
 		self->priv->status = status;
+
+		if (status == INSTALLING) {
+			self->priv->timeout = g_timeout_add (80, spinner_timeout, self);
+		}
+		else if (self->priv->timeout) {
+			g_source_remove (self->priv->timeout);
+			self->priv->timeout = 0;
+		}
 	}
+
 }
 
 /**
@@ -196,44 +231,89 @@ out:
 }
 
 /**
- * pk_plugin_install_package_cb:
+ * pk_plugin_install_finished_cb:
  **/
 static void
-pk_plugin_install_package_cb (PkClient *client, const PkPackageObj *obj, PkPluginInstall *self)
+pk_plugin_install_finished_cb (GObject *object, GAsyncResult *res, PkPluginInstall *self)
 {
+	PkClient *client = PK_CLIENT (object);
+	GError *error = NULL;
+	PkResults *results = NULL;
+	GPtrArray *packages = NULL;
+	PkPackage *item;
 	gchar *filename;
+	gchar **split = NULL;
+	PkError *error_code = NULL;
+	PkInfoEnum info;
+	gchar *package_id = NULL;
+	gchar *summary = NULL;
+
+	/* get the results */
+	results = pk_client_generic_finish (client, res, &error);
+	if (results == NULL) {
+		g_warning ("failed to resolve: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* check error code */
+	error_code = pk_results_get_error_code (results);
+	if (error_code != NULL) {
+		g_warning ("failed to install: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		goto out;
+	}
+
+	/* get packages */
+	packages = pk_results_get_package_array (results);
+	if (packages->len == 0)
+		goto out;
+
+	/* no results */
+	if (packages->len > 1)
+		g_warning ("more than one result (%i), just choosing first", packages->len);
+
+	/* choose first package */
+	item = g_ptr_array_index (packages, 0);
+	g_object_get (item,
+		      "info", &info,
+		      "package-id", &package_id,
+		      "summary", &summary,
+		      NULL);
 
 	/* if we didn't use displayname, use the summary */
 	if (self->priv->display_name == NULL)
-		self->priv->display_name = g_strdup (obj->summary);
+		self->priv->display_name = g_strdup (summary);
 
 	/* parse the data */
-	if (obj->info == PK_INFO_ENUM_AVAILABLE) {
+	if (info == PK_INFO_ENUM_AVAILABLE) {
 		if (self->priv->status == IN_PROGRESS)
 			pk_plugin_install_set_status (self, AVAILABLE);
 		else if (self->priv->status == INSTALLED)
 			pk_plugin_install_set_status (self, UPGRADABLE);
-		pk_plugin_install_set_available_version (self, obj->id->version);
-		pk_plugin_install_set_available_package_name (self, obj->id->name);
-
+		split = pk_package_id_split (package_id);
+		pk_plugin_install_set_available_package_name (self, split[0]);
+		pk_plugin_install_set_available_version (self, split[1]);
+		g_strfreev (split);
 #if 0
 		/* if we have data from the repo, override the user:
 		 *  * we don't want the remote site pretending to install another package
 		 *  * it might be localised if the backend supports it */
-		if (obj->summary != NULL && obj->summary[0] != '\0')
-			self->priv->display_name = g_strdup (obj->summary);
+		if (summary != NULL && summary[0] != '\0')
+			self->priv->display_name = g_strdup (summary);
 #endif
 
 		pk_plugin_install_clear_layout (self);
 		pk_plugin_install_refresh (self);
 
-	} else if (obj->info == PK_INFO_ENUM_INSTALLED) {
+	} else if (info == PK_INFO_ENUM_INSTALLED) {
 		if (self->priv->status == IN_PROGRESS)
 			pk_plugin_install_set_status (self, INSTALLED);
 		else if (self->priv->status == AVAILABLE)
 			pk_plugin_install_set_status (self, UPGRADABLE);
-		pk_plugin_install_set_installed_version (self, obj->id->version);
-		pk_plugin_install_set_installed_package_name (self, obj->id->name);
+		split = pk_package_id_split (package_id);
+		pk_plugin_install_set_installed_package_name (self, split[0]);
+		pk_plugin_install_set_installed_version (self, split[1]);
+		g_strfreev (split);
 
 		/* get desktop file information */
 		filename = pk_plugin_install_get_best_desktop_file (self);
@@ -252,34 +332,22 @@ pk_plugin_install_package_cb (PkClient *client, const PkPackageObj *obj, PkPlugi
 		pk_plugin_install_clear_layout (self);
 		pk_plugin_install_refresh (self);
 	}
-}
-
-/**
- * pk_plugin_install_error_code_cb:
- **/
-static void
-pk_plugin_install_error_code_cb (PkClient *client, PkErrorCodeEnum code, const gchar *details, PkPluginInstall *self)
-{
-	pk_warning ("Error getting data from PackageKit: %s\n", details);
+out:
+	g_free (package_id);
+	g_free (summary);
 
+	/* we didn't get any results, or we failed */
 	if (self->priv->status == IN_PROGRESS) {
 		pk_plugin_install_set_status (self, UNAVAILABLE);
 		pk_plugin_install_clear_layout (self);
 		pk_plugin_install_refresh (self);
 	}
-}
-
-/**
- * pk_plugin_install_finished_cb:
- **/
-static void
-pk_plugin_install_finished_cb (PkClient *client, PkExitEnum exit, guint runtime, PkPluginInstall *self)
-{
-	if (self->priv->status == IN_PROGRESS) {
-		pk_plugin_install_set_status (self, UNAVAILABLE);
-		pk_plugin_install_clear_layout (self);
-		pk_plugin_install_refresh (self);
-	}
+	if (error_code != NULL)
+		g_object_unref (error_code);
+	if (packages != NULL)
+		g_ptr_array_unref (packages);
+	if (results != NULL)
+		g_object_unref (results);
 }
 
 /**
@@ -288,12 +356,9 @@ pk_plugin_install_finished_cb (PkClient *client, PkExitEnum exit, guint runtime,
 static void
 pk_plugin_install_recheck (PkPluginInstall *self)
 {
-	guint i;
+//	guint i;
 	const gchar *data;
-	gchar **package_ids;
-	GError *error = NULL;
-	PkClient *client;
-	gboolean ret;
+//	gchar **package_ids;
 
 	self->priv->status = IN_PROGRESS;
 	pk_plugin_install_set_available_version (self, NULL);
@@ -309,26 +374,23 @@ pk_plugin_install_recheck (PkPluginInstall *self)
 		self->priv->package_names = g_strsplit (data, " ", -1);
 	}
 
+#if 0
 	for (i=0; self->priv->package_names[i] != NULL; i++) {
 		package_ids = pk_package_ids_from_id (self->priv->package_names[i]);
-		client = pk_client_pool_create (self->priv->client_pool);
 
 		/* do async resolve */
-		ret = pk_client_resolve (client, PK_FILTER_ENUM_NONE, package_ids, &error);
-		if (!ret) {
-			pk_warning ("%s", error->message);
-			g_clear_error (&error);
-			pk_client_pool_remove (self->priv->client_pool, client);
-		}
-		g_strfreev (package_ids);
-		g_object_unref (client);
-	}
+		pk_client_resolve_async (self->priv->client, pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST, -1), package_ids, NULL,
+					 (PkProgressCallback) pk_plugin_install_progress_cb, self,
+					 (GAsyncReadyCallback) pk_plugin_install_finished_cb, self);
 
-	if (pk_client_pool_get_size (self->priv->client_pool) == 0 && self->priv->status == IN_PROGRESS) {
-		pk_plugin_install_set_status (self, UNAVAILABLE);
-		pk_plugin_install_clear_layout (self);
-		pk_plugin_install_refresh (self);
+		g_strfreev (package_ids);
 	}
+#endif
+
+	/* do async resolve */
+	pk_client_resolve_async (self->priv->client, pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST, -1),
+				 self->priv->package_names, NULL, NULL, NULL,
+				 (GAsyncReadyCallback) pk_plugin_install_finished_cb, self);
 }
 
 /**
@@ -535,6 +597,83 @@ pk_plugin_install_start (PkPlugin *plugin)
 	return TRUE;
 }
 
+/**
+ * pk_plugin_install_draw_spinner:
+ **/
+static void
+pk_plugin_install_draw_spinner (PkPlugin *plugin, cairo_t *cr, int cx, int cy)
+{
+	gint width, height;
+	double x, y;
+	double radius;
+	double half;
+	gint i;
+
+	PkPluginInstall *self = PK_PLUGIN_INSTALL (plugin);
+
+        cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
+
+	width = height = SPINNER_SIZE;
+	radius = MIN (width / 2.0, height / 2.0);
+	half = SPINNER_LINES / 2;
+
+	x = cx + width / 2;
+	y = cy + height / 2;
+
+	for (i = 0; i < SPINNER_LINES; i++) {
+		gint inset = 0.7 * radius;
+		/* transparency is a function of time and intial value */
+		gdouble t = (gdouble) ((i + SPINNER_LINES - self->priv->current) % SPINNER_LINES) / SPINNER_LINES;
+		cairo_save (cr);
+
+		cairo_set_source_rgba (cr, 0, 0, 0, t);
+		cairo_set_line_width (cr, 2.0);
+		cairo_move_to (cr,
+			       x + (radius - inset) * cos (i * G_PI / half),
+			       y + (radius - inset) * sin (i * G_PI / half));
+		cairo_line_to (cr,
+			       x + radius * cos (i * G_PI / half),
+			       y + radius * sin (i * G_PI / half));
+		cairo_stroke (cr);
+		cairo_restore (cr);
+	}
+}
+
+/**
+ * pk_plugin_install_rounded_rectangle:
+ **/
+static void
+pk_plugin_install_rounded_rectangle (cairo_t *cr, gdouble x, gdouble y,
+				     gdouble w, gdouble h, gdouble radius)
+{
+	const gdouble ARC_TO_BEZIER = 0.55228475;
+	gdouble c;
+
+	if (radius == 0) {
+		cairo_rectangle (cr, x, y, w, h);
+		return;
+	}
+
+	if (radius > w - radius)
+		radius = w / 2;
+	if (radius > h - radius)
+		radius = h / 2;
+
+	c = ARC_TO_BEZIER * radius;
+
+	cairo_new_path (cr);
+	cairo_move_to (cr, x + radius, y);
+	cairo_rel_line_to (cr, w - 2 * radius, 0);
+	cairo_rel_curve_to (cr, c, 0, radius, c, radius, radius);
+	cairo_rel_line_to (cr, 0, h - 2 * radius);
+	cairo_rel_curve_to (cr, 0, c, c - radius, radius, -radius, radius);
+	cairo_rel_line_to (cr, -w + 2 * radius, 0);
+	cairo_rel_curve_to (cr, -c, 0, -radius, -c, -radius, -radius);
+	cairo_rel_line_to (cr, 0, -h + 2 * radius);
+	cairo_rel_curve_to (cr, 0, -c, radius - c, -radius, radius, -radius);
+	cairo_close_path (cr);
+}
+
 /**
  * pk_plugin_install_draw:
  **/
@@ -547,10 +686,16 @@ pk_plugin_install_draw (PkPlugin *plugin, cairo_t *cr)
 	guint y;
 	guint width;
 	guint height;
+	guint radius;
 	const gchar *filename;
 	GtkIconTheme *theme;
 	GdkPixbuf *pixbuf;
+	PangoRectangle rect;
 	PkPluginInstall *self = PK_PLUGIN_INSTALL (plugin);
+	guint sep;
+	const gchar *data;
+	PangoColor color;
+	gboolean has_color;
 
 	/* get parameters */
 	g_object_get (self,
@@ -560,19 +705,43 @@ pk_plugin_install_draw (PkPlugin *plugin, cairo_t *cr)
 		      "height", &height,
 		      NULL);
 
+	data = pk_plugin_get_data (plugin, "radius");
+	if (data)
+		radius = atoi (data);
+	else
+		radius = 0;
+
+	data = pk_plugin_get_data (plugin, "color");
+	if (data)
+		has_color = pango_color_parse (&color, data);
+	else
+		has_color = FALSE;
+
+	sep = MAX ((height - 48) / 2, radius);
+
 	pk_debug ("drawing on %ux%u (%ux%u)", x, y, width, height);
 
 	/* get properties */
 	pk_plugin_install_get_style (&font_desc, &foreground, &background, &link);
+	if (self->priv->update_spinner) {
+		self->priv->update_spinner = FALSE;
+		goto update_spinner;
+	}
 
-       /* fill background */
+        /* fill background */
 	pk_plugin_install_set_source_from_rgba (cr, background);
 	cairo_rectangle (cr, x, y, width, height);
 	cairo_fill (cr);
+	if (has_color)
+		cairo_set_source_rgb (cr, color.red / 65536.0, color.green / 65536.0, color.blue / 65536.0);
+	else
+		pk_plugin_install_set_source_from_rgba (cr, background);
+	pk_plugin_install_rounded_rectangle (cr, x + 0.5, y + 0.5, width - 1, height - 1, radius);
+	cairo_fill (cr);
 
         /* grey outline */
 	cairo_set_source_rgb (cr, 0.5, 0.5, 0.5);
-	cairo_rectangle (cr, x + 0.5, y + 0.5, width - 1, height - 1);
+	pk_plugin_install_rounded_rectangle (cr, x + 0.5, y + 0.5, width - 1, height - 1, radius);
 	cairo_set_line_width (cr, 1);
 	cairo_stroke (cr);
 
@@ -584,17 +753,39 @@ pk_plugin_install_draw (PkPlugin *plugin, cairo_t *cr)
 	pixbuf = gtk_icon_theme_load_icon (theme, filename, 48, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
 	if (pixbuf == NULL)
 		goto skip;
-	gdk_cairo_set_source_pixbuf (cr, pixbuf, x + PK_PLUGIN_INSTALL_MARGIN, y + PK_PLUGIN_INSTALL_MARGIN);
-	cairo_rectangle (cr, x + PK_PLUGIN_INSTALL_MARGIN, y + PK_PLUGIN_INSTALL_MARGIN, 48, 48);
+
+	gdk_cairo_set_source_pixbuf (cr, pixbuf, x + sep, y + (height - 48) / 2);
+	cairo_rectangle (cr, x + sep, y + (height - 48) / 2, 48, 48);
 	cairo_fill (cr);
 	g_object_unref (pixbuf);
 
 skip:
 	/* write text */
 	pk_plugin_install_ensure_layout (self, cr, font_desc, link);
-	cairo_move_to (cr, (x + PK_PLUGIN_INSTALL_MARGIN*2) + 48, y + PK_PLUGIN_INSTALL_MARGIN + PK_PLUGIN_INSTALL_MARGIN);
+	pango_layout_get_pixel_extents (self->priv->pango_layout, &rect, NULL);
+	cairo_move_to (cr, x + sep + 48 + sep, y + (height - (rect.height + 48) / 2) / 2);
 	pk_plugin_install_set_source_from_rgba (cr, foreground);
 	pango_cairo_show_layout (cr, self->priv->pango_layout);
+
+update_spinner:
+	if (self->priv->status == INSTALLING) {
+		pango_layout_get_pixel_extents (self->priv->pango_layout, &rect, NULL);
+		if (has_color)
+			cairo_set_source_rgb (cr, color.red / 65536.0, color.green / 65536.0, color.blue / 65536.0);
+		else
+			pk_plugin_install_set_source_from_rgba (cr, background);
+		cairo_rectangle (cr,
+				 x + sep + 48 + sep + rect.width + 2 * sep,
+				 y + (height - SPINNER_SIZE) / 2,
+				 SPINNER_SIZE, SPINNER_SIZE);
+		cairo_fill (cr);
+		pk_plugin_install_set_source_from_rgba (cr, foreground);
+
+		pk_plugin_install_draw_spinner (plugin, cr,
+						x + sep + 48 + sep + rect.width + 2 * sep,
+						y + (height - SPINNER_SIZE) / 2);
+	}
+
 	return TRUE;
 }
 
@@ -653,14 +844,27 @@ pk_plugin_install_get_link_index (PkPluginInstall *self, gint x, gint y)
 	gint seen_links = 0;
 	gboolean in_link = FALSE;
 	gint result = -1;
+	guint height;
+	guint radius;
+	guint sep;
+	PangoRectangle rect;
+	const char *data;
 
 	/* Coordinates are relative to origin of plugin (different from drawing) */
 
 	if (!self->priv->pango_layout)
 		return -1;
 
-	x -= (PK_PLUGIN_INSTALL_MARGIN * 2) + 48;
-	y -= (PK_PLUGIN_INSTALL_MARGIN * 2);
+	g_object_get (self, "height", &height, NULL);
+	data = pk_plugin_get_data (PK_PLUGIN (self), "radius");
+	if (data)
+		radius = atoi (data);
+	else
+		radius = 0;
+	sep = MAX ((height - 48) / 2, radius);
+	pango_layout_get_pixel_extents (self->priv->pango_layout, &rect, NULL);
+	x -= sep + 48 + sep;
+	y -= (height - (rect.height + 48) / 2) / 2;
 
 	if (!pango_layout_xy_to_index (self->priv->pango_layout, x * PANGO_SCALE, y * PANGO_SCALE, &idx, &trailing))
 		return - 1;
@@ -777,7 +981,7 @@ pk_plugin_install_install_package (PkPluginInstall *self, Time event_time)
 						      24 * 60 * 1000 * 1000, /* one day */
 						      G_TYPE_UINT, xid, /* xid */
 						      G_TYPE_STRV, packages,
-						      G_TYPE_STRING, "hide-finished",
+						      G_TYPE_STRING, "hide-confirm-search,hide-progress,hide-confirm-deps,hide-finished",
 						      G_TYPE_INVALID,
 						      G_TYPE_INVALID);
 	g_strfreev (packages);
@@ -867,6 +1071,52 @@ pk_plugin_install_button_release (PkPlugin *plugin, gint x, gint y, Time event_t
 	return TRUE;
 }
 
+static void
+pk_plugin_set_cursor (GdkWindow     *window,
+                      GdkCursorType  cursor)
+{
+	Display *display;
+	Cursor xcursor;
+
+	display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default());
+        if (cursor >= 0)
+		xcursor = XCreateFontCursor (display, cursor);
+	else
+		xcursor = None;
+	XDefineCursor (display, GDK_WINDOW_XID (window), xcursor);
+}
+
+static gboolean
+pk_plugin_install_motion (PkPlugin *plugin,
+                          gint      x,
+                          gint      y)
+{
+	PkPluginInstall *self = PK_PLUGIN_INSTALL (plugin);
+	GdkWindow *window;
+	gint idx;
+
+	idx = pk_plugin_install_get_link_index (self, x, y);
+        g_object_get (plugin, "gdk-window", &window, NULL);
+
+	if (idx < 0) {
+		pk_plugin_set_cursor (window, -1);
+		return FALSE;
+	}
+	switch (self->priv->status) {
+	case IN_PROGRESS:
+	case INSTALLING:
+	case UNAVAILABLE:
+		pk_plugin_set_cursor (window, -1);
+		break;
+	case INSTALLED:
+	case UPGRADABLE:
+	case AVAILABLE:
+		pk_plugin_set_cursor (window, GDK_HAND2);
+		break;
+	}
+	return FALSE;
+}
+
 /**
  * pk_plugin_install_finalize:
  **/
@@ -888,7 +1138,7 @@ pk_plugin_install_finalize (GObject *object)
 	}
 
 	/* remove clients */
-	g_object_unref (self->priv->client_pool);
+	g_object_unref (self->priv->client);
 
 	G_OBJECT_CLASS (pk_plugin_install_parent_class)->finalize (object);
 }
@@ -906,6 +1156,7 @@ pk_plugin_install_class_init (PkPluginInstallClass *klass)
 	plugin_class->start = pk_plugin_install_start;
 	plugin_class->draw = pk_plugin_install_draw;
 	plugin_class->button_release = pk_plugin_install_button_release;
+	plugin_class->motion = pk_plugin_install_motion;
 
 	g_type_class_add_private (klass, sizeof (PkPluginInstallPrivate));
 }
@@ -929,12 +1180,7 @@ pk_plugin_install_init (PkPluginInstall *self)
 	self->priv->pango_layout = NULL;
 	self->priv->install_package_proxy = NULL;
 	self->priv->install_package_call = NULL;
-
-	/* use a client pool to do everything async */
-	self->priv->client_pool = pk_client_pool_new ();
-	pk_client_pool_connect (self->priv->client_pool, "package", G_CALLBACK (pk_plugin_install_package_cb), G_OBJECT (self));
-	pk_client_pool_connect (self->priv->client_pool, "error-code", G_CALLBACK (pk_plugin_install_error_code_cb), G_OBJECT (self));
-	pk_client_pool_connect (self->priv->client_pool, "finished", G_CALLBACK (pk_plugin_install_finished_cb), G_OBJECT (self));
+	self->priv->client = pk_client_new ();
 }
 
 /**
