@@ -16,22 +16,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
 
 #include <string.h>
+#include <stdlib.h>
 #include <locale.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <signal.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
+#include <packagekit-glib2/packagekit-private.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
 
-#include "pk-tools-common.h"
-
 #define PK_MAX_PATH_LEN 1023
 
 typedef enum {
@@ -48,8 +51,15 @@ typedef struct {
 	PkCnfPolicy	 single_install;
 	PkCnfPolicy	 multiple_install;
 	gboolean	 software_source_search;
+	gchar		**locations;
 } PkCnfPolicyConfig;
 
+static PkTask *task = NULL;
+static GCancellable *cancellable = NULL;
+
+/* bash reserved code */
+#define EXIT_COMMAND_NOT_FOUND	127
+
 /**
  * pk_cnf_find_alternatives_swizzle:
  *
@@ -267,8 +277,8 @@ pk_cnf_find_alternatives (const gchar *cmd, guint len)
 	gchar buffer_sbin[PK_MAX_PATH_LEN+1];
 	gboolean ret;
 
-	array = g_ptr_array_new ();
-	possible = g_ptr_array_new ();
+	array = g_ptr_array_new_with_free_func (g_free);
+	possible = g_ptr_array_new_with_free_func (g_free);
 	unique = g_ptr_array_new ();
 	pk_cnf_find_alternatives_swizzle (cmd, len, possible);
 	pk_cnf_find_alternatives_replace (cmd, len, possible);
@@ -323,83 +333,122 @@ pk_cnf_find_alternatives (const gchar *cmd, guint len)
 			g_ptr_array_add (array, g_strdup (cmdt));
 	}
 
-	g_ptr_array_foreach (possible, (GFunc) g_free, NULL);
-	g_ptr_array_free (possible, TRUE);
+	g_ptr_array_unref (possible);
 	g_ptr_array_free (unique, TRUE);
 	return array;
 }
 
+/**
+ * pk_cnf_progress_cb:
+ **/
+static void
+pk_cnf_progress_cb (PkProgress *progress, PkProgressType type, gpointer data)
+{
+	PkStatusEnum status;
+	const gchar *text = NULL;
+
+	/* status */
+	if (type != PK_PROGRESS_TYPE_STATUS)
+		return;
+
+	g_object_get (progress,
+		      "status", &status,
+		      NULL);
+
+	switch (status) {
+	case PK_STATUS_ENUM_SETUP:
+	case PK_STATUS_ENUM_FINISHED:
+	case PK_STATUS_ENUM_QUERY:
+		break;
+	case PK_STATUS_ENUM_DOWNLOAD_REPOSITORY:
+		/* TRANSLATORS: downloading repo data so we can search */
+		text = _("Downloading details about the software sources.");
+		break;
+	case PK_STATUS_ENUM_DOWNLOAD_FILELIST:
+		/* TRANSLATORS: downloading file lists so we can search */
+		text = _("Downloading filelists (this may take some time to complete).");
+		break;
+	case PK_STATUS_ENUM_WAITING_FOR_LOCK:
+		/* TRANSLATORS: waiting for native lock */
+		text = _("Waiting for package manager lock.");
+		break;
+	case PK_STATUS_ENUM_LOADING_CACHE:
+		/* TRANSLATORS: loading package cache so we can search */
+		text = _("Loading list of packages.");
+		break;
+	default:
+		/* fallback to default */
+		text = pk_status_enum_to_localised_text (status);
+	}
+
+	/* print to screen, still one line */
+	if (text != NULL)
+		g_print ("\n * %s.. ", text);
+}
+
 /**
  * pk_cnf_find_available:
  *
  * Find software we could install
  **/
-static GPtrArray *
+static gchar **
 pk_cnf_find_available (const gchar *cmd)
 {
-	PkClient *client;
-	PkControl *control;
+	PkPackage *item;
+	gchar **package_ids = NULL;
+	const gchar *prefixes[] = {"/usr/bin", "/usr/sbin", "/bin", "/sbin", NULL};
+	gchar **values = NULL;
 	GError *error = NULL;
-	PkBitfield roles;
+	GPtrArray *array = NULL;
+	guint i;
+	guint len;
 	PkBitfield filters;
-	gboolean ret;
-	GPtrArray *array;
-	guint i, len;
-	PkPackageList *list = NULL;
-	const PkPackageObj *obj;
-	gchar *path = NULL;
+	PkResults *results = NULL;
+	PkError *error_code = NULL;
 
-	control = pk_control_new ();
-	client = pk_client_new ();
-	pk_client_set_synchronous (client, TRUE, NULL);
-	pk_client_set_use_buffer (client, TRUE, NULL);
-	roles = pk_control_get_actions (control, NULL);
-	array = g_ptr_array_new ();
-
-	/* can we search the repos */
-	if (!pk_bitfield_contain (roles, PK_ROLE_ENUM_SEARCH_FILE)) {
-		egg_warning ("cannot search file");
-		goto out;
-	}
+	/* create new array of full paths */
+	len = g_strv_length ((gchar **)prefixes);
+	values = g_new0 (gchar *, len + 1);
+	for (i=0; prefixes[i] != NULL; i++)
+		values[i] = g_build_filename (prefixes[i], cmd, NULL);
 
 	/* do search */
-	path = g_strdup_printf ("/usr/bin/%s", cmd);
-	egg_debug ("searching for %s", path);
-	filters = pk_bitfield_from_enums (PK_FILTER_ENUM_NOT_INSTALLED, PK_FILTER_ENUM_NEWEST, -1);
-	ret = pk_client_search_file (client, filters, path, &error);
-	if (!ret) {
+	filters = pk_bitfield_from_enums (PK_FILTER_ENUM_NOT_INSTALLED,
+					  PK_FILTER_ENUM_NEWEST,
+					  PK_FILTER_ENUM_ARCH, -1);
+	results = pk_client_search_files (PK_CLIENT(task), filters, values, cancellable,
+					 (PkProgressCallback) pk_cnf_progress_cb, NULL, &error);
+	if (results == NULL) {
 		/* TRANSLATORS: we failed to find the package, this shouldn't happen */
-		egg_warning ("%s: %s", _("Failed to search for file"), error->message);
+		g_printerr ("%s: %s\n", _("Failed to search for file"), error->message);
 		g_error_free (error);
 		goto out;
 	}
 
-	/* get package list */
-	list = pk_client_get_package_list (client);
-	if (list == NULL) {
-		egg_warning ("failed to get list");
+	/* check error code */
+	error_code = pk_results_get_error_code (results);
+	if (error_code != NULL) {
+		/* TRANSLATORS: the transaction failed in a way we could not expect */
+		g_printerr ("%s: %s, %s\n", _("The transaction failed"), pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
-	/* nothing found */
-	len = PK_OBJ_LIST(list)->len;
-	if (len == 0)
-		goto out;
-
-	/* add all package names */
-	for (i=0; i<len; i++) {
-		obj = pk_package_list_get_obj (list, i);
-		g_ptr_array_add (array, g_strdup (obj->id->name));
-		egg_warning ("obj->id->name=%s", obj->id->name);
+	/* get the packages returned */
+	array = pk_results_get_package_array (results);
+	package_ids = g_new0 (gchar *, array->len+1);
+	for (i=0; i<array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		package_ids[i] = g_strdup (pk_package_get_id (item));
 	}
 out:
-	if (list != NULL)
-		g_object_unref (list);
-	g_object_unref (control);
-	g_object_unref (client);
-	g_free (path);
-
-	return array;
+	if (error_code != NULL)
+		g_object_unref (error_code);
+	if (results != NULL)
+		g_object_unref (results);
+	if (array != NULL)
+		g_ptr_array_unref (array);
+	g_strfreev (values);
+	return package_ids;
 }
 
 /**
@@ -445,13 +494,17 @@ pk_cnf_get_policy_from_file (GKeyFile *file, const gchar *key)
 /**
  * pk_cnf_get_config:
  **/
-static gboolean
-pk_cnf_get_config (PkCnfPolicyConfig *config)
+static PkCnfPolicyConfig *
+pk_cnf_get_config (void)
 {
 	GKeyFile *file;
 	gchar *path;
 	gboolean ret;
 	GError *error = NULL;
+	PkCnfPolicyConfig *config;
+
+	/* create */
+	config = g_new0 (PkCnfPolicyConfig, 1);
 
 	/* set defaults if the conf file is not found */
 	config->single_match = PK_CNF_POLICY_UNKNOWN;
@@ -459,6 +512,7 @@ pk_cnf_get_config (PkCnfPolicyConfig *config)
 	config->single_install = PK_CNF_POLICY_UNKNOWN;
 	config->multiple_install = PK_CNF_POLICY_UNKNOWN;
 	config->software_source_search = FALSE;
+	config->locations = NULL;
 
 	/* load file */
 	file = g_key_file_new ();
@@ -476,29 +530,109 @@ pk_cnf_get_config (PkCnfPolicyConfig *config)
 	config->single_install = pk_cnf_get_policy_from_file (file, "SingleInstall");
 	config->multiple_install = pk_cnf_get_policy_from_file (file, "MultipleInstall");
 	config->software_source_search = g_key_file_get_boolean (file, "CommandNotFound", "SoftwareSourceSearch", NULL);
+	config->locations = g_key_file_get_string_list (file, "CommandNotFound", "SearchLocations", NULL, NULL);
+
+	/* fallback */
+	if (config->locations == NULL) {
+		egg_warning ("not found SearchLocations, using fallback");
+		config->locations = g_strsplit ("/usr/bin;/usr/sbin", ";", -1);
+	}
 out:
 	g_free (path);
 	g_key_file_free (file);
-	return ret;
+	return config;
 }
 
 /**
  * pk_cnf_spawn_command:
  **/
-static gboolean
-pk_cnf_spawn_command (const gchar *exec)
+static gint
+pk_cnf_spawn_command (const gchar *exec, gchar **arguments)
 {
 	gboolean ret;
+	gint exit_status;
+	gchar *cmd;
+	gchar *args;
 	GError *error = NULL;
-	ret = g_spawn_command_line_sync (exec, NULL, NULL, NULL, &error);
+
+	/* ensure program starts on a fresh line */
+	g_print ("\n");
+
+	args = g_strjoinv (" ", arguments);
+	cmd = g_strjoin (" ", exec, args, NULL);
+	ret = g_spawn_command_line_sync (cmd, NULL, NULL, &exit_status, &error);
 	if (!ret) {
 		/* TRANSLATORS: we failed to launch the executable, the error follows */
-		g_print ("%s '%s': %s", _("Failed to launch:"), exec, error->message);
+		g_printerr ("%s '%s': %s\n", _("Failed to launch:"), cmd, error->message);
 		g_error_free (error);
+		goto out;
 	}
+out:
+	g_free (args);
+	g_free (cmd);
 	return ret;
 }
 
+/**
+ * pk_cnf_install_package_id:
+ **/
+static gboolean
+pk_cnf_install_package_id (const gchar *package_id)
+{
+	GError *error = NULL;
+	PkResults *results = NULL;
+	gchar **package_ids;
+	gboolean ret = FALSE;
+	PkError *error_code = NULL;
+
+	/* do install */
+	package_ids = pk_package_ids_from_id (package_id);
+	results = pk_task_install_packages_sync (task, package_ids, cancellable,
+						 (PkProgressCallback) pk_cnf_progress_cb, NULL, &error);
+	if (results == NULL) {
+		/* TRANSLATORS: we failed to install the package */
+		g_printerr ("%s: %s\n", _("Failed to install packages"), error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* check error code */
+	error_code = pk_results_get_error_code (results);
+	if (error_code != NULL) {
+		/* TRANSLATORS: the transaction failed in a way we could not expect */
+		g_printerr ("%s: %s, %s\n", _("The transaction failed"), pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		goto out;
+	}
+
+	ret = TRUE;
+out:
+	if (error_code != NULL)
+		g_object_unref (error_code);
+	if (results != NULL)
+		g_object_unref (results);
+	g_strfreev (package_ids);
+	return ret;
+}
+
+/**
+ * pk_cnf_sigint_handler:
+ **/
+static void
+pk_cnf_sigint_handler (int sig)
+{
+	egg_debug ("Handling SIGINT");
+
+	/* restore default ASAP, as the cancel might hang */
+	signal (SIGINT, SIG_DFL);
+
+	/* hopefully, cancel client */
+	g_cancellable_cancel (cancellable);
+
+	/* kill ourselves */
+	egg_debug ("Retrying SIGINT");
+	kill (getpid (), SIGINT);
+}
+
 /**
  * main:
  **/
@@ -506,19 +640,18 @@ int
 main (int argc, char *argv[])
 {
 	gboolean ret;
-	gboolean verbose = FALSE;
 	GOptionContext *context;
 	GPtrArray *array = NULL;
-	GPtrArray *available = NULL;
-	PkCnfPolicyConfig config;
+	gchar **package_ids = NULL;
+	PkCnfPolicyConfig *config = NULL;
 	guint i;
 	guint len;
 	gchar *text;
 	const gchar *possible;
+	gchar **parts;
+	guint retval = EXIT_SUCCESS;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-		  _("Show extra debugging information"), NULL },
 		{ NULL}
 	};
 
@@ -536,68 +669,77 @@ main (int argc, char *argv[])
 	/* TRANSLATORS: tool that gets called when the command is not found */
 	g_option_context_set_summary (context, _("PackageKit Command Not Found"));
 	g_option_context_add_main_entries (context, options, NULL);
+	g_option_context_add_group (context, egg_debug_get_option_group ());
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
-	egg_debug_init (verbose);
-
 	/* no input */
 	if (argv[1] == NULL)
 		goto out;
 
+	/* do stuff on ctrl-c */
+	signal (SIGINT, pk_cnf_sigint_handler);
+
 	/* get policy config */
-	pk_cnf_get_config (&config);
+	config = pk_cnf_get_config ();
+	task = PK_TASK(pk_task_text_new ());
+	cancellable = g_cancellable_new ();
 
 	/* get length */
 	len = egg_strlen (argv[1], 1024);
-	if (len < 1)
+	if (len < 1) {
+		retval = EXIT_COMMAND_NOT_FOUND;
 		goto out;
+	}
 
 	/* generate swizzles */
 	array = pk_cnf_find_alternatives (argv[1], len);
 
 	/* TRANSLATORS: the prefix of all the output telling the user why it's not executing */
-	g_print ("%s ", _("Command not found."));
+	g_printerr ("%s ", _("Command not found."));
 
 	/* one exact possibility */
 	if (array->len == 1) {
 		possible = g_ptr_array_index (array, 0);
-		if (config.single_match == PK_CNF_POLICY_WARN) {
+		if (config->single_match == PK_CNF_POLICY_WARN) {
 			/* TRANSLATORS: tell the user what we think the command is */
-			g_print ("%s '%s'\n", _("Similar command is:"), possible);
+			g_printerr ("%s '%s'\n", _("Similar command is:"), possible);
+			retval = EXIT_COMMAND_NOT_FOUND;
 
 		/* run */
-		} else if (config.single_match == PK_CNF_POLICY_RUN) {
-			pk_cnf_spawn_command (possible);
+		} else if (config->single_match == PK_CNF_POLICY_RUN) {
+			retval = pk_cnf_spawn_command (possible, &argv[2]);
 
 		/* ask */
-		} else if (config.single_match == PK_CNF_POLICY_ASK) {
+		} else if (config->single_match == PK_CNF_POLICY_ASK) {
 			/* TRANSLATORS: Ask the user if we should run the similar command */
 			text = g_strdup_printf ("%s %s", _("Run similar command:"), possible);
 			ret = pk_console_get_prompt (text, TRUE);
 			if (ret)
-				pk_cnf_spawn_command (possible);
+				retval = pk_cnf_spawn_command (possible, &argv[2]);
+			else
+				retval = EXIT_COMMAND_NOT_FOUND;
 			g_free (text);
 		}
 		goto out;
 
 	/* multiple choice */
 	} else if (array->len > 1) {
-		if (config.multiple_match == PK_CNF_POLICY_WARN) {
+		if (config->multiple_match == PK_CNF_POLICY_WARN) {
 			/* TRANSLATORS: show the user a list of commands that they could have meant */
-			g_print ("%s:\n", _("Similar commands are:"));
+			g_printerr ("%s:\n", _("Similar commands are:"));
 			for (i=0; i<array->len; i++) {
 				possible = g_ptr_array_index (array, i);
-				g_print ("'%s'\n", possible);
+				g_printerr ("'%s'\n", possible);
 			}
 
 		/* ask */
-		} else if (config.multiple_match == PK_CNF_POLICY_ASK) {
+		} else if (config->multiple_match == PK_CNF_POLICY_ASK) {
 			/* TRANSLATORS: show the user a list of commands we could run */
-			g_print ("%s:\n", _("Similar commands are:"));
+			g_printerr ("%s:\n", _("Similar commands are:"));
 			for (i=0; i<array->len; i++) {
 				possible = g_ptr_array_index (array, i);
-				g_print ("%i\t'%s'\n", i+1, possible);
+				g_printerr ("%i\t'%s'\n", i+1, possible);
 			}
 
 			/* TRANSLATORS: ask the user to choose a file to run */
@@ -605,86 +747,96 @@ main (int argc, char *argv[])
 
 			/* run command */
 			possible = g_ptr_array_index (array, i);
-			pk_cnf_spawn_command (possible);
+			retval = pk_cnf_spawn_command (possible, &argv[2]);
 		}
 		goto out;
 
 	/* only search using PackageKit if configured to do so */
-	} else if (config.software_source_search) {
-		available = pk_cnf_find_available (argv[1]);
-		if (available->len == 1) {
-			possible = g_ptr_array_index (available, 0);
-			if (config.single_install == PK_CNF_POLICY_WARN) {
+	} else if (config->software_source_search) {
+		package_ids = pk_cnf_find_available (argv[1]);
+		if (package_ids == NULL)
+			goto out;
+		len = g_strv_length (package_ids);
+		if (len == 1) {
+			parts = pk_package_id_split (package_ids[0]);
+			if (config->single_install == PK_CNF_POLICY_WARN) {
 				/* TRANSLATORS: tell the user what package provides the command */
-				g_print ("%s '%s'\n", _("The package providing this file is:"), possible);
+				g_printerr ("%s '%s'\n", _("The package providing this file is:"), parts[PK_PACKAGE_ID_NAME]);
 
 			/* ask */
-			} else if (config.single_install == PK_CNF_POLICY_ASK) {
+			} else if (config->single_install == PK_CNF_POLICY_ASK) {
 				/* TRANSLATORS: as the user if we want to install a package to provide the command */
-				text = g_strdup_printf (_("Install package '%s' to provide command '%s'?"), possible, argv[1]);
+				text = g_strdup_printf (_("Install package '%s' to provide command '%s'?"), parts[PK_PACKAGE_ID_NAME], argv[1]);
 				ret = pk_console_get_prompt (text, FALSE);
 				g_free (text);
 				if (ret) {
-					text = g_strdup_printf ("pkcon install %s", possible);
-					ret = pk_cnf_spawn_command (text);
+					ret = pk_cnf_install_package_id (package_ids[0]);
 					if (ret)
-						pk_cnf_spawn_command (argv[1]);
-					g_free (text);
+						retval = pk_cnf_spawn_command (argv[1], &argv[2]);
+					else
+						retval = EXIT_COMMAND_NOT_FOUND;
 				}
 
 			/* install */
-			} else if (config.single_install == PK_CNF_POLICY_INSTALL) {
-				text = g_strdup_printf ("pkcon install %s", possible);
-				pk_cnf_spawn_command (text);
-				g_free (text);
+			} else if (config->single_install == PK_CNF_POLICY_INSTALL) {
+				ret = pk_cnf_install_package_id (package_ids[0]);
+				if (ret)
+					retval = pk_cnf_spawn_command (argv[1], &argv[2]);
+				else
+					retval = EXIT_COMMAND_NOT_FOUND;
 			}
+			g_strfreev (parts);
 			goto out;
-		} else if (available->len > 1) {
-			if (config.multiple_install == PK_CNF_POLICY_WARN) {
+		} else if (len > 1) {
+			if (config->multiple_install == PK_CNF_POLICY_WARN) {
 				/* TRANSLATORS: Show the user a list of packages that provide this command */
-				g_print ("%s:\n", _("Packages providing this file are:"));
-				for (i=0; i<available->len; i++) {
-					possible = g_ptr_array_index (available, i);
-					g_print ("'%s'\n", possible);
+				g_printerr ("%s\n", _("Packages providing this file are:"));
+				for (i=0; package_ids[i] != NULL; i++) {
+					parts = pk_package_id_split (package_ids[i]);
+					g_printerr ("'%s'\n", parts[PK_PACKAGE_ID_NAME]);
+					g_strfreev (parts);
 				}
 
 			/* ask */
-			} else if (config.multiple_install == PK_CNF_POLICY_ASK) {
+			} else if (config->multiple_install == PK_CNF_POLICY_ASK) {
 				/* TRANSLATORS: Show the user a list of packages that they can install to provide this command */
-				g_print ("%s:\n", _("Suitable packages are:"));
-				for (i=0; i<available->len; i++) {
-					possible = g_ptr_array_index (available, i);
-					g_print ("%i\t'%s'\n", i+1, possible);
+				g_printerr ("%s:\n", _("Suitable packages are:"));
+				for (i=0; package_ids[i] != NULL; i++) {
+					parts = pk_package_id_split (package_ids[i]);
+					g_printerr ("%i\t'%s'\n", i+1, parts[PK_PACKAGE_ID_NAME]);
+					g_strfreev (parts);
 				}
 
 				/* get selection */
 				/* TRANSLATORS: ask the user to choose a file to install */
-				i = pk_console_get_number (_("Please choose a package to install"), available->len);
+				i = pk_console_get_number (_("Please choose a package to install"), len);
 
 				/* run command */
-				possible = g_ptr_array_index (available, i);
-				text = g_strdup_printf ("pkcon install %s", possible);
-				ret = pk_cnf_spawn_command (text);
+				ret = pk_cnf_install_package_id (package_ids[i]);
 				if (ret)
-					pk_cnf_spawn_command (argv[1]);
-				g_free (text);
+					retval = pk_cnf_spawn_command (argv[1], &argv[2]);
+				else
+					retval = EXIT_COMMAND_NOT_FOUND;
 			}
 			goto out;
 		}
 	}
 
-	g_print ("\n");
+	g_printerr ("\n");
 
 out:
-	if (array != NULL) {
-		g_ptr_array_foreach (array, (GFunc) g_free, NULL);
-		g_ptr_array_free (array, TRUE);
-	}
-	if (available != NULL) {
-		g_ptr_array_foreach (available, (GFunc) g_free, NULL);
-		g_ptr_array_free (available, TRUE);
+	g_strfreev (package_ids);
+	if (task != NULL)
+		g_object_unref (task);
+	if (cancellable != NULL)
+		g_object_unref (cancellable);
+	if (config != NULL) {
+		g_strfreev (config->locations);
+		g_free (config);
 	}
+	if (array != NULL)
+		g_ptr_array_unref (array);
 
-	return 0;
+	return retval;
 }
 
