@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -323,11 +323,12 @@ out:
 #include "egg-test.h"
 
 void
-pk_bitfield_test (EggTest *test)
+pk_bitfield_test (gpointer user_data)
 {
+	EggTest *test = (EggTest *) user_data;
 	gchar *text;
 	PkBitfield filter;
-	guint value;
+	gint value;
 	PkBitfield values;
 
 	if (!egg_test_start (test, "PkBitfield"))
@@ -336,7 +337,7 @@ pk_bitfield_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "check we can convert filter bitfield to text (none)");
 	text = pk_filter_bitfield_to_text (pk_bitfield_value (PK_FILTER_ENUM_NONE));
-	if (egg_strequal (text, "none"))
+	if (g_strcmp0 (text, "none") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "text was %s", text);
@@ -363,7 +364,7 @@ pk_bitfield_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "check we can convert filter bitfield to text (single)");
 	text = pk_filter_bitfield_to_text (pk_bitfield_value (PK_FILTER_ENUM_NOT_DEVELOPMENT));
-	if (egg_strequal (text, "~devel"))
+	if (g_strcmp0 (text, "~devel") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "text was %s", text);
@@ -374,7 +375,7 @@ pk_bitfield_test (EggTest *test)
 	text = pk_filter_bitfield_to_text (pk_bitfield_value (PK_FILTER_ENUM_NOT_DEVELOPMENT) |
 					   pk_bitfield_value (PK_FILTER_ENUM_GUI) |
 					   pk_bitfield_value (PK_FILTER_ENUM_NEWEST));
-	if (egg_strequal (text, "~devel;gui;newest"))
+	if (g_strcmp0 (text, "~devel;gui;newest") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "text was %s", text);
@@ -414,7 +415,7 @@ pk_bitfield_test (EggTest *test)
 	pk_bitfield_add (filter, PK_FILTER_ENUM_NOT_FREE);
 	pk_bitfield_remove (filter, PK_FILTER_ENUM_NOT_DEVELOPMENT);
 	text = pk_filter_bitfield_to_text (filter);
-	if (egg_strequal (text, "gui;~free;newest"))
+	if (g_strcmp0 (text, "gui;~free;newest") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "text was %s", text);
@@ -442,7 +443,7 @@ pk_bitfield_test (EggTest *test)
 	filter = pk_bitfield_value (PK_FILTER_ENUM_NOT_DEVELOPMENT);
 	pk_bitfield_remove (filter, PK_FILTER_ENUM_NOT_DEVELOPMENT);
 	text = pk_filter_bitfield_to_text (filter);
-	if (egg_strequal (text, "none"))
+	if (g_strcmp0 (text, "none") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "text was %s", text);
@@ -485,7 +486,7 @@ pk_bitfield_test (EggTest *test)
 	egg_test_title (test, "group bitfield to text (unknown)");
 	values = pk_bitfield_from_enums (PK_GROUP_ENUM_UNKNOWN, -1);
 	text = pk_group_bitfield_to_text (values);
-	if (egg_strequal (text, "unknown"))
+	if (g_strcmp0 (text, "unknown") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "returned bitfield text %s (%" PK_BITFIELD_FORMAT ")", text, values);
@@ -495,7 +496,7 @@ pk_bitfield_test (EggTest *test)
 	egg_test_title (test, "group bitfield to text (first and last)");
 	values = pk_bitfield_from_enums (PK_GROUP_ENUM_ACCESSIBILITY, PK_GROUP_ENUM_UNKNOWN, -1);
 	text = pk_group_bitfield_to_text (values);
-	if (egg_strequal (text, "accessibility;unknown"))
+	if (g_strcmp0 (text, "accessibility;unknown") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "returned bitfield text %s (%" PK_BITFIELD_FORMAT ")", text, values);
@@ -505,7 +506,7 @@ pk_bitfield_test (EggTest *test)
 	egg_test_title (test, "group bitfield to text (random)");
 	values = pk_bitfield_from_enums (PK_GROUP_ENUM_UNKNOWN, PK_GROUP_ENUM_REPOS, -1);
 	text = pk_group_bitfield_to_text (values);
-	if (egg_strequal (text, "repos;unknown"))
+	if (g_strcmp0 (text, "repos;unknown") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "returned bitfield text %s (%" PK_BITFIELD_FORMAT ")", text, values);
