@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -47,6 +47,24 @@
 #include "egg-debug.h"
 #include "egg-string.h"
 
+/**
+ * pk_get_os_release:
+ *
+ * Return value: The current OS release, e.g. "7.2-RELEASE"
+ * Note: Don't use this function if you can get this data from /etc/foo
+ **/
+static gchar *
+pk_get_os_release (void)
+{
+	gint retval;
+	struct utsname buf;
+
+	retval = uname (&buf);
+	if (retval != 0)
+		return g_strdup ("unknown");
+	return g_strdup (buf.release);
+}
+
 /**
  * pk_get_machine_type:
  *
@@ -195,6 +213,48 @@ pk_get_distro_id (void)
 		goto out;
 	}
 
+	/* check for Slackware */
+	ret = g_file_get_contents ("/etc/slackware-version", &contents, NULL, NULL);
+	if (ret) {
+		/* Slackware 13.0.0.0.0 */
+		split = g_strsplit (contents, " ", 0);
+		if (split == NULL)
+			goto out;
+
+		/* we can't get arch from /etc */
+		arch = pk_get_machine_type ();
+		if (arch == NULL)
+			goto out;
+
+		/* complete! */
+		distro = g_strdup_printf ("slackware-%s-%s", split[1], arch);
+		goto out;
+	}
+
+#ifdef __FreeBSD__
+	ret = TRUE;
+#endif
+	/* FreeBSD */
+	if (ret) {
+		/* we can't get version from /etc */
+		version = pk_get_os_release ();
+		if (version == NULL)
+			goto out;
+
+		/* 7.2-RELEASE */
+		split = g_strsplit (version, "-", 0);
+		if (split == NULL)
+			goto out;
+
+		/* we can't get arch from /etc */
+		arch = pk_get_machine_type ();
+		if (arch == NULL)
+			goto out;
+
+		/* complete! */
+		distro = g_strdup_printf ("freebsd-%s-%s", split[0], arch);
+		goto out;
+	}
 out:
 	g_strfreev (split);
 	g_free (version);
@@ -426,22 +486,20 @@ pk_strvalidate (const gchar *text)
 gchar **
 pk_ptr_array_to_strv (GPtrArray *array)
 {
-	gchar **strv_array;
+	gchar **value;
 	const gchar *value_temp;
 	guint i;
 
 	g_return_val_if_fail (array != NULL, NULL);
 
 	/* copy the array to a strv */
-	strv_array = g_new0 (gchar *, array->len + 2);
+	value = g_new0 (gchar *, array->len + 1);
 	for (i=0; i<array->len; i++) {
 		value_temp = (const gchar *) g_ptr_array_index (array, i);
-		strv_array[i] = g_strdup (value_temp);
+		value[i] = g_strdup (value_temp);
 	}
-	/* set the last element to NULL */
-	strv_array[i] = NULL;
 
-	return strv_array;
+	return value;
 }
 
 /**
@@ -510,6 +568,32 @@ pk_va_list_to_argv (const gchar *string_first, va_list *args)
 	return array;
 }
 
+/**
+ * pk_error_code_is_need_untrusted:
+ * @error_code: the transactions #PkErrorCodeEnum
+ *
+ * Is this error could be handled with retrying with only_trusted %FALSE.
+ *
+ * Return value: if the error code suggests to try with only_trusted %FALSE
+ **/
+gboolean
+pk_error_code_is_need_untrusted (PkErrorCodeEnum error_code)
+{
+	gboolean ret = FALSE;
+	switch (error_code) {
+		case PK_ERROR_ENUM_GPG_FAILURE:
+		case PK_ERROR_ENUM_BAD_GPG_SIGNATURE:
+		case PK_ERROR_ENUM_MISSING_GPG_SIGNATURE:
+		case PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED:
+		case PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED:
+			ret = TRUE;
+			break;
+		default:
+			break;
+	}
+	return ret;
+}
+
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
@@ -531,8 +615,9 @@ pk_va_list_to_argv_test (const gchar *first_element, ...)
 }
 
 void
-pk_common_test (EggTest *test)
+pk_common_test (gpointer user_data)
 {
+	EggTest *test = (EggTest *) user_data;
 	gboolean ret;
 	gchar **array;
 	gchar *text_safe;
@@ -559,7 +644,7 @@ pk_common_test (EggTest *test)
 	 ************************************************************/
 	egg_test_title (test, "va_list_to_argv single");
 	array = pk_va_list_to_argv_test ("richard", NULL);
-	if (egg_strequal (array[0], "richard") &&
+	if (g_strcmp0 (array[0], "richard") == 0 &&
 	    array[1] == NULL)
 		egg_test_success (test, NULL);
 	else
@@ -569,9 +654,9 @@ pk_common_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "va_list_to_argv triple");
 	array = pk_va_list_to_argv_test ("richard", "phillip", "hughes", NULL);
-	if (egg_strequal (array[0], "richard") &&
-	    egg_strequal (array[1], "phillip") &&
-	    egg_strequal (array[2], "hughes") &&
+	if (g_strcmp0 (array[0], "richard") == 0 &&
+	    g_strcmp0 (array[1], "phillip") == 0 &&
+	    g_strcmp0 (array[2], "hughes") == 0 &&
 	    array[3] == NULL)
 		egg_test_success (test, NULL);
 	else
@@ -610,7 +695,7 @@ pk_common_test (EggTest *test)
 	 ************************************************************/
 	egg_test_title (test, "test replace unsafe (okay)");
 	text_safe = pk_strsafe ("Richard Hughes");
-	if (egg_strequal (text_safe, "Richard Hughes"))
+	if (g_strcmp0 (text_safe, "Richard Hughes") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed the replace unsafe '%s'", text_safe);
@@ -619,7 +704,7 @@ pk_common_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "test replace UTF8 unsafe (okay)");
 	text_safe = pk_strsafe ("Gölas");
-	if (egg_strequal (text_safe, "Gölas"))
+	if (g_strcmp0 (text_safe, "Gölas") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed the replace unsafe '%s'", text_safe);
@@ -628,7 +713,7 @@ pk_common_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "test replace unsafe (one invalid)");
 	text_safe = pk_strsafe ("Richard\rHughes");
-	if (egg_strequal (text_safe, "Richard Hughes"))
+	if (g_strcmp0 (text_safe, "Richard Hughes") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed the replace unsafe '%s'", text_safe);
@@ -637,7 +722,7 @@ pk_common_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "test replace unsafe (multiple invalid)");
 	text_safe = pk_strsafe (" Richard\rHughes\f");
-	if (egg_strequal (text_safe, " Richard Hughes "))
+	if (g_strcmp0 (text_safe, " Richard Hughes ") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed the replace unsafe '%s'", text_safe);
