@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #if !defined (__PACKAGEKIT_H_INSIDE__) && !defined (PK_COMPILATION)
@@ -27,6 +27,7 @@
 #define __PK_COMMON_H
 
 #include <glib-object.h>
+#include "pk-enum.h"
 
 G_BEGIN_DECLS
 
@@ -72,6 +73,7 @@ G_BEGIN_DECLS
  */
 #define	PK_SYSTEM_PACKAGE_LIST_FILENAME	"/var/lib/PackageKit/system.package-list"
 
+void		 pk_common_test				(gpointer	 user_data);
 gboolean	 pk_strvalidate				(const gchar	*text)
 							 G_GNUC_WARN_UNUSED_RESULT;
 gchar		*pk_strsafe				(const gchar	*text)
@@ -90,6 +92,7 @@ gchar		*pk_iso8601_from_date			(const GDate	*date);
 GDate		*pk_iso8601_to_date			(const gchar	*iso_date);
 gchar		*pk_get_distro_id			(void)
 							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_error_code_is_need_untrusted	(PkErrorCodeEnum error_code);
 
 G_END_DECLS
 
