@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -49,6 +49,7 @@ static const PkEnumMatch enum_exit[] = {
 	{PK_EXIT_ENUM_EULA_REQUIRED,		"eula-required"},
 	{PK_EXIT_ENUM_MEDIA_CHANGE_REQUIRED,	"media-change-required"},
 	{PK_EXIT_ENUM_KILLED,			"killed"},
+	{PK_EXIT_ENUM_NEED_UNTRUSTED,		"need-untrusted"},
 	{0, NULL}
 };
 
@@ -86,41 +87,49 @@ static const PkEnumMatch enum_status[] = {
 	{PK_STATUS_ENUM_GENERATE_PACKAGE_LIST,	"generate-package-list"},
 	{PK_STATUS_ENUM_WAITING_FOR_LOCK,	"waiting-for-lock"},
 	{PK_STATUS_ENUM_WAITING_FOR_AUTH,	"waiting-for-auth"},
+	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"scan-process-list"},
+	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"check-executable-files"},
+	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"check-libraries"},
+	{PK_STATUS_ENUM_COPY_FILES,		"copy-files"},
 	{0, NULL}
 };
 
 static const PkEnumMatch enum_role[] = {
-	{PK_ROLE_ENUM_UNKNOWN,			"unknown"},	/* fall though value */
-	{PK_ROLE_ENUM_CANCEL,			"cancel"},
-	{PK_ROLE_ENUM_GET_DEPENDS,		"get-depends"},
-	{PK_ROLE_ENUM_GET_DETAILS,		"get-details"},
-	{PK_ROLE_ENUM_GET_FILES,		"get-files"},
-	{PK_ROLE_ENUM_GET_PACKAGES,		"get-packages"},
-	{PK_ROLE_ENUM_GET_REPO_LIST,		"get-repo-list"},
-	{PK_ROLE_ENUM_GET_REQUIRES,		"get-requires"},
-	{PK_ROLE_ENUM_GET_UPDATE_DETAIL,	"get-update-detail"},
-	{PK_ROLE_ENUM_GET_UPDATES,		"get-updates"},
-	{PK_ROLE_ENUM_INSTALL_FILES,		"install-files"},
-	{PK_ROLE_ENUM_INSTALL_PACKAGES,		"install-packages"},
-	{PK_ROLE_ENUM_INSTALL_SIGNATURE,	"install-signature"},
-	{PK_ROLE_ENUM_REFRESH_CACHE,		"refresh-cache"},
-	{PK_ROLE_ENUM_REMOVE_PACKAGES,		"remove-packages"},
-	{PK_ROLE_ENUM_REPO_ENABLE,		"repo-enable"},
-	{PK_ROLE_ENUM_REPO_SET_DATA,		"repo-set-data"},
-	{PK_ROLE_ENUM_RESOLVE,			"resolve"},
-	{PK_ROLE_ENUM_ROLLBACK,			"rollback"},
-	{PK_ROLE_ENUM_SEARCH_DETAILS,		"search-details"},
-	{PK_ROLE_ENUM_SEARCH_FILE,		"search-file"},
-	{PK_ROLE_ENUM_SEARCH_GROUP,		"search-group"},
-	{PK_ROLE_ENUM_SEARCH_NAME,		"search-name"},
-	{PK_ROLE_ENUM_UPDATE_PACKAGES,		"update-packages"},
-	{PK_ROLE_ENUM_UPDATE_SYSTEM,		"update-system"},
-	{PK_ROLE_ENUM_WHAT_PROVIDES,		"what-provides"},
-	{PK_ROLE_ENUM_ACCEPT_EULA,		"accept-eula"},
-	{PK_ROLE_ENUM_DOWNLOAD_PACKAGES,	"download-packages"},
-	{PK_ROLE_ENUM_GET_DISTRO_UPGRADES,	"get-distro-upgrades"},
-	{PK_ROLE_ENUM_GET_CATEGORIES,		"get-categories"},
-	{PK_ROLE_ENUM_GET_OLD_TRANSACTIONS,	"get-old-transactions"},
+	{PK_ROLE_ENUM_UNKNOWN,				"unknown"},	/* fall though value */
+	{PK_ROLE_ENUM_CANCEL,				"cancel"},
+	{PK_ROLE_ENUM_GET_DEPENDS,			"get-depends"},
+	{PK_ROLE_ENUM_GET_DETAILS,			"get-details"},
+	{PK_ROLE_ENUM_GET_FILES,			"get-files"},
+	{PK_ROLE_ENUM_GET_PACKAGES,			"get-packages"},
+	{PK_ROLE_ENUM_GET_REPO_LIST,			"get-repo-list"},
+	{PK_ROLE_ENUM_GET_REQUIRES,			"get-requires"},
+	{PK_ROLE_ENUM_GET_UPDATE_DETAIL,		"get-update-detail"},
+	{PK_ROLE_ENUM_GET_UPDATES,			"get-updates"},
+	{PK_ROLE_ENUM_INSTALL_FILES,			"install-files"},
+	{PK_ROLE_ENUM_INSTALL_PACKAGES,			"install-packages"},
+	{PK_ROLE_ENUM_INSTALL_SIGNATURE,		"install-signature"},
+	{PK_ROLE_ENUM_REFRESH_CACHE,			"refresh-cache"},
+	{PK_ROLE_ENUM_REMOVE_PACKAGES,			"remove-packages"},
+	{PK_ROLE_ENUM_REPO_ENABLE,			"repo-enable"},
+	{PK_ROLE_ENUM_REPO_SET_DATA,			"repo-set-data"},
+	{PK_ROLE_ENUM_RESOLVE,				"resolve"},
+	{PK_ROLE_ENUM_ROLLBACK,				"rollback"},
+	{PK_ROLE_ENUM_SEARCH_DETAILS,			"search-details"},
+	{PK_ROLE_ENUM_SEARCH_FILE,			"search-file"},
+	{PK_ROLE_ENUM_SEARCH_GROUP,			"search-group"},
+	{PK_ROLE_ENUM_SEARCH_NAME,			"search-name"},
+	{PK_ROLE_ENUM_UPDATE_PACKAGES,			"update-packages"},
+	{PK_ROLE_ENUM_UPDATE_SYSTEM,			"update-system"},
+	{PK_ROLE_ENUM_WHAT_PROVIDES,			"what-provides"},
+	{PK_ROLE_ENUM_ACCEPT_EULA,			"accept-eula"},
+	{PK_ROLE_ENUM_DOWNLOAD_PACKAGES,		"download-packages"},
+	{PK_ROLE_ENUM_GET_DISTRO_UPGRADES,		"get-distro-upgrades"},
+	{PK_ROLE_ENUM_GET_CATEGORIES,			"get-categories"},
+	{PK_ROLE_ENUM_GET_OLD_TRANSACTIONS,		"get-old-transactions"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_FILES,		"simulate-install-files"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES,	"simulate-install-packages"},
+	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,		"simulate-remove-packages"},
+	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,		"simulate-update-packages"},
 	{0, NULL}
 };
 
@@ -177,6 +186,14 @@ static const PkEnumMatch enum_error[] = {
 	{PK_ERROR_ENUM_UPDATE_NOT_FOUND,	"update-not-found"},
 	{PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED,	"cannot-install-repo-unsigned"},
 	{PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED,	"cannot-update-repo-unsigned"},
+	{PK_ERROR_ENUM_CANNOT_GET_FILELIST, "cannot-get-filelist"},
+	{PK_ERROR_ENUM_CANNOT_GET_REQUIRES, "cannot-get-requires"},
+	{PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY, "cannot-disable-repository"},
+	{PK_ERROR_ENUM_RESTRICTED_DOWNLOAD, "restricted-download"},
+	{PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE, "package-failed-to-configure"},
+	{PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD, "package-failed-to-build"},
+	{PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL, "package-failed-to-install"},
+	{PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE, "package-failed-to-remove"},
 	{0, NULL}
 };
 
@@ -186,6 +203,8 @@ static const PkEnumMatch enum_restart[] = {
 	{PK_RESTART_ENUM_SYSTEM,		"system"},
 	{PK_RESTART_ENUM_SESSION,		"session"},
 	{PK_RESTART_ENUM_APPLICATION,		"application"},
+	{PK_RESTART_ENUM_SECURITY_SYSTEM,	"security-system"},
+	{PK_RESTART_ENUM_SECURITY_SESSION,	"security-session"},
 	{0, NULL}
 };
 
@@ -203,6 +222,8 @@ static const PkEnumMatch enum_message[] = {
 	{PK_MESSAGE_ENUM_COULD_NOT_FIND_PACKAGE,	"could-not-find-package"},
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"config-files-changed"},
 	{PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED, "package-already-installed"},
+	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED, "autoremove-ignored"},
+	{PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED, "repo-metadata-download-failed"},
 	{0, NULL}
 };
 
@@ -303,6 +324,10 @@ static const PkEnumMatch enum_info[] = {
 	{PK_INFO_ENUM_COLLECTION_INSTALLED,	"collection-installed"},
 	{PK_INFO_ENUM_COLLECTION_AVAILABLE,	"collection-available"},
 	{PK_INFO_ENUM_FINISHED,			"finished"},
+	{PK_INFO_ENUM_REINSTALLING,		"reinstalling"},
+	{PK_INFO_ENUM_DOWNGRADING,		"downgrading"},
+	{PK_INFO_ENUM_PREPARING,		"preparing"},
+	{PK_INFO_ENUM_DECOMPRESSING,		"decompressing"},
 	{0, NULL}
 };
 
@@ -327,6 +352,7 @@ static const PkEnumMatch enum_provides[] = {
 	{PK_PROVIDES_ENUM_MIMETYPE,		"mimetype"},
 	{PK_PROVIDES_ENUM_HARDWARE_DRIVER,	"driver"},
 	{PK_PROVIDES_ENUM_FONT,			"font"},
+	{PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,	"postscript-driver"},
 	{0, NULL}
 };
 
@@ -340,133 +366,174 @@ static const PkEnumMatch enum_network[] = {
 	{0, NULL}
 };
 
+/* DO NOT ADD ENTRIES MANUALLY... Use pk-refresh-licenses in tools */
 static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
-	{PK_LICENSE_ENUM_GLIDE,			"Glide"},
-	{PK_LICENSE_ENUM_AFL,			"AFL"},
-	{PK_LICENSE_ENUM_AMPAS_BSD,		"AMPAS BSD"},
-	{PK_LICENSE_ENUM_AMAZON_DSL,		"ADSL"},
+	{PK_LICENSE_ENUM_AAL,			"AAL"},
 	{PK_LICENSE_ENUM_ADOBE,			"Adobe"},
+	{PK_LICENSE_ENUM_ADSL,			"ADSL"},
+	{PK_LICENSE_ENUM_AFL,			"AFL"},
 	{PK_LICENSE_ENUM_AGPLV1,		"AGPLv1"},
-	{PK_LICENSE_ENUM_AGPLV3,		"AGPLv3"},
+	{PK_LICENSE_ENUM_AMPAS_BSD,		"AMPAS BSD"},
+	{PK_LICENSE_ENUM_APSL_2_DOT_0,		"APSL 2.0"},
+	{PK_LICENSE_ENUM_ARL,			"ARL"},
+	{PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,	"Artistic 2.0"},
+	{PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,	"Artistic clarified"},
 	{PK_LICENSE_ENUM_ASL_1_DOT_0,		"ASL 1.0"},
 	{PK_LICENSE_ENUM_ASL_1_DOT_1,		"ASL 1.1"},
 	{PK_LICENSE_ENUM_ASL_2_DOT_0,		"ASL 2.0"},
-	{PK_LICENSE_ENUM_APSL_2_DOT_0,		"APSL 2.0"},
-	{PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,	"Artistic clarified"},
-	{PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,	"Artistic 2.0"},
-	{PK_LICENSE_ENUM_ARL,			"ARL"},
 	{PK_LICENSE_ENUM_BITTORRENT,		"BitTorrent"},
 	{PK_LICENSE_ENUM_BOOST,			"Boost"},
-	{PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,	"BSD with advertising"},
 	{PK_LICENSE_ENUM_BSD,			"BSD"},
-	{PK_LICENSE_ENUM_CECILL,		"CeCILL"},
+	{PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,	"BSD with advertising"},
+	{PK_LICENSE_ENUM_CATOSL,		"CATOSL"},
+	{PK_LICENSE_ENUM_CC_BY,			"CC-BY"},
+	{PK_LICENSE_ENUM_CC_BY_SA,		"CC-BY-SA"},
 	{PK_LICENSE_ENUM_CDDL,			"CDDL"},
-	{PK_LICENSE_ENUM_CPL,			"CPL"},
+	{PK_LICENSE_ENUM_CDL,			"CDL"},
+	{PK_LICENSE_ENUM_CECILL,		"CeCILL"},
+	{PK_LICENSE_ENUM_CECILL_B,		"CeCILL-B"},
+	{PK_LICENSE_ENUM_CECILL_C,		"CeCILL-C"},
+	{PK_LICENSE_ENUM_CNRI,			"CNRI"},
 	{PK_LICENSE_ENUM_CONDOR,		"Condor"},
 	{PK_LICENSE_ENUM_COPYRIGHT_ONLY,	"Copyright only"},
-	{PK_LICENSE_ENUM_CRYPTIX,		"Cryptix"},
+	{PK_LICENSE_ENUM_CPAL,			"CPAL"},
+	{PK_LICENSE_ENUM_CPL,			"CPL"},
 	{PK_LICENSE_ENUM_CRYSTAL_STACKER,	"Crystal Stacker"},
 	{PK_LICENSE_ENUM_DOC,			"DOC"},
-	{PK_LICENSE_ENUM_WTFPL,			"WTFPL"},
-	{PK_LICENSE_ENUM_EPL,			"EPL"},
+	{PK_LICENSE_ENUM_DSL,			"DSL"},
+	{PK_LICENSE_ENUM_DVIPDFM,		"dvipdfm"},
+	{PK_LICENSE_ENUM_ECL_1_DOT_0,		"ECL 1.0"},
+	{PK_LICENSE_ENUM_ECL_2_DOT_0,		"ECL 2.0"},
 	{PK_LICENSE_ENUM_ECOS,			"eCos"},
 	{PK_LICENSE_ENUM_EFL_2_DOT_0,		"EFL 2.0"},
+	{PK_LICENSE_ENUM_ENTESSA,		"Entessa"},
+	{PK_LICENSE_ENUM_EPL,			"EPL"},
+	{PK_LICENSE_ENUM_ERPL,			"ERPL"},
+	{PK_LICENSE_ENUM_EUROSYM,		"Eurosym"},
 	{PK_LICENSE_ENUM_EU_DATAGRID,		"EU Datagrid"},
-	{PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS,"LGPLv2 with exceptions"},
+	{PK_LICENSE_ENUM_FAIR,			"Fair"},
+	{PK_LICENSE_ENUM_FBSDDL,		"FBSDDL"},
+	{PK_LICENSE_ENUM_FREE_ART,		"Free Art"},
 	{PK_LICENSE_ENUM_FTL,			"FTL"},
+	{PK_LICENSE_ENUM_GEOGRATIS,		"GeoGratis"},
+	{PK_LICENSE_ENUM_GFDL,			"GFDL"},
 	{PK_LICENSE_ENUM_GIFTWARE,		"Giftware"},
-	{PK_LICENSE_ENUM_GPLV2,			"GPLv2"},
-	{PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,	"GPLv2 with exceptions"},
-	{PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS, "GPLv2+ with exceptions"},
-	{PK_LICENSE_ENUM_GPLV3,			"GPLv3"},
-	{PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,	"GPLv3 with exceptions"},
-	{PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS, "GPLv3+ with exceptions"},
-	{PK_LICENSE_ENUM_LGPLV2,		"LGPLv2"},
-	{PK_LICENSE_ENUM_LGPLV3,		"LGPLv3"},
+	{PK_LICENSE_ENUM_GL2PS,			"GL2PS"},
+	{PK_LICENSE_ENUM_GLIDE,			"Glide"},
 	{PK_LICENSE_ENUM_GNUPLOT,		"gnuplot"},
+	{PK_LICENSE_ENUM_GPLV1,			"GPLv1"},
+	{PK_LICENSE_ENUM_GPLV2,			"GPLv2"},
+	{PK_LICENSE_ENUM_GPLV2_OR_ARTISTIC,	"GPLv2 or Artistic"},
+	{PK_LICENSE_ENUM_GPLV2_PLUS,		"GPLv2+"},
+	{PK_LICENSE_ENUM_GPLV2_PLUS_OR_ARTISTIC, "GPLv2+ or Artistic"},
+	{PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS, "GPLv2+ with exceptions"},
+	{PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,	"GPLv2 with exceptions"},
+	{PK_LICENSE_ENUM_GPLV3,			"GPLv3"},
+	{PK_LICENSE_ENUM_GPLV3_PLUS,		"GPLv3+"},
+	{PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS, "GPLv3+ with exceptions"},
+	{PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,	"GPLv3 with exceptions"},
+	{PK_LICENSE_ENUM_GPL_PLUS,		"GPL+"},
+	{PK_LICENSE_ENUM_GPL_PLUS_OR_ARTISTIC,	"GPL+ or Artistic"},
+	{PK_LICENSE_ENUM_GPL_PLUS_WITH_EXCEPTIONS, "GPL+ with exceptions"},
 	{PK_LICENSE_ENUM_IBM,			"IBM"},
-	{PK_LICENSE_ENUM_IMATIX,		"iMatix"},
-	{PK_LICENSE_ENUM_IMAGEMAGICK,		"ImageMagick"},
-	{PK_LICENSE_ENUM_IMLIB2,		"Imlib2"},
+	{PK_LICENSE_ENUM_IEEE,			"IEEE"},
 	{PK_LICENSE_ENUM_IJG,			"IJG"},
+	{PK_LICENSE_ENUM_IMAGEMAGICK,		"ImageMagick"},
+	{PK_LICENSE_ENUM_IMATIX,		"iMatix"},
+	{PK_LICENSE_ENUM_IMLIB2,		"Imlib2"},
 	{PK_LICENSE_ENUM_INTEL_ACPI,		"Intel ACPI"},
 	{PK_LICENSE_ENUM_INTERBASE,		"Interbase"},
 	{PK_LICENSE_ENUM_ISC,			"ISC"},
 	{PK_LICENSE_ENUM_JABBER,		"Jabber"},
 	{PK_LICENSE_ENUM_JASPER,		"JasPer"},
-	{PK_LICENSE_ENUM_LPPL,			"LPPL"},
+	{PK_LICENSE_ENUM_JPYTHON,		"JPython"},
+	{PK_LICENSE_ENUM_KNUTH,			"Knuth"},
+	{PK_LICENSE_ENUM_LBNL_BSD,		"LBNL BSD"},
+	{PK_LICENSE_ENUM_LGPLV2,		"LGPLv2"},
+	{PK_LICENSE_ENUM_LGPLV2_PLUS,		"LGPLv2+"},
+	{PK_LICENSE_ENUM_LGPLV2_PLUS_OR_ARTISTIC, "LGPLv2+ or Artistic"},
+	{PK_LICENSE_ENUM_LGPLV2_PLUS_WITH_EXCEPTIONS, "LGPLv2+ with exceptions"},
+	{PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS, "LGPLv2 with exceptions"},
+	{PK_LICENSE_ENUM_LGPLV3,		"LGPLv3"},
+	{PK_LICENSE_ENUM_LGPLV3_PLUS,		"LGPLv3+"},
+	{PK_LICENSE_ENUM_LGPLV3_PLUS_WITH_EXCEPTIONS, "LGPLv3+ with exceptions"},
+	{PK_LICENSE_ENUM_LGPLV3_WITH_EXCEPTIONS, "LGPLv3 with exceptions"},
 	{PK_LICENSE_ENUM_LIBTIFF,		"libtiff"},
+	{PK_LICENSE_ENUM_LLGPL,			"LLGPL"},
+	{PK_LICENSE_ENUM_LOGICA,		"Logica"},
 	{PK_LICENSE_ENUM_LPL,			"LPL"},
+	{PK_LICENSE_ENUM_LPPL,			"LPPL"},
 	{PK_LICENSE_ENUM_MECAB_IPADIC,		"mecab-ipadic"},
+	{PK_LICENSE_ENUM_MIROS,			"MirOS"},
 	{PK_LICENSE_ENUM_MIT,			"MIT"},
 	{PK_LICENSE_ENUM_MIT_WITH_ADVERTISING,	"MIT with advertising"},
+	{PK_LICENSE_ENUM_MOTOSOTO,		"Motosoto"},
 	{PK_LICENSE_ENUM_MPLV1_DOT_0,		"MPLv1.0"},
 	{PK_LICENSE_ENUM_MPLV1_DOT_1,		"MPLv1.1"},
+	{PK_LICENSE_ENUM_MS_PL,			"MS-PL"},
+	{PK_LICENSE_ENUM_NAUMEN,		"Naumen"},
 	{PK_LICENSE_ENUM_NCSA,			"NCSA"},
-	{PK_LICENSE_ENUM_NGPL,			"NGPL"},
-	{PK_LICENSE_ENUM_NOSL,			"NOSL"},
 	{PK_LICENSE_ENUM_NETCDF,		"NetCDF"},
 	{PK_LICENSE_ENUM_NETSCAPE,		"Netscape"},
+	{PK_LICENSE_ENUM_NEWMAT,		"Newmat"},
+	{PK_LICENSE_ENUM_NGPL,			"NGPL"},
 	{PK_LICENSE_ENUM_NOKIA,			"Nokia"},
+	{PK_LICENSE_ENUM_NOSL,			"NOSL"},
+	{PK_LICENSE_ENUM_NOWEB,			"Noweb"},
+	{PK_LICENSE_ENUM_OAL,			"OAL"},
+	{PK_LICENSE_ENUM_OFSFDL,		"OFSFDL"},
 	{PK_LICENSE_ENUM_OPENLDAP,		"OpenLDAP"},
 	{PK_LICENSE_ENUM_OPENPBS,		"OpenPBS"},
+	{PK_LICENSE_ENUM_OPENSSL,		"OpenSSL"},
+	{PK_LICENSE_ENUM_OREILLY,		"OReilly"},
 	{PK_LICENSE_ENUM_OSL_1_DOT_0,		"OSL 1.0"},
 	{PK_LICENSE_ENUM_OSL_1_DOT_1,		"OSL 1.1"},
 	{PK_LICENSE_ENUM_OSL_2_DOT_0,		"OSL 2.0"},
+	{PK_LICENSE_ENUM_OSL_2_DOT_1,		"OSL 2.1"},
 	{PK_LICENSE_ENUM_OSL_3_DOT_0,		"OSL 3.0"},
-	{PK_LICENSE_ENUM_OPENSSL,		"OpenSSL"},
-	{PK_LICENSE_ENUM_OREILLY,		"OReilly"},
 	{PK_LICENSE_ENUM_PHORUM,		"Phorum"},
 	{PK_LICENSE_ENUM_PHP,			"PHP"},
+	{PK_LICENSE_ENUM_PLEXUS,		"Plexus"},
+	{PK_LICENSE_ENUM_PSUTILS,		"psutils"},
 	{PK_LICENSE_ENUM_PUBLIC_DOMAIN,		"Public Domain"},
+	{PK_LICENSE_ENUM_PUBLIC_USE,		"Public Use"},
 	{PK_LICENSE_ENUM_PYTHON,		"Python"},
+	{PK_LICENSE_ENUM_QHULL,			"Qhull"},
 	{PK_LICENSE_ENUM_QPL,			"QPL"},
+	{PK_LICENSE_ENUM_RICEBSD,		"RiceBSD"},
 	{PK_LICENSE_ENUM_RPSL,			"RPSL"},
 	{PK_LICENSE_ENUM_RUBY,			"Ruby"},
+	{PK_LICENSE_ENUM_SAXPATH,		"Saxpath"},
+	{PK_LICENSE_ENUM_SCEA,			"SCEA"},
+	{PK_LICENSE_ENUM_SCRIP,			"SCRIP"},
 	{PK_LICENSE_ENUM_SENDMAIL,		"Sendmail"},
+	{PK_LICENSE_ENUM_SISSL,			"SISSL"},
 	{PK_LICENSE_ENUM_SLEEPYCAT,		"Sleepycat"},
 	{PK_LICENSE_ENUM_SLIB,			"SLIB"},
-	{PK_LICENSE_ENUM_SISSL,			"SISSL"},
+	{PK_LICENSE_ENUM_SNIA,			"SNIA"},
 	{PK_LICENSE_ENUM_SPL,			"SPL"},
 	{PK_LICENSE_ENUM_TCL,			"TCL"},
+	{PK_LICENSE_ENUM_TMATE,			"TMate"},
+	{PK_LICENSE_ENUM_TPL,			"TPL"},
 	{PK_LICENSE_ENUM_UCD,			"UCD"},
 	{PK_LICENSE_ENUM_VIM,			"Vim"},
 	{PK_LICENSE_ENUM_VNLSL,			"VNLSL"},
+	{PK_LICENSE_ENUM_VOSTROM,		"VOSTROM"},
 	{PK_LICENSE_ENUM_VSL,			"VSL"},
 	{PK_LICENSE_ENUM_W3C,			"W3C"},
+	{PK_LICENSE_ENUM_WEBMIN,		"Webmin"},
+	{PK_LICENSE_ENUM_WTFPL,			"WTFPL"},
 	{PK_LICENSE_ENUM_WXWIDGETS,		"wxWidgets"},
+	{PK_LICENSE_ENUM_XEROX,			"Xerox"},
 	{PK_LICENSE_ENUM_XINETD,		"xinetd"},
+	{PK_LICENSE_ENUM_YPLV1_DOT_1,		"YPLv1.1"},
 	{PK_LICENSE_ENUM_ZEND,			"Zend"},
+	{PK_LICENSE_ENUM_ZLIB,			"zlib"},
+	{PK_LICENSE_ENUM_ZLIB_WITH_ACKNOWLEDGEMENT, "zlib with acknowledgement"},
 	{PK_LICENSE_ENUM_ZPLV1_DOT_0,		"ZPLv1.0"},
 	{PK_LICENSE_ENUM_ZPLV2_DOT_0,		"ZPLv2.0"},
 	{PK_LICENSE_ENUM_ZPLV2_DOT_1,		"ZPLv2.1"},
-	{PK_LICENSE_ENUM_ZLIB,			"zlib"},
-	{PK_LICENSE_ENUM_ZLIB_WITH_ACK,		"zlib with acknowledgement"},
-	{PK_LICENSE_ENUM_CDL,			"CDL"},
-	{PK_LICENSE_ENUM_FBSDDL,		"FBSDDL"},
-	{PK_LICENSE_ENUM_GFDL,			"GFDL"},
-	{PK_LICENSE_ENUM_IEEE,			"IEEE"},
-	{PK_LICENSE_ENUM_OFSFDL,		"OFSFDL"},
-	{PK_LICENSE_ENUM_OPEN_PUBLICATION,	"Open Publication"},
-	{PK_LICENSE_ENUM_CC_BY,			"CC-BY"},
-	{PK_LICENSE_ENUM_CC_BY_SA,		"CC-BY-SA"},
-	{PK_LICENSE_ENUM_CC_BY_ND,		"CC-BY-ND"},
-	{PK_LICENSE_ENUM_DSL,			"DSL"},
-	{PK_LICENSE_ENUM_FREE_ART,		"Free Art"},
-	{PK_LICENSE_ENUM_OFL,			"OFL"},
-	{PK_LICENSE_ENUM_UTOPIA,		"Utopia"},
-	{PK_LICENSE_ENUM_ARPHIC,		"Arphic"},
-	{PK_LICENSE_ENUM_BAEKMUK,		"Baekmuk"},
-	{PK_LICENSE_ENUM_BITSTREAM_VERA,	"Bitstream Vera"},
-	{PK_LICENSE_ENUM_LUCIDA,		"Lucida"},
-	{PK_LICENSE_ENUM_MPLUS,			"mplus"},
-	{PK_LICENSE_ENUM_STIX,			"STIX"},
-	{PK_LICENSE_ENUM_XANO,			"XANO"},
-	{PK_LICENSE_ENUM_VOSTROM,		"VOSTROM"},
-	{PK_LICENSE_ENUM_XEROX,			"Xerox License"},
-	{PK_LICENSE_ENUM_RICEBSD,		"RiceBSD"},
-	{PK_LICENSE_ENUM_QHULL,			"Qhull"},
 	{0, NULL}
 };
 
@@ -478,6 +545,14 @@ static const PkEnumMatch enum_media_type[] = {
 	{0, NULL}
 };
 
+static const PkEnumMatch enum_authorize_type[] = {
+	{PK_AUTHORIZE_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
+	{PK_AUTHORIZE_ENUM_YES,			"yes"},
+	{PK_AUTHORIZE_ENUM_NO,			"no"},
+	{PK_AUTHORIZE_ENUM_INTERACTIVE,		"interactive"},
+	{0, NULL}
+};
+
 /**
  * pk_enum_find_value:
  * @table: A #PkEnumMatch enum table of values
@@ -963,7 +1038,8 @@ pk_license_enum_to_text (PkLicenseEnum license)
  *
  * Return value: the enumerated constant value, e.g. PK_MEDIA_TYPE_ENUM_CD
  **/
-PkMediaTypeEnum pk_media_type_enum_from_text (const gchar *media_type)
+PkMediaTypeEnum
+pk_media_type_enum_from_text (const gchar *media_type)
 {
 	return pk_enum_find_value (enum_media_type, media_type);
 }
@@ -976,11 +1052,40 @@ PkMediaTypeEnum pk_media_type_enum_from_text (const gchar *media_type)
  *
  * Return value: the enumerated constant value, e.g. "dvd"
  **/
-const gchar* pk_media_type_enum_to_text (PkMediaTypeEnum media_type)
+const gchar *
+pk_media_type_enum_to_text (PkMediaTypeEnum media_type)
 {
 	return pk_enum_find_string (enum_media_type, media_type);
 }
 
+/**
+ * pk_authorize_type_enum_from_text:
+ * @code: Text describing the enumerated type
+ *
+ * Converts a text enumerated type to its unsigned integer representation
+ *
+ * Return value: the enumerated constant value, e.g. PK_AUTHORIZE_ENUM_YES
+ **/
+PkAuthorizeEnum
+pk_authorize_type_enum_from_text (const gchar *authorize_type)
+{
+	return pk_enum_find_value (enum_authorize_type, authorize_type);
+}
+
+/**
+ * pk_authorize_type_enum_to_text:
+ * @code: The enumerated type value
+ *
+ * Converts a enumerated type to its text representation
+ *
+ * Return value: the enumerated constant value, e.g. "yes"
+ **/
+const gchar *
+pk_authorize_type_enum_to_text (PkAuthorizeEnum authorize_type)
+{
+	return pk_enum_find_string (enum_authorize_type, authorize_type);
+}
+
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
@@ -988,8 +1093,9 @@ const gchar* pk_media_type_enum_to_text (PkMediaTypeEnum media_type)
 #include "egg-test.h"
 
 void
-pk_enum_test (EggTest *test)
+pk_enum_test (gpointer user_data)
 {
+	EggTest *test = (EggTest *) user_data;
 	const gchar *string;
 	PkRoleEnum role_value;
 	guint i;
@@ -1008,7 +1114,7 @@ pk_enum_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "find string");
 	string = pk_enum_find_string (enum_role, PK_ROLE_ENUM_SEARCH_FILE);
-	if (egg_strequal (string, "search-file"))
+	if (g_strcmp0 (string, "search-file") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, NULL);
@@ -1024,7 +1130,7 @@ pk_enum_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "find string");
 	string = pk_role_enum_to_text (PK_ROLE_ENUM_SEARCH_FILE);
-	if (egg_strequal (string, "search-file"))
+	if (g_strcmp0 (string, "search-file") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, NULL);
