@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #if !defined (__PACKAGEKIT_H_INSIDE__) && !defined (PK_COMPILATION)
@@ -80,6 +80,10 @@ typedef enum {
 	PK_ROLE_ENUM_GET_DISTRO_UPGRADES,
 	PK_ROLE_ENUM_GET_CATEGORIES,
 	PK_ROLE_ENUM_GET_OLD_TRANSACTIONS,
+	PK_ROLE_ENUM_SIMULATE_INSTALL_FILES,
+	PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES,
+	PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,
+	PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,
 	PK_ROLE_ENUM_UNKNOWN
 } PkRoleEnum;
 
@@ -136,6 +140,10 @@ typedef enum {
 	PK_STATUS_ENUM_GENERATE_PACKAGE_LIST,
 	PK_STATUS_ENUM_WAITING_FOR_LOCK,
 	PK_STATUS_ENUM_WAITING_FOR_AUTH,
+	PK_STATUS_ENUM_SCAN_PROCESS_LIST,
+	PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,
+	PK_STATUS_ENUM_CHECK_LIBRARIES,
+	PK_STATUS_ENUM_COPY_FILES,
 	PK_STATUS_ENUM_UNKNOWN
 } PkStatusEnum;
 
@@ -152,6 +160,7 @@ typedef enum {
 	PK_EXIT_ENUM_EULA_REQUIRED,
 	PK_EXIT_ENUM_KILLED, /* when we forced the cancel, but had to SIGKILL */
 	PK_EXIT_ENUM_MEDIA_CHANGE_REQUIRED,
+	PK_EXIT_ENUM_NEED_UNTRUSTED,
 	PK_EXIT_ENUM_UNKNOWN
 } PkExitEnum;
 
@@ -204,13 +213,15 @@ typedef enum {
 /**
  * PkRestartEnum:
  *
- * What restart we need to after a transaction
+ * What restart we need to after a transaction, ordered by severity
  **/
 typedef enum {
 	PK_RESTART_ENUM_NONE,
 	PK_RESTART_ENUM_APPLICATION,
 	PK_RESTART_ENUM_SESSION,
 	PK_RESTART_ENUM_SYSTEM,
+	PK_RESTART_ENUM_SECURITY_SESSION,	/* a library that is being used by this package has been updated for security */
+	PK_RESTART_ENUM_SECURITY_SYSTEM,
 	PK_RESTART_ENUM_UNKNOWN
 } PkRestartEnum;
 
@@ -232,6 +243,8 @@ typedef enum {
 	PK_MESSAGE_ENUM_COULD_NOT_FIND_PACKAGE,
 	PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,
 	PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED,
+	PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,
+	PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED,
 	PK_MESSAGE_ENUM_UNKNOWN
 } PkMessageEnum;
 
@@ -292,6 +305,14 @@ typedef enum {
 	PK_ERROR_ENUM_UPDATE_NOT_FOUND,
 	PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED,
 	PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED,
+	PK_ERROR_ENUM_CANNOT_GET_FILELIST,
+	PK_ERROR_ENUM_CANNOT_GET_REQUIRES,
+	PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY,
+	PK_ERROR_ENUM_RESTRICTED_DOWNLOAD,
+	PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE,
+	PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD,
+	PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL,
+	PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE,
 	PK_ERROR_ENUM_UNKNOWN
 } PkErrorCodeEnum;
 
@@ -375,6 +396,10 @@ typedef enum {
 	PK_INFO_ENUM_COLLECTION_INSTALLED,
 	PK_INFO_ENUM_COLLECTION_AVAILABLE,
 	PK_INFO_ENUM_FINISHED,
+	PK_INFO_ENUM_REINSTALLING,
+	PK_INFO_ENUM_DOWNGRADING,
+	PK_INFO_ENUM_PREPARING,
+	PK_INFO_ENUM_DECOMPRESSING,
 	PK_INFO_ENUM_UNKNOWN
 } PkInfoEnum;
 
@@ -411,135 +436,176 @@ typedef enum {
 	PK_PROVIDES_ENUM_MIMETYPE,
 	PK_PROVIDES_ENUM_FONT,
 	PK_PROVIDES_ENUM_HARDWARE_DRIVER,
+	PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,
 	PK_PROVIDES_ENUM_UNKNOWN
 } PkProvidesEnum;
 
 typedef enum {
-	PK_LICENSE_ENUM_GLIDE,
-	PK_LICENSE_ENUM_AFL,
-	PK_LICENSE_ENUM_AMPAS_BSD,
-	PK_LICENSE_ENUM_AMAZON_DSL,
+	PK_LICENSE_ENUM_AAL,
 	PK_LICENSE_ENUM_ADOBE,
+	PK_LICENSE_ENUM_ADSL,
+	PK_LICENSE_ENUM_AFL,
 	PK_LICENSE_ENUM_AGPLV1,
-	PK_LICENSE_ENUM_AGPLV3,
+	PK_LICENSE_ENUM_AMPAS_BSD,
+	PK_LICENSE_ENUM_APSL_2_DOT_0,
+	PK_LICENSE_ENUM_ARL,
+	PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,
+	PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,
 	PK_LICENSE_ENUM_ASL_1_DOT_0,
 	PK_LICENSE_ENUM_ASL_1_DOT_1,
 	PK_LICENSE_ENUM_ASL_2_DOT_0,
-	PK_LICENSE_ENUM_APSL_2_DOT_0,
-	PK_LICENSE_ENUM_ARTISTIC_CLARIFIED,
-	PK_LICENSE_ENUM_ARTISTIC_2_DOT_0,
-	PK_LICENSE_ENUM_ARL,
 	PK_LICENSE_ENUM_BITTORRENT,
 	PK_LICENSE_ENUM_BOOST,
-	PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,
 	PK_LICENSE_ENUM_BSD,
-	PK_LICENSE_ENUM_CECILL,
+	PK_LICENSE_ENUM_BSD_WITH_ADVERTISING,
+	PK_LICENSE_ENUM_CATOSL,
+	PK_LICENSE_ENUM_CC_BY,
+	PK_LICENSE_ENUM_CC_BY_SA,
 	PK_LICENSE_ENUM_CDDL,
-	PK_LICENSE_ENUM_CPL,
+	PK_LICENSE_ENUM_CDL,
+	PK_LICENSE_ENUM_CECILL,
+	PK_LICENSE_ENUM_CECILL_B,
+	PK_LICENSE_ENUM_CECILL_C,
+	PK_LICENSE_ENUM_CNRI,
 	PK_LICENSE_ENUM_CONDOR,
 	PK_LICENSE_ENUM_COPYRIGHT_ONLY,
-	PK_LICENSE_ENUM_CRYPTIX,
+	PK_LICENSE_ENUM_CPAL,
+	PK_LICENSE_ENUM_CPL,
 	PK_LICENSE_ENUM_CRYSTAL_STACKER,
 	PK_LICENSE_ENUM_DOC,
-	PK_LICENSE_ENUM_WTFPL,
-	PK_LICENSE_ENUM_EPL,
+	PK_LICENSE_ENUM_DSL,
+	PK_LICENSE_ENUM_DVIPDFM,
+	PK_LICENSE_ENUM_ECL_1_DOT_0,
+	PK_LICENSE_ENUM_ECL_2_DOT_0,
 	PK_LICENSE_ENUM_ECOS,
 	PK_LICENSE_ENUM_EFL_2_DOT_0,
+	PK_LICENSE_ENUM_ENTESSA,
+	PK_LICENSE_ENUM_EPL,
+	PK_LICENSE_ENUM_ERPL,
+	PK_LICENSE_ENUM_EUROSYM,
 	PK_LICENSE_ENUM_EU_DATAGRID,
-	PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_FAIR,
+	PK_LICENSE_ENUM_FBSDDL,
+	PK_LICENSE_ENUM_FREE_ART,
 	PK_LICENSE_ENUM_FTL,
+	PK_LICENSE_ENUM_GEOGRATIS,
+	PK_LICENSE_ENUM_GFDL,
 	PK_LICENSE_ENUM_GIFTWARE,
-	PK_LICENSE_ENUM_GPLV2,
-	PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV3,
-	PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS,
-	PK_LICENSE_ENUM_LGPLV2,
-	PK_LICENSE_ENUM_LGPLV3,
+	PK_LICENSE_ENUM_GL2PS,
+	PK_LICENSE_ENUM_GLIDE,
 	PK_LICENSE_ENUM_GNUPLOT,
+	PK_LICENSE_ENUM_GPLV1,
+	PK_LICENSE_ENUM_GPLV2,
+	PK_LICENSE_ENUM_GPLV2_OR_ARTISTIC,
+	PK_LICENSE_ENUM_GPLV2_PLUS,
+	PK_LICENSE_ENUM_GPLV2_PLUS_OR_ARTISTIC,
+	PK_LICENSE_ENUM_GPLV2_PLUS_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_GPLV2_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_GPLV3,
+	PK_LICENSE_ENUM_GPLV3_PLUS,
+	PK_LICENSE_ENUM_GPLV3_PLUS_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_GPLV3_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_GPL_PLUS,
+	PK_LICENSE_ENUM_GPL_PLUS_OR_ARTISTIC,
+	PK_LICENSE_ENUM_GPL_PLUS_WITH_EXCEPTIONS,
 	PK_LICENSE_ENUM_IBM,
-	PK_LICENSE_ENUM_IMATIX,
-	PK_LICENSE_ENUM_IMAGEMAGICK,
-	PK_LICENSE_ENUM_IMLIB2,
+	PK_LICENSE_ENUM_IEEE,
 	PK_LICENSE_ENUM_IJG,
+	PK_LICENSE_ENUM_IMAGEMAGICK,
+	PK_LICENSE_ENUM_IMATIX,
+	PK_LICENSE_ENUM_IMLIB2,
 	PK_LICENSE_ENUM_INTEL_ACPI,
 	PK_LICENSE_ENUM_INTERBASE,
 	PK_LICENSE_ENUM_ISC,
 	PK_LICENSE_ENUM_JABBER,
 	PK_LICENSE_ENUM_JASPER,
-	PK_LICENSE_ENUM_LPPL,
+	PK_LICENSE_ENUM_JPYTHON,
+	PK_LICENSE_ENUM_KNUTH,
+	PK_LICENSE_ENUM_LBNL_BSD,
+	PK_LICENSE_ENUM_LGPLV2,
+	PK_LICENSE_ENUM_LGPLV2_PLUS,
+	PK_LICENSE_ENUM_LGPLV2_PLUS_OR_ARTISTIC,
+	PK_LICENSE_ENUM_LGPLV2_PLUS_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_LGPLV2_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_LGPLV3,
+	PK_LICENSE_ENUM_LGPLV3_PLUS,
+	PK_LICENSE_ENUM_LGPLV3_PLUS_WITH_EXCEPTIONS,
+	PK_LICENSE_ENUM_LGPLV3_WITH_EXCEPTIONS,
 	PK_LICENSE_ENUM_LIBTIFF,
+	PK_LICENSE_ENUM_LLGPL,
+	PK_LICENSE_ENUM_LOGICA,
 	PK_LICENSE_ENUM_LPL,
+	PK_LICENSE_ENUM_LPPL,
 	PK_LICENSE_ENUM_MECAB_IPADIC,
+	PK_LICENSE_ENUM_MIROS,
 	PK_LICENSE_ENUM_MIT,
 	PK_LICENSE_ENUM_MIT_WITH_ADVERTISING,
+	PK_LICENSE_ENUM_MOTOSOTO,
 	PK_LICENSE_ENUM_MPLV1_DOT_0,
 	PK_LICENSE_ENUM_MPLV1_DOT_1,
+	PK_LICENSE_ENUM_MS_PL,
+	PK_LICENSE_ENUM_NAUMEN,
 	PK_LICENSE_ENUM_NCSA,
-	PK_LICENSE_ENUM_NGPL,
-	PK_LICENSE_ENUM_NOSL,
 	PK_LICENSE_ENUM_NETCDF,
 	PK_LICENSE_ENUM_NETSCAPE,
+	PK_LICENSE_ENUM_NEWMAT,
+	PK_LICENSE_ENUM_NGPL,
 	PK_LICENSE_ENUM_NOKIA,
+	PK_LICENSE_ENUM_NOSL,
+	PK_LICENSE_ENUM_NOWEB,
+	PK_LICENSE_ENUM_OAL,
+	PK_LICENSE_ENUM_OFSFDL,
 	PK_LICENSE_ENUM_OPENLDAP,
 	PK_LICENSE_ENUM_OPENPBS,
+	PK_LICENSE_ENUM_OPENSSL,
+	PK_LICENSE_ENUM_OREILLY,
 	PK_LICENSE_ENUM_OSL_1_DOT_0,
 	PK_LICENSE_ENUM_OSL_1_DOT_1,
 	PK_LICENSE_ENUM_OSL_2_DOT_0,
+	PK_LICENSE_ENUM_OSL_2_DOT_1,
 	PK_LICENSE_ENUM_OSL_3_DOT_0,
-	PK_LICENSE_ENUM_OPENSSL,
-	PK_LICENSE_ENUM_OREILLY,
 	PK_LICENSE_ENUM_PHORUM,
 	PK_LICENSE_ENUM_PHP,
+	PK_LICENSE_ENUM_PLEXUS,
+	PK_LICENSE_ENUM_PSUTILS,
 	PK_LICENSE_ENUM_PUBLIC_DOMAIN,
+	PK_LICENSE_ENUM_PUBLIC_USE,
 	PK_LICENSE_ENUM_PYTHON,
+	PK_LICENSE_ENUM_QHULL,
 	PK_LICENSE_ENUM_QPL,
+	PK_LICENSE_ENUM_RICEBSD,
 	PK_LICENSE_ENUM_RPSL,
 	PK_LICENSE_ENUM_RUBY,
+	PK_LICENSE_ENUM_SAXPATH,
+	PK_LICENSE_ENUM_SCEA,
+	PK_LICENSE_ENUM_SCRIP,
 	PK_LICENSE_ENUM_SENDMAIL,
+	PK_LICENSE_ENUM_SISSL,
 	PK_LICENSE_ENUM_SLEEPYCAT,
 	PK_LICENSE_ENUM_SLIB,
-	PK_LICENSE_ENUM_SISSL,
+	PK_LICENSE_ENUM_SNIA,
 	PK_LICENSE_ENUM_SPL,
 	PK_LICENSE_ENUM_TCL,
+	PK_LICENSE_ENUM_TMATE,
+	PK_LICENSE_ENUM_TPL,
 	PK_LICENSE_ENUM_UCD,
 	PK_LICENSE_ENUM_VIM,
 	PK_LICENSE_ENUM_VNLSL,
+	PK_LICENSE_ENUM_VOSTROM,
 	PK_LICENSE_ENUM_VSL,
 	PK_LICENSE_ENUM_W3C,
+	PK_LICENSE_ENUM_WEBMIN,
+	PK_LICENSE_ENUM_WTFPL,
 	PK_LICENSE_ENUM_WXWIDGETS,
+	PK_LICENSE_ENUM_XEROX,
 	PK_LICENSE_ENUM_XINETD,
+	PK_LICENSE_ENUM_YPLV1_DOT_1,
 	PK_LICENSE_ENUM_ZEND,
+	PK_LICENSE_ENUM_ZLIB,
+	PK_LICENSE_ENUM_ZLIB_WITH_ACKNOWLEDGEMENT,
 	PK_LICENSE_ENUM_ZPLV1_DOT_0,
 	PK_LICENSE_ENUM_ZPLV2_DOT_0,
 	PK_LICENSE_ENUM_ZPLV2_DOT_1,
-	PK_LICENSE_ENUM_ZLIB,
-	PK_LICENSE_ENUM_ZLIB_WITH_ACK,
-	PK_LICENSE_ENUM_CDL,
-	PK_LICENSE_ENUM_FBSDDL,
-	PK_LICENSE_ENUM_GFDL,
-	PK_LICENSE_ENUM_IEEE,
-	PK_LICENSE_ENUM_OFSFDL,
-	PK_LICENSE_ENUM_OPEN_PUBLICATION,
-	PK_LICENSE_ENUM_CC_BY,
-	PK_LICENSE_ENUM_CC_BY_SA,
-	PK_LICENSE_ENUM_CC_BY_ND,
-	PK_LICENSE_ENUM_DSL,
-	PK_LICENSE_ENUM_FREE_ART,
-	PK_LICENSE_ENUM_OFL,
-	PK_LICENSE_ENUM_UTOPIA,
-	PK_LICENSE_ENUM_ARPHIC,
-	PK_LICENSE_ENUM_BAEKMUK,
-	PK_LICENSE_ENUM_BITSTREAM_VERA,
-	PK_LICENSE_ENUM_LUCIDA,
-	PK_LICENSE_ENUM_MPLUS,
-	PK_LICENSE_ENUM_STIX,
-	PK_LICENSE_ENUM_XANO,
-	PK_LICENSE_ENUM_VOSTROM,
-	PK_LICENSE_ENUM_XEROX,
-	PK_LICENSE_ENUM_RICEBSD,
-	PK_LICENSE_ENUM_QHULL,
 	PK_LICENSE_ENUM_UNKNOWN
 } PkLicenseEnum;
 
@@ -555,7 +621,20 @@ typedef enum {
 	PK_MEDIA_TYPE_ENUM_UNKNOWN
 } PkMediaTypeEnum;
 
+/**
+ * PkAuthorizeEnum:
+ *
+ * The authorization result
+ **/
+typedef enum {
+	PK_AUTHORIZE_ENUM_YES,
+	PK_AUTHORIZE_ENUM_NO,
+	PK_AUTHORIZE_ENUM_INTERACTIVE,
+	PK_AUTHORIZE_ENUM_UNKNOWN
+} PkAuthorizeEnum;
+
 /* general */
+void		 pk_enum_test				(gpointer	 user_data);
 guint		 pk_enum_find_value			(const PkEnumMatch *table,
 							 const gchar	*string)
 							 G_GNUC_WARN_UNUSED_RESULT;
@@ -611,6 +690,9 @@ const gchar	*pk_distro_upgrade_enum_to_text		(PkDistroUpgradeEnum upgrade);
 PkMediaTypeEnum  pk_media_type_enum_from_text		(const gchar	*media_type);
 const gchar	*pk_media_type_enum_to_text		(PkMediaTypeEnum media_type);
 
+PkAuthorizeEnum  pk_authorize_type_enum_from_text	(const gchar	*auth_type);
+const gchar	*pk_authorize_type_enum_to_text		(PkAuthorizeEnum auth_type);
+
 G_END_DECLS
 
 #endif /* __PK_ENUM_H */
