@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -542,14 +542,11 @@ pk_obj_list_to_file (PkObjList *list, const gchar *filename)
 	GString *string;
 	gboolean ret = TRUE;
 	GError *error = NULL;
-	PkObjListFreeFunc func_free;
 	PkObjListToStringFunc func_to_string;
 
 	g_return_val_if_fail (PK_IS_OBJ_LIST (list), FALSE);
 	g_return_val_if_fail (list->priv->func_to_string != NULL, FALSE);
-	g_return_val_if_fail (list->priv->func_free != NULL, FALSE);
 
-	func_free = list->priv->func_free;
 	func_to_string = list->priv->func_to_string;
 
 	/* generate data */
