@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -54,7 +54,7 @@ main (int argc, char **argv)
 
 	g_type_init ();
 	test = egg_test_init ();
-	egg_debug_init (TRUE);
+	egg_debug_init (&argc, &argv);
 
 	/* tests go here */
 	egg_string_test (test);
