@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -248,6 +248,7 @@ pk_task_list_item_create (PkTaskList *tlist, const gchar *tid)
 		pk_task_list_item_free (item);
 		return NULL;
 	}
+	pk_client_set_use_buffer (item->monitor, TRUE, NULL);
 	pk_client_get_role (item->monitor, &item->role, &item->text, NULL);
 	pk_client_get_status (item->monitor, &item->status, NULL);
 
