@@ -22,6 +22,8 @@
 #define CLIENT_H
 
 #include <QtCore>
+#include <QDBusReply>
+#include <bitfield.h>
 
 namespace PackageKit {
 
@@ -82,44 +84,55 @@ public:
 	 * \sa getActions
 	 */
 	typedef enum {
-		ActionCancel		 = 0x00000001,
-		ActionGetDepends	 = 0x00000002,
-		ActionGetDetails	 = 0x00000004,
-		ActionGetFiles		 = 0x00000008,
-		ActionGetPackages	 = 0x00000010,
-		ActionGetRepoList	 = 0x00000020,
-		ActionGetRequires	 = 0x00000040,
-		ActionGetUpdateDetail	 = 0x00000080,
-		ActionGetUpdates	 = 0x00000100,
-		ActionInstallFiles	 = 0x00000200,
-		ActionInstallPackages	 = 0x00000400,
-		ActionInstallSignature	 = 0x00000800,
-		ActionRefreshCache	 = 0x00001000,
-		ActionRemovePackages	 = 0x00002000,
-		ActionRepoEnable	 = 0x00004000,
-		ActionRepoSetData	 = 0x00008000,
-		ActionResolve		 = 0x00010000,
-		ActionRollback		 = 0x00020000,
-		ActionSearchDetails	 = 0x00040000,
-		ActionSearchFile	 = 0x00080000,
-		ActionSearchGroup	 = 0x00100000,
-		ActionSearchName	 = 0x00200000,
-		ActionUpdatePackages	 = 0x00400000,
-		ActionUpdateSystem	 = 0x00800000,
-		ActionWhatProvides	 = 0x01000000,
-		ActionAcceptEula	 = 0x02000000,
-		ActionDownloadPackages	 = 0x04000000,
-		ActionGetDistroUpgrades	 = 0x08000000,
-		ActionGetCategories	 = 0x10000000,
-		ActionGetOldTransactions = 0x20000000,
-		UnknownAction		 = 0x40000000
+		UnknownAction,
+		ActionCancel,
+		ActionGetDepends,
+		ActionGetDetails,
+		ActionGetFiles,
+		ActionGetPackages,
+		ActionGetRepoList,
+		ActionGetRequires,
+		ActionGetUpdateDetail,
+		ActionGetUpdates,
+		ActionInstallFiles,
+		ActionInstallPackages,
+		ActionInstallSignature,
+		ActionRefreshCache,
+		ActionRemovePackages,
+		ActionRepoEnable,
+		ActionRepoSetData,
+		ActionResolve,
+		ActionRollback,
+		ActionSearchDetails,
+		ActionSearchFile,
+		ActionSearchGroup,
+		ActionSearchName,
+		ActionUpdatePackages,
+		ActionUpdateSystem,
+		ActionWhatProvides,
+		ActionAcceptEula,
+		ActionDownloadPackages,
+		ActionGetDistroUpgrades,
+		ActionGetCategories,
+		ActionGetOldTransactions,
+		ActionSimulateInstallFiles,
+		ActionSimulateInstallPackages,
+		ActionSimulateRemovePackages,
+		ActionSimulateUpdatePackages
 	} Action;
-	Q_DECLARE_FLAGS(Actions, Action);
+	typedef Bitfield Actions;
+
+	/**
+	 * Returns all the actions supported by the current backend
+	 * This function is DEPRECATED and will be removed in a
+	 * future release, use \sa actions() instead.
+	 */
+	Actions Q_DECL_DEPRECATED getActions() const;
 
 	/**
 	 * Returns all the actions supported by the current backend
 	 */
-	Actions getActions();
+	Actions actions() const;
 
 	/**
 	 * Holds a backend's detail
@@ -134,51 +147,76 @@ public:
 	/**
 	 * Gets the current backend's details
 	 * \return a BackendDetail struct holding the backend's details. You have to free this structure.
+	 * This method is DEPRECATED use backendAuthor(), backendName()
+	 * and backendDescription() instead.
 	 */
-	BackendDetail getBackendDetail();
+	BackendDetail Q_DECL_DEPRECATED getBackendDetail() const;
+
+	/**
+	 * The backend name, e.g. "yum".
+	 */
+	QString backendName() const;
+
+	/**
+	 * The backend description, e.g. "Yellow Dog Update Modifier".
+	 */
+	QString backendDescription() const;
+
+	/**
+	 * The backend author, e.g. "Joe Bloggs <joe@blogs.com>"
+	 */
+	QString backendAuthor() const;
 
 	/**
 	 * Describes the different filters
 	 */
 	typedef enum {
-		NoFilter		 = 0x0000001,
-		FilterInstalled		 = 0x0000002,
-		FilterNotInstalled	 = 0x0000004,
-		FilterDevelopment	 = 0x0000008,
-		FilterNotDevelopment	 = 0x0000010,
-		FilterGui		 = 0x0000020,
-		FilterNotGui		 = 0x0000040,
-		FilterFree		 = 0x0000080,
-		FilterNotFree		 = 0x0000100,
-		FilterVisible		 = 0x0000200,
-		FilterNotVisible	 = 0x0000400,
-		FilterSupported		 = 0x0000800,
-		FilterNotSupported	 = 0x0001000,
-		FilterBasename		 = 0x0002000,
-		FilterNotBasename	 = 0x0004000,
-		FilterNewest		 = 0x0008000,
-		FilterNotNewest		 = 0x0010000,
-		FilterArch		 = 0x0020000,
-		FilterNotArch		 = 0x0040000,
-		FilterSource		 = 0x0080000,
-		FilterNotSource		 = 0x0100000,
-		FilterCollections	 = 0x0200000,
-		FilterNotCollections	 = 0x0400000,
-		FilterApplication	 = 0x0800000,
-		FilterNotApplication	 = 0x1000000,
-		UnknownFilter		 = 0x2000000
+		UnknownFilter		 = 0x0000001,
+		NoFilter		 = 0x0000002,
+		FilterInstalled		 = 0x0000004,
+		FilterNotInstalled	 = 0x0000008,
+		FilterDevelopment	 = 0x0000010,
+		FilterNotDevelopment	 = 0x0000020,
+		FilterGui		 = 0x0000040,
+		FilterNotGui		 = 0x0000080,
+		FilterFree		 = 0x0000100,
+		FilterNotFree		 = 0x0000200,
+		FilterVisible		 = 0x0000400,
+		FilterNotVisible	 = 0x0000800,
+		FilterSupported		 = 0x0001000,
+		FilterNotSupported	 = 0x0002000,
+		FilterBasename		 = 0x0004000,
+		FilterNotBasename	 = 0x0008000,
+		FilterNewest		 = 0x0010000,
+		FilterNotNewest		 = 0x0020000,
+		FilterArch		 = 0x0040000,
+		FilterNotArch		 = 0x0080000,
+		FilterSource		 = 0x0100000,
+		FilterNotSource		 = 0x0200000,
+		FilterCollections	 = 0x0400000,
+		FilterNotCollections	 = 0x0800000,
+		FilterApplication	 = 0x1000000,
+		FilterNotApplication	 = 0x2000000,
+		FilterLast		 = 0x4000000
 	} Filter;
-	Q_DECLARE_FLAGS(Filters, Filter);
+	Q_DECLARE_FLAGS(Filters, Filter)
+
+	/**
+	 * Returns the filters supported by the current backend
+	 * This method is DEPRECATED use \sa filters() instead.
+	 */
+	Filters Q_DECL_DEPRECATED getFilters() const;
 
 	/**
 	 * Returns the filters supported by the current backend
 	 */
-	Filters getFilters();
+	Filters filters() const;
 
 	/**
 	 * Describes the different groups
 	 */
 	typedef enum {
+		UnknownGroup,
 		GroupAccessibility,
 		GroupAccessories,
 		GroupAdminTools,
@@ -212,42 +250,71 @@ public:
 		GroupElectronics,
 		GroupCollections,
 		GroupVendor,
-		GroupNewest,
-		UnknownGroup
+		GroupNewest
 	} Group;
 	typedef QSet<Group> Groups;
 
 	/**
 	 * Returns the groups supported by the current backend
+	 * This method is DEPRECATED use \sa groups() instead.
 	 */
-	Groups getGroups();
+	Groups Q_DECL_DEPRECATED getGroups() const;
+
+	/**
+	 * Returns the groups supported by the current backend
+	 */
+	Groups groups() const;
+
+	/**
+	 * Set when the backend is locked and native tools would fail.
+	 */
+	bool locked() const;
+
+	/**
+	 * Returns a list containing the MIME types supported by the current backend
+	 * This method is DEPRECATED use \sa mimeTypes() instead.
+	 */
+	QStringList Q_DECL_DEPRECATED getMimeTypes() const;
 
 	/**
 	 * Returns a list containing the MIME types supported by the current backend
 	 */
-	QStringList getMimeTypes();
+	QStringList mimeTypes() const;
 
 	/**
 	 * Describes the current network state
 	 */
 	typedef enum {
+		UnknownNetworkState,
 		NetworkOffline,
 		NetworkOnline,
 		NetworkWired,
 		NetworkWifi,
-		NetworkMobile,
-		UnknownNetworkState
+		NetworkMobile
 	} NetworkState;
 
 	/**
 	 * Returns the current network state
+	 * This method is DEPRECATED use \sa networkState() instead.
 	 */
-	NetworkState getNetworkState();
+	NetworkState Q_DECL_DEPRECATED getNetworkState() const;
+
+	/**
+	 * Returns the current network state
+	 */
+	NetworkState networkState() const;
+
+	/**
+	 * The distribution identifier in the
+	 * distro;version;arch form,
+	 * e.g. "debian;squeeze/sid;x86_64".
+	 */
+	QString distroId() const;
 
 	/**
 	 * Returns the time (in seconds) since the specified \p action
 	 */
-	uint getTimeSinceAction(Action action);
+	uint getTimeSinceAction(Action action) const;
 
 	/**
 	 * Returns the list of current transactions
@@ -256,13 +323,36 @@ public:
 
 	/**
 	 * Sets a global locale for all the transactions to be created
+	 * \warning THIS FUNCTION IS DEPRECATED. It will be removed in a future release.
+	 * Use SetHints("locale=$code") instead.
 	 */
-	void setLocale(const QString& locale);
+	void Q_DECL_DEPRECATED setLocale(const QString& locale);
+
+	/**
+	 * \brief Sets a global hints for all the transactions to be created
+	 *
+	 * This method allows the calling session to set transaction \p hints for
+	 * the package manager which can change as the transaction runs.
+	 *
+	 * This method can be sent before the transaction has been run
+	 * (by using Client::setHints) or whilst it is running
+	 * (by using Transaction::setHints).
+	 * There is no limit to the number of times this
+	 * method can be sent, although some backends may only use the values
+	 * that were set before the transaction was started.
+	 *
+	 * The \p hints can be filled with entries like these
+	 * ('locale=en_GB.utf8','idle=true','interactive=false').
+	 *
+	 * \sa Transaction::setHints
+	 */
+	void setHints(const QString& hints);
+	void setHints(const QStringList& hints);
 
 	/**
 	 * Sets a proxy to be used for all the network operations
 	 */
-	void setProxy(const QString& http_proxy, const QString& ftp_proxy);
+	bool setProxy(const QString& http_proxy, const QString& ftp_proxy);
 
 	/**
 	 * \brief Tells the daemon that the system state has changed, to make it reload its cache
@@ -281,8 +371,8 @@ public:
 	 * Describes a signature type
 	 */
 	typedef enum {
-		SignatureGpg,
-		UnknownSignatureType
+		UnknownSignatureType,
+		SignatureGpg
 	} SignatureType;
 
 	/**
@@ -308,19 +398,21 @@ public:
 	 * \sa whatProvides
 	 */
 	typedef enum {
+		UnknownProvidesType,
 		ProvidesAny,
 		ProvidesModalias,
 		ProvidesCodec,
 		ProvidesMimetype,
 		ProvidesFont,
 		ProvidesHardwareDriver,
-		UnknownProvidesType
+		ProvidesPostscriptDriver
 	} ProvidesType;
 
 	/**
 	 * Lists the different types of error
 	 */
 	typedef enum {
+		UnknownErrorType,
 		ErrorOom,
 		ErrorNoNetwork,
 		ErrorNotSupported,
@@ -368,13 +460,25 @@ public:
 		ErrorIncompatibleArchitecture,
 		ErrorNoSpaceOnDevice,
 		ErrorMediaChangeRequired,
-		UnknownErrorType
+		ErrorNotAuthorized,
+		ErrorUpdateNotFound,
+		ErrorCannotInstallRepoUnsigned,
+		ErrorCannotUpdateRepoUnsigned,
+		ErrorCannotGetFilelist,
+		ErrorCannotGetRequires,
+		ErrorCannotDisableRepository,
+		ErrorRestrictedDownload,
+		ErrorPackageFailedToConfigure,
+		ErrorPackageFailedToBuild,
+		ErrorPackageFailedToInstall,
+		ErrorPackageFailedToRemove
 	} ErrorType;
 
 	/**
 	 * Describes a message's type
 	 */
 	typedef enum {
+		UnknownMessageType,
 		MessageBrokenMirror,
 		MessageConnectionRefused,
 		MessageParameterInvalid,
@@ -387,7 +491,8 @@ public:
 		MessageCouldNotFindPackage,
 		MessageConfigFilesChanged,
 		MessagePackageAlreadyInstalled,
-		UnknownMessageType
+		MessageAutoremoveIgnored,
+		MessageRepoMetadataDownloadFailed,
 	} MessageType;
 
 	/**
@@ -408,43 +513,59 @@ public:
 	 * Describes a restart type
 	 */
 	typedef enum {
+		UnknownRestartType,
 		RestartNone,
 		RestartApplication,
 		RestartSession,
 		RestartSystem,
-		UnknownRestartType
+		RestartSecuritySession,
+		RestartSecuritySystem,
 	} RestartType;
 
 	/**
 	 * Describes an update's state
 	 */
 	typedef enum {
+		UnknownUpdateState,
 		UpdateStable,
 		UpdateUnstable,
-		UpdateTesting,
-		UnknownUpdateState
+		UpdateTesting
 	} UpdateState;
 
 	/**
 	 * Describes an distro upgrade state
 	 */
 	typedef enum {
+		UnknownDistroUpgrade,
 		DistroUpgradeStable,
-		DistroUpgradeUnstable,
-		UnknownDistroUpgrade
+		DistroUpgradeUnstable
 	} DistroUpgradeType;
 
 	/**
 	 * Describes an error at the daemon level (for example, PackageKit crashes or is unreachable)
+	 *
+	 * \sa Client::error
+	 * \sa Transaction::error
 	 */
 	typedef enum {
-		DaemonUnreachable,
-		UnkownDaemonError
+		NoError = 0,
+		UnkownError,
+		ErrorFailed,
+		ErrorFailedAuth,
+		ErrorNoTid,
+		ErrorAlreadyTid,
+		ErrorRoleUnkown,
+		ErrorCannotStartDaemon,
+		ErrorInvalidInput,
+		ErrorInvalidFile,
+		ErrorFunctionNotSupported,
+		ErrorDaemonUnreachable
 	} DaemonError;
+
 	/**
 	 * Returns the last daemon error that was caught
 	 */
-	DaemonError getLastError();
+	DaemonError getLastError() const;
 
 	/**
 	 * Describes a software update
@@ -473,6 +594,21 @@ public:
 		QDateTime updated;
 	} UpdateInfo;
 
+	/**
+	 * Returns the major version number.
+	 */
+	uint versionMajor() const;
+
+	/**
+	 * The minor version number.
+	 */
+	uint versionMinor() const;
+
+	/**
+	 * The micro version number.
+	 */
+	uint versionMicro() const;
+
 	// Transaction functions
 
 	/**
@@ -513,8 +649,8 @@ public:
 	 * \sa Transaction::package
 	 *
 	 */
-	Transaction* getDepends(const QList<Package*>& packages, Filters filters = NoFilter, bool recursive = true);
-	Transaction* getDepends(Package* package, Filters filters = NoFilter, bool recursive = true);
+	Transaction* getDepends(const QList<Package*>& packages, Filters filters, bool recursive);
+	Transaction* getDepends(Package* package, Filters filters , bool recursive);
 
 	/**
 	 * Gets more details about the given \p packages
@@ -557,8 +693,8 @@ public:
 	 * The search can be limited using the \p filters parameter. The recursive flag is used to tell
 	 * if the package manager should also search for the package requiring the resulting packages.
 	 */
-	Transaction* getRequires(const QList<Package*>& packages, Filters filters = NoFilter, bool recursive = true);
-	Transaction* getRequires(Package* package, Filters filters = NoFilter, bool recursive = true);
+	Transaction* getRequires(const QList<Package*>& packages, Filters filters, bool recursive);
+	Transaction* getRequires(Package* package, Filters filters, bool recursive);
 
 	/**
 	 * Retrieves more details about the update for the given \p packages
@@ -581,16 +717,18 @@ public:
 	/**
 	 * \brief Installs the local packages \p files
 	 *
-	 * \p trusted indicate if the packages are signed by a trusted authority
+	 * \p only_trusted indicate if the packages are signed by a trusted authority
 	 */
-	Transaction* installFiles(const QStringList& files, bool trusted);
-	Transaction* installFile(const QString& file, bool trusted);
+	Transaction* installFiles(const QStringList& files, bool only_trusted);
+	Transaction* installFile(const QString& file, bool only_trusted);
 
 	/**
 	 * Install the given \p packages
+	 *
+	 * \p only_trusted indicates if we should allow installation of untrusted packages (requires a different authorization)
 	 */
-	Transaction* installPackages(const QList<Package*>& packages);
-	Transaction* installPackage(Package* p);
+	Transaction* installPackages(bool only_trusted, const QList<Package*>& packages);
+	Transaction* installPackage(bool only_trusted, Package* p);
 
 	/**
 	 * \brief Installs a signature
@@ -608,11 +746,11 @@ public:
 	 * \brief Removes the given \p packages
 	 *
 	 * \p allow_deps if the package manager has the right to remove other packages which depend on the
-	 * pacakges to be removed. \p autoremove tells the package manager to remove all the package which
+	 * packages to be removed. \p autoremove tells the package manager to remove all the package which
 	 * won't be needed anymore after the packages are uninstalled.
 	 */
-	Transaction* removePackages(const QList<Package*>& packages, bool allow_deps = false, bool autoremove = false);
-	Transaction* removePackage(Package* p, bool allow_deps = false, bool autoremove = false);
+	Transaction* removePackages(const QList<Package*>& packages, bool allow_deps, bool autoremove);
+	Transaction* removePackage(Package* p, bool allow_deps, bool autoremove);
 
 	/**
 	 * Activates or disables a repository
@@ -643,6 +781,7 @@ public:
 	 * \p filters can be used to restrict the returned packages
 	 */
 	Transaction* searchFile(const QString& search, Filters filters = NoFilter);
+	Transaction* searchFile(const QStringList& search, Filters filters = NoFilter);
 
 	/**
 	 * \brief Search in the packages details
@@ -675,42 +814,85 @@ public:
 	 */
 	Package* searchFromDesktopFile(const QString& path);
 
+	/**
+	 * \brief Simulates an installation of \p files.
+	 *
+	 * You should call this method before installing \p files
+	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
+	 *        REINSTALLING or OBSOLETING status.
+	 */
+	Transaction* simulateInstallFiles(const QStringList& files);
+	Transaction* simulateInstallFile(const QString& file);
+
+	/**
+	 * \brief Simulates an installation of \p packages.
+	 *
+	 * You should call this method before installing \p packages
+	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
+	 *        REINSTALLING or OBSOLETING status.
+	 */
+	Transaction* simulateInstallPackages(const QList<Package*>& packages);
+	Transaction* simulateInstallPackage(Package* package);
+
+	/**
+	 * \brief Simulates a removal of \p packages.
+	 *
+	 * You should call this method before removing \p packages
+	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
+	 *        REINSTALLING or OBSOLETING status.
+	 */
+	Transaction* simulateRemovePackages(const QList<Package*>& packages);
+	Transaction* simulateRemovePackage(Package* package);
+
+	/**
+	 * \brief Simulates an update of \p packages.
+	 *
+	 * You should call this method before updating \p packages
+	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
+	 *        REINSTALLING or OBSOLETING status.
+	 */
+	Transaction* simulateUpdatePackages(const QList<Package*>& packages);
+	Transaction* simulateUpdatePackage(Package* package);
+
 	/**
 	 * Update the given \p packages
 	 */
-	Transaction* updatePackages(const QList<Package*>& packages);
-	Transaction* updatePackage(Package* package);
+	Transaction* updatePackages(bool only_trusted, const QList<Package*>& packages);
+	Transaction* updatePackage(bool only_trusted, Package* package);
 
 	/**
 	 * Updates the whole system
+	 *
+	 * \p only_trusted indicates if this transaction is only allowed to install trusted packages
 	 */
-	Transaction* updateSystem();
+	Transaction* updateSystem(bool only_trusted);
 
 	/**
 	 * Searchs for a package providing a file/a mimetype
 	 */
 	Transaction* whatProvides(ProvidesType type, const QString& search, Filters filters = NoFilter);
+	Transaction* whatProvides(ProvidesType type, const QStringList& search, Filters filters = NoFilter);
 
 Q_SIGNALS:
 	/**
-	 * \brief Emitted when PolicyKit doesn't grant the necessary permissions to the user
-	 *
-	 * \p action is the PolicyKit name of the action
+	 * This signal is emitted when a property on the interface changes.
 	 */
-	void authError(const QString& action);
+	void changed();
 
 	/**
-	 * Emitted when the PackageKit daemon is not reachable anymore
+	 * Emitted when the PackageKit daemon sends an error
 	 */
-	void daemonError(PackageKit::Client::DaemonError e);
+	void error(PackageKit::Client::DaemonError e);
 
 	/**
 	 * Emitted when the daemon's locked state changes
+	 * This signal is DEPRECATED use \sa changed() and \sa locked() instead.
 	 */
 	void locked(bool locked);
 
 	/**
 	 * Emitted when the network state changes
+	 * This signal is DEPRECATED use \sa changed() and \sa networkState() instead.
 	 */
 	void networkStateChanged(PackageKit::Client::NetworkState state);
 
@@ -741,8 +923,10 @@ private:
 	static Client* m_instance;
 	friend class ClientPrivate;
 	ClientPrivate* d;
+
+	void setLastError (DaemonError e);
+	void setTransactionError (Transaction* t, DaemonError e);
 };
-Q_DECLARE_OPERATORS_FOR_FLAGS(Client::Actions)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Client::Filters)
 
 } // End namespace PackageKit
