@@ -84,6 +84,7 @@ public:
 	 * Describes the state of a package
 	 */
 	typedef enum {
+		UnknownState,
 		StateInstalled,
 		StateAvailable,
 		StateLow,
@@ -102,7 +103,10 @@ public:
 		StateCollectionInstalled,
 		StateCollectionAvailable,
 		StateFinished,
-		UnknownState
+		StateReinstalling,
+		StateDowngrading,
+		StatePreparing,
+		StateDecompressing
 	} State;
 	/**
 	 * Returns the package's state
@@ -113,6 +117,7 @@ public:
 	 * Describes a package's license
 	 */
 	typedef enum {
+		UnknownLicense,
 		LicenseGlide,
 		LicenseAfl,
 		LicenseAmpasBsd,
@@ -237,8 +242,7 @@ public:
 		LicenseVostrom,
 		LicenseXerox,
 		LicenseRicebsd,
-		LicenseQhull,
-		UnknownLicense
+		LicenseQhull
 	} License;
 
 	/**
@@ -307,6 +311,13 @@ public:
 	 */
 	Details* details() const;
 
+	/**
+	 * \brief Returns the path to the package icon, if known
+	 *
+	 * \return A QString holding the path to the package icon if known, an empty QString else
+	 */
+	QString iconPath ();
+
 	bool operator==(const Package *package) const;
 
 private:
