@@ -24,7 +24,6 @@
 #include "package.h"
 #include "transactionprivate.h"
 #include "transactionproxy.h"
-#include "polkitclient.h"
 #include "util.h"
 
 using namespace PackageKit;
@@ -40,8 +39,12 @@ Transaction::Transaction(const QString& tid, Client* parent) : QObject(parent)
 	if(!d->p->isValid())
 		qDebug("Error, cannot create transaction proxy");
 
+	d->error = Client::NoError;
+
+	connect(d->p, SIGNAL(Changed()), this, SIGNAL(changed()));
 	connect(d->p, SIGNAL(AllowCancel(bool)), this, SIGNAL(allowCancelChanged(bool)));
 	connect(d->p, SIGNAL(Category(const QString&, const QString&, const QString&, const QString&, const QString&)), this, SIGNAL(category(const QString&, const QString&, const QString&, const QString&, const QString&)));
+	connect(d->p, SIGNAL(Destroy()), this, SIGNAL(destroy()));
 	connect(d->p, SIGNAL(Details(const QString&, const QString&, const QString&, const QString&, const QString&, qulonglong)), d, SLOT(details(const QString&, const QString&, const QString&, const QString&, const QString&, qulonglong)));
 	connect(d->p, SIGNAL(DistroUpgrade(const QString&, const QString&, const QString&)), d, SLOT(distroUpgrade(const QString&, const QString&, const QString&)));
 	connect(d->p, SIGNAL(ErrorCode(const QString&, const QString&)), d, SLOT(errorCode(const QString&, const QString&)));
@@ -69,14 +72,13 @@ Transaction::Transaction(const QString& tid, const QString& timespec, bool succe
 	d->tid = tid;
 	d->timespec = QDateTime::fromString(timespec, Qt::ISODate);
 	d->succeeded = succeeded;
-	RoleInfo r;
-	r.action = (Client::Action)Util::enumFromString<Client>(role, "Action", "Action");
-	d->role = r;
+	d->role = (Client::Action)Util::enumFromString<Client>(role, "Action", "Action");
 	d->duration = duration;
 	d->data = data;
 	d->uid = uid;
 	d->cmdline = cmdline;
 	d->client = parent;
+	d->error = Client::NoError;
 }
 
 Transaction::~Transaction()
@@ -89,60 +91,76 @@ QString Transaction::tid() const
 	return d->tid;
 }
 
-bool Transaction::allowCancel()
+Client::DaemonError Transaction::error () const
 {
-	return d->p->GetAllowCancel().value();
+	return d->error;
 }
 
-bool Transaction::callerActive()
+bool Transaction::allowCancel() const
 {
-	return d->p->IsCallerActive().value();
+	return d->p->allowCancel ();
+}
+
+bool Transaction::callerActive() const
+{
+	return d->p->callerActive ();
 }
 
 void Transaction::cancel()
 {
-	if (!d->p->Cancel().isValid ()) {
-		// Cancel failed, maybe it's not our transaction and we need authorization
-		if(!PolkitClient::instance()->getAuth(AUTH_CANCEL_FOREIGN)) {
-			// FIXME : should warn somehow here
-			qDebug () << "Authorization to cancel foreign failed";
-			return;
-		}
-
-		d->p->Cancel();
+	QDBusReply<void> r = d->p->Cancel ();
+	if (!r.isValid ()) {
+		d->error = Util::errorFromString (r.error ().message ());
 	}
 }
 
-Package* Transaction::lastPackage()
+Package* Transaction::lastPackage() const
 {
-	return new Package(d->p->GetPackageLast().value());
+	return new Package(d->p->lastPackage ());
 }
 
-Transaction::ProgressInfo Transaction::progress()
+Transaction::ProgressInfo Transaction::progress() const
 {
-	uint p, subp, elaps, rem;
-	p = d->p->GetProgress(subp, elaps, rem);
 	ProgressInfo i;
-	i.percentage = p;
-	i.subpercentage = subp;
-	i.elapsed = elaps;
-	i.remaining = rem;
+	i.percentage = d->p->percentage ();
+	i.subpercentage = d->p->subpercentage ();
+	i.elapsed = d->p->elapsedTime ();
+	i.remaining = d->p->remainingTime ();
 
 	return i;
 }
 
-Transaction::RoleInfo Transaction::role()
+uint Transaction::percentage() const
+{
+	return d->p->percentage ();
+}
+
+uint Transaction::subpercentage() const
+{
+	return d->p->subpercentage ();
+}
+
+uint Transaction::elapsedTime() const
+{
+	return d->p->elapsedTime ();
+}
+
+uint Transaction::remainingTime() const
+{
+	return d->p->remainingTime ();
+}
+
+uint Transaction::speed() const
+{
+	return d->p->speed ();
+}
+
+Client::Action Transaction::role() const
 {
 	if(d->oldtrans)
 		return d->role;
 
-	QString terms;
-	RoleInfo i;
-
-	i.action = (Client::Action) Util::enumFromString<Client>(d->p->GetRole(terms).value(), "Action", "Action");
-	i.terms = terms.split(";");
-
-	return i;
+	return (Client::Action) Util::enumFromString<Client>(d->p->role (), "Action", "Action");
 }
 
 void Transaction::setLocale(const QString& locale)
@@ -150,37 +168,50 @@ void Transaction::setLocale(const QString& locale)
 	d->p->SetLocale(locale);
 }
 
-Transaction::Status Transaction::status()
+void Transaction::setHints(const QStringList& hints)
 {
-	return (Transaction::Status) Util::enumFromString<Transaction>(d->p->GetStatus().value(), "Status", "Status");
+	d->p->SetHints(hints);
 }
 
-QDateTime Transaction::timespec()
+void Transaction::setHints(const QString& hints)
+{
+	setHints(QStringList() << hints);
+}
+
+Transaction::Status Transaction::status() const
+{
+	return (Transaction::Status) Util::enumFromString<Transaction>(d->p->status (), "Status", "Status");
+}
+
+QDateTime Transaction::timespec() const
 {
 	return d->timespec;
 }
 
-bool Transaction::succeeded()
+bool Transaction::succeeded() const
 {
 	return d->succeeded;
 }
 
-uint Transaction::duration()
+uint Transaction::duration() const
 {
 	return d->duration;
 }
 
-QString Transaction::data()
+QString Transaction::data() const
 {
 	return d->data;
 }
 
-uint Transaction::uid()
+uint Transaction::uid() const
 {
+	if(d->p) {
+		return d->p->uid();
+	}
 	return d->uid;
 }
 
-QString Transaction::cmdline()
+QString Transaction::cmdline() const
 {
 	return d->cmdline;
 }
