@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # Copyright (C) 2007 Tim Lauridsen <timlau@fedoraproject.org>
 
@@ -55,6 +55,7 @@ class PackageKitBaseBackend:
         self._locked = False
         self.lang = "C"
         self.has_network = False
+        self.background = False
         self.percentage_old = 0
         self.sub_percentage_old = 0
 
@@ -71,6 +72,13 @@ class PackageKitBaseBackend:
         except KeyError, e:
             print "Error: No NETWORK envp"
 
+        # try to get BACKGROUND state
+        try:
+            if os.environ['BACKGROUND'] == 'TRUE':
+                self.background = True
+        except KeyError, e:
+            print "Error: No BACKGROUND envp"
+
     def doLock(self):
         ''' Generic locking, overide and extend in child class'''
         self._locked = True
@@ -148,8 +156,7 @@ class PackageKitBaseBackend:
         @param id: the localised label of the media
         @param text: the localised text describing the media
         '''
-        print >> sys.stdout, "media-change-required\t%s\t%s\t%s" % (mtype, id,
-                                                                    text)
+        print >> sys.stdout, "media-change-required\t%s\t%s\t%s" % (mtype, id, text)
         sys.stdout.flush()
 
     def distro_upgrade(self, dtype, name, summary):
@@ -176,7 +183,7 @@ class PackageKitBaseBackend:
         @param repoid: The repo id tag
         @param state: false is repo is disabled else true.
         '''
-        print >> sys.stdout, "repo-detail\t%s\t%s\t%s" % (repoid, name, state)
+        print >> sys.stdout, "repo-detail\t%s\t%s\t%s" % (repoid, name, _bool_to_text(state))
         sys.stdout.flush()
 
     def data(self, data):
@@ -288,28 +295,28 @@ class PackageKitBaseBackend:
 # Backend Action Methods
 #
 
-    def search_name(self, filters, key):
+    def search_name(self, filters, values):
         '''
         Implement the {backend}-search-name functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def search_details(self, filters, key):
+    def search_details(self, filters, values):
         '''
         Implement the {backend}-search-details functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def search_group(self, filters, key):
+    def search_group(self, filters, values):
         '''
         Implement the {backend}-search-group functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def search_file(self, filters, key):
+    def search_file(self, filters, values):
         '''
         Implement the {backend}-search-file functionality
         Needed to be implemented in a sub class
@@ -344,28 +351,28 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def what_provides(self, filters, provides_type, search):
+    def what_provides(self, filters, provides_type, values):
         '''
         Implement the {backend}-what-provides functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def update_system(self):
+    def update_system(self, only_trusted):
         '''
         Implement the {backend}-update-system functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def refresh_cache(self):
+    def refresh_cache(self, force):
         '''
         Implement the {backend}-refresh_cache functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def install_packages(self, package_ids):
+    def install_packages(self, only_trusted, package_ids):
         '''
         Implement the {backend}-install functionality
         Needed to be implemented in a sub class
@@ -379,7 +386,7 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def install_files (self, trusted, inst_files):
+    def install_files (self, only_trusted, inst_files):
         '''
         Implement the {backend}-install_files functionality
         Install the package containing the inst_file file
@@ -394,14 +401,14 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def remove_packages(self, allowdep, package_ids):
+    def remove_packages(self, allowdep, autoremove, package_ids):
         '''
         Implement the {backend}-remove functionality
         Needed to be implemented in a sub class
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
-    def update_packages(self, package_ids):
+    def update_packages(self, only_trusted, package_ids):
         '''
         Implement the {backend}-update functionality
         Needed to be implemented in a sub class
@@ -485,6 +492,34 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
+    def simulate_install_files (self, inst_files):
+        '''
+        Implement the {backend}-simulate-install-files functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
+    def simulate_install_packages(self, package_ids):
+        '''
+        Implement the {backend}-simulate-install-packages functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
+    def simulate_remove_packages(self, package_ids):
+        '''
+        Implement the {backend}-simulate-remove-packages functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
+    def simulate_update_packages(self, package_ids):
+        '''
+        Implement the {backend}-simulate-update-packages functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
     def customTracebackHandler(self, tb):
         '''
         Custom Traceback Handler
@@ -514,7 +549,7 @@ class PackageKitBaseBackend:
         elif cmd == 'get-depends':
             filters = args[0]
             package_ids = args[1].split(PACKAGE_IDS_DELIM)
-            recursive = args[2]
+            recursive = _text_to_bool(args[2])
             self.get_depends(filters, package_ids, recursive)
             self.finished()
         elif cmd == 'get-details':
@@ -536,7 +571,7 @@ class PackageKitBaseBackend:
         elif cmd == 'get-requires':
             filters = args[0]
             package_ids = args[1].split(PACKAGE_IDS_DELIM)
-            recursive = args[2]
+            recursive = _text_to_bool(args[2])
             self.get_requires(filters, package_ids, recursive)
             self.finished()
         elif cmd == 'get-update-detail':
@@ -551,13 +586,14 @@ class PackageKitBaseBackend:
             self.get_updates(filters)
             self.finished()
         elif cmd == 'install-files':
-            trusted = args[0]
+            only_trusted = _text_to_bool(args[0])
             files_to_inst = args[1].split(FILENAME_DELIM)
-            self.install_files(trusted, files_to_inst)
+            self.install_files(only_trusted, files_to_inst)
             self.finished()
         elif cmd == 'install-packages':
-            package_ids = args[0].split(PACKAGE_IDS_DELIM)
-            self.install_packages(package_ids)
+            only_trusted = _text_to_bool(args[0])
+            package_ids = args[1].split(PACKAGE_IDS_DELIM)
+            self.install_packages(only_trusted, package_ids)
             self.finished()
         elif cmd == 'install-signature':
             sigtype = args[0]
@@ -566,16 +602,18 @@ class PackageKitBaseBackend:
             self.install_signature(sigtype, key_id, package_id)
             self.finished()
         elif cmd == 'refresh-cache':
-            self.refresh_cache()
+            force = _text_to_bool(args[0])
+            self.refresh_cache(force)
             self.finished()
         elif cmd == 'remove-packages':
-            allowdeps = args[0]
-            package_ids = args[1].split(PACKAGE_IDS_DELIM)
-            self.remove_packages(allowdeps, package_ids)
+            allowdeps = _text_to_bool(args[0])
+            autoremove = _text_to_bool(args[1])
+            package_ids = args[2].split(PACKAGE_IDS_DELIM)
+            self.remove_packages(allowdeps, autoremove, package_ids)
             self.finished()
         elif cmd == 'repo-enable':
             repoid = args[0]
-            state = args[1]
+            state = _text_to_bool(args[1])
             self.repo_enable(repoid, state)
             self.finished()
         elif cmd == 'repo-set-data':
@@ -591,40 +629,42 @@ class PackageKitBaseBackend:
             self.finished()
         elif cmd == 'search-details':
             options = args[0]
-            searchterms = _to_unicode(args[1])
-            self.search_details(options, searchterms)
+            values = _to_unicode(args[1])
+            self.search_details(options, values)
             self.finished()
         elif cmd == 'search-file':
             options = args[0]
-            searchterms = args[1]
-            self.search_file(options, searchterms)
+            values = args[1]
+            self.search_file(options, values)
             self.finished()
         elif cmd == 'search-group':
             options = args[0]
-            searchterms = args[1]
-            self.search_group(options, searchterms)
+            values = args[1]
+            self.search_group(options, values)
             self.finished()
         elif cmd == 'search-name':
             options = args[0]
-            searchterms = _to_unicode(args[1])
-            self.search_name(options, searchterms)
+            values = _to_unicode(args[1])
+            self.search_name(options, values)
             self.finished()
         elif cmd == 'signature-install':
             package = args[0]
             self.repo_signature_install(package)
             self.finished()
         elif cmd == 'update-packages':
-            package_ids = args[0].split(PACKAGE_IDS_DELIM)
-            self.update_packages(package_ids)
+            only_trusted = _text_to_bool(args[0])
+            package_ids = args[1].split(PACKAGE_IDS_DELIM)
+            self.update_packages(only_trusted, package_ids)
             self.finished()
         elif cmd == 'update-system':
-            self.update_system()
+            only_trusted = _text_to_bool(args[0])
+            self.update_system(only_trusted)
             self.finished()
         elif cmd == 'what-provides':
             filters = args[0]
             provides_type = args[1]
-            search = _to_unicode(args[2])
-            self.what_provides(filters, provides_type, search)
+            values = _to_unicode(args[2])
+            self.what_provides(filters, provides_type, values)
             self.finished()
         elif cmd == 'set-locale':
             code = args[0]
@@ -633,6 +673,22 @@ class PackageKitBaseBackend:
         elif cmd == 'get-categories':
             self.get_categories()
             self.finished()
+        elif cmd == 'simulate-install-files':
+            files_to_inst = args[0].split(FILENAME_DELIM)
+            self.simulate_install_files(files_to_inst)
+            self.finished()
+        elif cmd == 'simulate-install-packages':
+            package_ids = args[0].split(PACKAGE_IDS_DELIM)
+            self.simulate_install_packages(package_ids)
+            self.finished()
+        elif cmd == 'simulate-remove-packages':
+            package_ids = args[0].split(PACKAGE_IDS_DELIM)
+            self.simulate_remove_packages(package_ids)
+            self.finished()
+        elif cmd == 'simulate-update-packages':
+            package_ids = args[0].split(PACKAGE_IDS_DELIM)
+            self.simulate_update_packages(package_ids)
+            self.finished()
         else:
             errmsg = "command '%s' is not known" % cmd
             self.error(ERROR_INTERNAL_ERROR, errmsg, exit=False)
@@ -667,12 +723,17 @@ def format_string(text, encoding='utf-8'):
         txt = unicode(text, encoding, errors='replace')
     return text.replace("\n", ";")
 
-def text_to_bool(text):
+def _text_to_bool(text):
     '''Convert a string to a boolean value.'''
     if text.lower() in ["yes", "true"]:
         return True
     return False
 
+def _bool_to_text(value):
+    if value:
+        return "true"
+    return "false"
+
 def get_package_id(name, version, arch, data):
     """Returns a package id."""
     return ";".join((name, version, arch, data))
