@@ -18,7 +18,7 @@ to search for packages, install packages or codecs.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # (c) 2008
 #    Canonical Ltd.
@@ -258,11 +258,11 @@ class PackageKitClient:
         return self._run_transaction("SearchFile", [filters, search],
                                      exit_handler)
 
-    def install_packages(self, packages, exit_handler=None):
+    def install_packages(self, packages, only_trusted=True, exit_handler=None):
         '''Install the packages of the given package ids'''
         package_ids = self._to_package_id_list(packages)
-        return self._run_transaction("InstallPackages", [package_ids], 
-                                     exit_handler)
+        return self._run_transaction("InstallPackages",
+                                     [only_trusted, package_ids], exit_handler)
 
     def update_packages(self, packages, exit_handler=None):
         '''Update the packages of the given package ids'''
@@ -358,9 +358,9 @@ class PackageKitClient:
         return self._run_transaction("GetDistroUpgrades", [],
                                      exit_handler)
 
-    def install_files(self, trusted, files, exit_handler=None):
+    def install_files(self, only_trusted, files, exit_handler=None):
         '''Install the given local packages'''
-        return self._run_transaction("InstallFiles", [trusted, files],
+        return self._run_transaction("InstallFiles", [only_trusted, files],
                                      exit_handler)
 
     def install_signature(self, sig_type, key_id, package_id, 
@@ -381,9 +381,9 @@ class PackageKitClient:
         return self._run_transaction("Rollback", [transaction_id], 
                                      exit_handler)
 
-    def what_provides(self, provides, search, exit_handler=None):
+    def what_provides(self, filters, enum, search, exit_handler=None):
         '''Search for packages that provide the supplied attributes'''
-        return self._run_transaction("WhatProvides", [provides, search], 
+        return self._run_transaction("WhatProvides", [filters, enum, search], 
                                      exit_handler)
 
     def set_locale(self, code):
