@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # Copyright (C) 2008
 #    Richard Hughes <richard@hughsie.com>
@@ -35,20 +35,20 @@ class PackagekitFilter(object, PackagekitPackage):
         for pkg in pkgs:
             if self.pre_process(pkg):
                 self.package_list.append((pkg, INFO_INSTALLED))
-            name = self._pkg_get_name(pkg)
+            name = self._pkg_get_unique(pkg)
             self.installed_unique[name] = pkg
 
     def add_available(self, pkgs):
         ''' add a list of packages that are available '''
         for pkg in pkgs:
-            name = self._pkg_get_name(pkg)
+            name = self._pkg_get_unique(pkg)
             if not self.installed_unique.has_key(name):
                 if self.pre_process(pkg):
                     self.package_list.append((pkg, INFO_AVAILABLE))
 
     def add_custom(self, pkg, info):
         ''' add a custom packages indervidually '''
-        name = self._pkg_get_name(pkg)
+        name = self._pkg_get_unique(pkg)
         if not self.installed_unique.has_key(name):
             if self.pre_process(pkg):
                 self.package_list.append((pkg, info))
@@ -68,6 +68,9 @@ class PackagekitFilter(object, PackagekitPackage):
             elif flt in (FILTER_FREE, FILTER_NOT_FREE):
                 if not self._do_free_filtering(flt, pkg):
                     return False
+            elif flt in (FILTER_ARCH, FILTER_NOT_ARCH):
+                if not self._do_arch_filtering(flt, pkg):
+                    return False
         return True
 
     def post_process(self):
@@ -119,6 +122,13 @@ class PackagekitFilter(object, PackagekitPackage):
         '''
         return True
 
+    def _pkg_is_arch(self, pkg):
+        '''
+        Return if the package is the same architecture as the machine.
+        Needed to be implemented in a sub class
+        '''
+        return True
+
     def _do_installed_filtering(self, flt, pkg):
         is_installed = self._pkg_is_installed(pkg)
         if flt == FILTER_INSTALLED:
@@ -151,3 +161,11 @@ class PackagekitFilter(object, PackagekitPackage):
             want_free = False
         return is_free == want_free
 
+    def _do_arch_filtering(self, flt, pkg):
+        is_arch = self._pkg_is_arch(pkg)
+        if flt == FILTER_ARCH:
+            want_arch = True
+        else:
+            want_arch = False
+        return is_arch == want_arch
+
