@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +38,9 @@
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include <gmodule.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/pk-enum.h>
+#include <packagekit-glib2/pk-common.h>
+#include <packagekit-glib2/pk-package-id.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -60,9 +62,9 @@ struct PkBackendSpawnPrivate
 	PkBackend		*backend;
 	gchar			*name;
 	guint			 kill_id;
-	guint			 backend_finished_id;
 	PkConf			*conf;
 	gboolean		 finished;
+	gboolean		 allow_sigkill;
 	PkBackendSpawnFilterFunc stdout_func;
 	PkBackendSpawnFilterFunc stderr_func;
 };
@@ -91,13 +93,59 @@ pk_backend_spawn_set_filter_stderr (PkBackendSpawn *backend_spawn, PkBackendSpaw
 	return TRUE;
 }
 
+/**
+ * pk_backend_spawn_exit_timeout_cb:
+ **/
+static gboolean
+pk_backend_spawn_exit_timeout_cb (PkBackendSpawn *backend_spawn)
+{
+	gboolean ret;
+
+	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
+
+	/* only try to close if running */
+	ret = pk_spawn_is_running (backend_spawn->priv->spawn);
+	if (ret) {
+		egg_debug ("closing dispatcher as running and is idle");
+		pk_spawn_exit (backend_spawn->priv->spawn);
+	}
+	return FALSE;
+}
+
+/**
+ * pk_backend_spawn_start_kill_timer:
+ **/
+static void
+pk_backend_spawn_start_kill_timer (PkBackendSpawn *backend_spawn)
+{
+	gint timeout;
+	PkBackendSpawnPrivate *priv = backend_spawn->priv;
+
+	/* we finished okay, so we don't need to emulate Finished() for a crashing script */
+	priv->finished = TRUE;
+	egg_debug ("backend marked as finished, so starting kill timer");
+
+	if (priv->kill_id > 0)
+		g_source_remove (priv->kill_id);
+
+	/* get policy timeout */
+	timeout = pk_conf_get_int (priv->conf, "BackendShutdownTimeout");
+	if (timeout == PK_CONF_VALUE_INT_MISSING) {
+		egg_warning ("using built in default value");
+		timeout = 5;
+	}
+
+	/* close down the dispatcher if it is still open after this much time */
+	priv->kill_id = g_timeout_add_seconds (timeout, (GSourceFunc) pk_backend_spawn_exit_timeout_cb, backend_spawn);
+}
+
 /**
  * pk_backend_spawn_parse_stdout:
  *
  * If you are editing this function creating a new backend,
  * then you are probably doing something wrong.
  **/
-G_GNUC_WARN_UNUSED_RESULT static gboolean
+static gboolean
 pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 {
 	gchar **sections;
@@ -110,12 +158,13 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 	PkGroupEnum group;
 	gulong package_size;
 	gint percentage;
-	PkErrorCodeEnum error_enum;
+	PkErrorEnum error_enum;
 	PkStatusEnum status_enum;
 	PkMessageEnum message_enum;
 	PkRestartEnum restart_enum;
 	PkSigTypeEnum sig_type;
 	PkUpdateStateEnum update_state_enum;
+	PkMediaTypeEnum media_type_enum;
 	PkDistroUpgradeEnum distro_upgrade_enum;
 
 	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
@@ -131,9 +180,9 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 	/* get size */
 	size = g_strv_length (sections);
 
-	if (egg_strequal (command, "package")) {
+	if (g_strcmp0 (command, "package") == 0) {
 		if (size != 4) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -150,9 +199,9 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 			goto out;
 		}
 		pk_backend_package (backend_spawn->priv->backend, info, sections[2], sections[3]);
-	} else if (egg_strequal (command, "details")) {
+	} else if (g_strcmp0 (command, "details") == 0) {
 		if (size != 7) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -171,38 +220,43 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 		pk_backend_details (backend_spawn->priv->backend, sections[1], sections[2],
 					group, text, sections[5], package_size);
 		g_free (text);
-	} else if (egg_strequal (command, "finished")) {
+	} else if (g_strcmp0 (command, "finished") == 0) {
 		if (size != 1) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
+
 		pk_backend_finished (backend_spawn->priv->backend);
-	} else if (egg_strequal (command, "files")) {
+
+		/* from this point on, we can start the kill timer */
+		pk_backend_spawn_start_kill_timer (backend_spawn);
+
+	} else if (g_strcmp0 (command, "files") == 0) {
 		if (size != 3) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
 		pk_backend_files (backend_spawn->priv->backend, sections[1], sections[2]);
-	} else if (egg_strequal (command, "repo-detail")) {
+	} else if (g_strcmp0 (command, "repo-detail") == 0) {
 		if (size != 4) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
-		if (egg_strequal (sections[3], "true")) {
+		if (g_strcmp0 (sections[3], "true") == 0) {
 			pk_backend_repo_detail (backend_spawn->priv->backend, sections[1], sections[2], TRUE);
-		} else if (egg_strequal (sections[3], "false")) {
+		} else if (g_strcmp0 (sections[3], "false") == 0) {
 			pk_backend_repo_detail (backend_spawn->priv->backend, sections[1], sections[2], FALSE);
 		} else {
 			egg_warning ("invalid qualifier '%s'", sections[3]);
 			ret = FALSE;
 			goto out;
 		}
-	} else if (egg_strequal (command, "updatedetail")) {
+	} else if (g_strcmp0 (command, "updatedetail") == 0) {
 		if (size != 13) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command '%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -214,18 +268,17 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 			goto out;
 		}
 		update_state_enum = pk_update_state_enum_from_text (sections[10]);
-		text = g_strdup (sections[8]);
 		/* convert ; to \n as we can't emit them on stdout */
-		g_strdelimit (text, ";", '\n');
+		g_strdelimit (sections[8], ";", '\n');
+		g_strdelimit (sections[9], ";", '\n');
 		pk_backend_update_detail (backend_spawn->priv->backend, sections[1],
 					  sections[2], sections[3], sections[4],
-					  sections[5], sections[6], restart, text,
+					  sections[5], sections[6], restart, sections[8],
 					  sections[9], update_state_enum,
 					  sections[11], sections[12]);
-		g_free (text);
-	} else if (egg_strequal (command, "percentage")) {
+	} else if (g_strcmp0 (command, "percentage") == 0) {
 		if (size != 2) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -238,9 +291,9 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 		} else {
 			pk_backend_set_percentage (backend_spawn->priv->backend, percentage);
 		}
-	} else if (egg_strequal (command, "subpercentage")) {
+	} else if (g_strcmp0 (command, "subpercentage") == 0) {
 		if (size != 2) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -253,9 +306,9 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 		} else {
 			pk_backend_set_sub_percentage (backend_spawn->priv->backend, percentage);
 		}
-	} else if (egg_strequal (command, "error")) {
+	} else if (g_strcmp0 (command, "error") == 0) {
 		if (size != 3) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -277,9 +330,9 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 
 		pk_backend_error_code (backend_spawn->priv->backend, error_enum, text);
 		g_free (text);
-	} else if (egg_strequal (command, "requirerestart")) {
+	} else if (g_strcmp0 (command, "requirerestart") == 0) {
 		if (size != 3) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -290,10 +343,15 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 			ret = FALSE;
 			goto out;
 		}
+		if (!pk_package_id_check (sections[2])) {
+			egg_warning ("invalid package_id");
+			ret = FALSE;
+			goto out;
+		}
 		pk_backend_require_restart (backend_spawn->priv->backend, restart_enum, sections[2]);
-	} else if (egg_strequal (command, "message")) {
+	} else if (g_strcmp0 (command, "message") == 0) {
 		if (size != 3) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -309,16 +367,16 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 		g_strdelimit (text, ";", '\n');
 		pk_backend_message (backend_spawn->priv->backend, message_enum, text);
 		g_free (text);
-	} else if (egg_strequal (command, "change-transaction-data")) {
+	} else if (g_strcmp0 (command, "change-transaction-data") == 0) {
 		if (size != 2) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
 		pk_backend_set_transaction_data (backend_spawn->priv->backend, sections[1]);
-	} else if (egg_strequal (command, "status")) {
+	} else if (g_strcmp0 (command, "status") == 0) {
 		if (size != 2) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -330,32 +388,32 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 			goto out;
 		}
 		pk_backend_set_status (backend_spawn->priv->backend, status_enum);
-	} else if (egg_strequal (command, "allow-cancel")) {
+	} else if (g_strcmp0 (command, "allow-cancel") == 0) {
 		if (size != 2) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
-		if (egg_strequal (sections[1], "true")) {
+		if (g_strcmp0 (sections[1], "true") == 0) {
 			pk_backend_set_allow_cancel (backend_spawn->priv->backend, TRUE);
-		} else if (egg_strequal (sections[1], "false")) {
+		} else if (g_strcmp0 (sections[1], "false") == 0) {
 			pk_backend_set_allow_cancel (backend_spawn->priv->backend, FALSE);
 		} else {
 			egg_warning ("invalid section '%s'", sections[1]);
 			ret = FALSE;
 			goto out;
 		}
-	} else if (egg_strequal (command, "no-percentage-updates")) {
+	} else if (g_strcmp0 (command, "no-percentage-updates") == 0) {
 		if (size != 1) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
 		pk_backend_set_percentage (backend_spawn->priv->backend, PK_BACKEND_PERCENTAGE_INVALID);
-	} else if (egg_strequal (command, "repo-signature-required")) {
+	} else if (g_strcmp0 (command, "repo-signature-required") == 0) {
 
 		if (size != 9) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -385,10 +443,28 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 							  sections[2], sections[3], sections[4],
 							  sections[5], sections[6], sections[7], sig_type);
 		goto out;
-	} else if (egg_strequal (command, "distro-upgrade")) {
+	} else if (g_strcmp0 (command, "media-change-required") == 0) {
 
 		if (size != 4) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
+			ret = FALSE;
+			goto out;
+		}
+
+		media_type_enum = pk_media_type_enum_from_text (sections[1]);
+		if (media_type_enum == PK_MEDIA_TYPE_ENUM_UNKNOWN) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR,
+					    "media type enum not recognised, and hence ignored: '%s'", sections[1]);
+			ret = FALSE;
+			goto out;
+		}
+
+		ret = pk_backend_media_change_required (backend_spawn->priv->backend, media_type_enum, sections[2], sections[3]);
+		goto out;
+	} else if (g_strcmp0 (command, "distro-upgrade") == 0) {
+
+		if (size != 4) {
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
@@ -403,14 +479,14 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 
 		ret = pk_backend_distro_upgrade (backend_spawn->priv->backend, distro_upgrade_enum, sections[2], sections[3]);
 		goto out;
-	} else if (egg_strequal (command, "category")) {
+	} else if (g_strcmp0 (command, "category") == 0) {
 
 		if (size != 6) {
-			egg_warning ("invalid command '%s'", command);
+			egg_warning ("invalid command'%s', size %i", command, size);
 			ret = FALSE;
 			goto out;
 		}
-		if (egg_strequal (sections[1], sections[2])) {
+		if (g_strcmp0 (sections[1], sections[2]) == 0) {
 			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "cat_id cannot be the same as parent_id");
 			ret = FALSE;
 			goto out;
@@ -449,25 +525,22 @@ out:
  * pk_backend_spawn_exit_cb:
  **/
 static void
-pk_backend_spawn_exit_cb (PkSpawn *spawn, PkSpawnExitType exit, PkBackendSpawn *backend_spawn)
+pk_backend_spawn_exit_cb (PkSpawn *spawn, PkSpawnExitType exit_enum, PkBackendSpawn *backend_spawn)
 {
 	g_return_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn));
 
 	/* if we force killed the process, set an error */
-	if (exit == PK_SPAWN_EXIT_TYPE_SIGKILL) {
+	if (exit_enum == PK_SPAWN_EXIT_TYPE_SIGKILL) {
 		/* we just call this failed, and set an error */
 		pk_backend_error_code (backend_spawn->priv->backend, PK_ERROR_ENUM_PROCESS_KILL,
 				       "Process had to be killed to be cancelled");
 	}
 
 	/* only emit if not finished */
-	if (!backend_spawn->priv->finished) {
-		/* ignore when we exit from a dispatcher */
-		if (exit != PK_SPAWN_EXIT_TYPE_DISPATCHER_EXIT &&
-		    exit != PK_SPAWN_EXIT_TYPE_DISPATCHER_CHANGED) {
-			egg_warning ("script exited without doing finished");
-			pk_backend_finished (backend_spawn->priv->backend);
-		}
+	if (!backend_spawn->priv->finished &&
+	    exit_enum != PK_SPAWN_EXIT_TYPE_DISPATCHER_CHANGED) {
+		egg_warning ("script exited without doing finished");
+		pk_backend_finished (backend_spawn->priv->backend);
 	}
 }
 
@@ -513,6 +586,33 @@ pk_backend_spawn_stderr_cb (PkBackendSpawn *spawn, const gchar *line, PkBackendS
 	pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "%s", line);
 }
 
+/**
+ * pk_backend_spawn_convert_uri:
+ *
+ * Our proxy variable is typically 'username:password@server:port'
+ * but http_proxy expects 'http://username:password@server:port/'
+ **/
+static gchar *
+pk_backend_spawn_convert_uri (const gchar *proxy)
+{
+	GString *string;
+	string = g_string_new (proxy);
+
+	/* if we didn't specify a prefix, add a default one */
+	if (!g_str_has_prefix (proxy, "http://") &&
+	    !g_str_has_prefix (proxy, "https://") &&
+	    !g_str_has_prefix (proxy, "ftp://")) {
+		g_string_prepend (string, "http://");
+	}
+
+	/* if we didn't specify a trailing slash, add one */
+	if (!g_str_has_suffix (proxy, "/")) {
+		g_string_append_c (string, '/');
+	}
+
+	return g_string_free (string, FALSE);
+}
+
 /**
  * pk_backend_spawn_get_envp:
  *
@@ -524,29 +624,35 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 	gchar **envp;
 	gchar *value;
 	gchar *line;
+	gchar *uri;
 	GPtrArray *array;
+	gboolean ret;
 
-	array = g_ptr_array_new ();
+	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* http_proxy */
 	value = pk_backend_get_proxy_http (backend_spawn->priv->backend);
 	if (!egg_strzero (value)) {
-		line = g_strdup_printf ("%s=%s", "http_proxy", value);
+		uri = pk_backend_spawn_convert_uri (value);
+		line = g_strdup_printf ("%s=%s", "http_proxy", uri);
 		egg_debug ("setting evp '%s'", line);
 		g_ptr_array_add (array, line);
+		g_free (uri);
 	}
 	g_free (value);
 
 	/* ftp_proxy */
 	value = pk_backend_get_proxy_ftp (backend_spawn->priv->backend);
 	if (!egg_strzero (value)) {
-		line = g_strdup_printf ("%s=%s", "ftp_proxy", value);
+		uri = pk_backend_spawn_convert_uri (value);
+		line = g_strdup_printf ("%s=%s", "ftp_proxy", uri);
 		egg_debug ("setting evp '%s'", line);
 		g_ptr_array_add (array, line);
+		g_free (uri);
 	}
 	g_free (value);
 
-	/* ftp_proxy */
+	/* LANG */
 	value = pk_backend_get_locale (backend_spawn->priv->backend);
 	if (!egg_strzero (value)) {
 		line = g_strdup_printf ("%s=%s", "LANG", value);
@@ -555,12 +661,64 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 	}
 	g_free (value);
 
+	/* NETWORK */
+	ret = pk_backend_is_online (backend_spawn->priv->backend);
+	line = g_strdup_printf ("%s=%s", "NETWORK", ret ? "TRUE" : "FALSE");
+	egg_debug ("setting evp '%s'", line);
+	g_ptr_array_add (array, line);
+
+	/* IDLE */
+	ret = pk_backend_use_idle_bandwidth (backend_spawn->priv->backend);
+	line = g_strdup_printf ("%s=%s", "IDLE", ret ? "TRUE" : "FALSE");
+	egg_debug ("setting evp '%s'", line);
+	g_ptr_array_add (array, line);
+
 	envp = pk_ptr_array_to_strv (array);
-	g_ptr_array_foreach (array, (GFunc) g_free, NULL);
-	g_ptr_array_free (array, TRUE);
+	g_ptr_array_unref (array);
 	return envp;
 }
 
+/**
+ * pk_backend_spawn_va_list_to_argv:
+ * @string_first: the first string
+ * @args: any subsequant string's
+ *
+ * Form a composite string array of the va_list
+ *
+ * Return value: the string array, or %NULL if invalid
+ **/
+static gchar **
+pk_backend_spawn_va_list_to_argv (const gchar *string_first, va_list *args)
+{
+	GPtrArray *ptr_array;
+	gchar **array;
+	gchar *value_temp;
+	guint i;
+
+	g_return_val_if_fail (args != NULL, NULL);
+	g_return_val_if_fail (string_first != NULL, NULL);
+
+	/* find how many elements we have in a temp array */
+	ptr_array = g_ptr_array_new ();
+	g_ptr_array_add (ptr_array, g_strdup (string_first));
+
+	/* process all the va_list entries */
+	for (i=0;; i++) {
+		value_temp = va_arg (*args, gchar *);
+		if (value_temp == NULL)
+			break;
+		g_ptr_array_add (ptr_array, g_strdup (value_temp));
+	}
+
+	/* convert the array to a strv type */
+	array = pk_ptr_array_to_strv (ptr_array);
+
+	/* get rid of the array, and free the contents */
+	g_ptr_array_foreach (ptr_array, (GFunc) g_free, NULL);
+	g_ptr_array_free (ptr_array, TRUE);
+	return array;
+}
+
 /**
  * pk_backend_spawn_helper_va_list:
  **/
@@ -571,6 +729,7 @@ pk_backend_spawn_helper_va_list (PkBackendSpawn *backend_spawn, const gchar *exe
 	gchar *filename;
 	gchar **argv;
 	gchar **envp;
+	PkTristate background;
 #if PK_BUILD_LOCAL
 	const gchar *directory;
 #endif
@@ -578,7 +737,7 @@ pk_backend_spawn_helper_va_list (PkBackendSpawn *backend_spawn, const gchar *exe
 	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
 
 	/* convert to a argv */
-	argv = pk_va_list_to_argv (executable, args);
+	argv = pk_backend_spawn_va_list_to_argv (executable, args);
 	if (argv == NULL) {
 		egg_warning ("argv NULL");
 		return FALSE;
@@ -610,6 +769,10 @@ pk_backend_spawn_helper_va_list (PkBackendSpawn *backend_spawn, const gchar *exe
 	g_free (argv[0]);
 	argv[0] = g_strdup (filename);
 
+	/* copy idle setting from backend to PkSpawn instance */
+	g_object_get (backend_spawn->priv->backend, "background", &background, NULL);
+	g_object_set (backend_spawn->priv->spawn, "background", (background == PK_TRISTATE_TRUE), NULL);
+
 	backend_spawn->priv->finished = FALSE;
 	envp = pk_backend_spawn_get_envp (backend_spawn);
 	ret = pk_spawn_argv (backend_spawn->priv->spawn, argv, envp);
@@ -659,45 +822,6 @@ pk_backend_spawn_kill (PkBackendSpawn *backend_spawn)
 	return TRUE;
 }
 
-/**
- * pk_backend_spawn_exit_timeout_cb:
- **/
-static gboolean
-pk_backend_spawn_exit_timeout_cb (PkBackendSpawn *backend_spawn)
-{
-	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
-	egg_debug ("closing dispatcher as idle");
-	pk_spawn_exit (backend_spawn->priv->spawn);
-	return FALSE;
-}
-
-/**
- * pk_backend_spawn_finished_cb:
- **/
-static void
-pk_backend_spawn_finished_cb (PkBackend *backend, PkExitEnum exit, PkBackendSpawn *backend_spawn)
-{
-	gint timeout;
-
-	g_return_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn));
-
-	/* we finished okay, so we don't need to emulate Finished() for a crashing script */
-	backend_spawn->priv->finished = TRUE;
-
-	if (backend_spawn->priv->kill_id > 0)
-		g_source_remove (backend_spawn->priv->kill_id);
-
-	/* get policy timeout */
-	timeout = pk_conf_get_int (backend_spawn->priv->conf, "BackendShutdownTimeout");
-	if (timeout == PK_CONF_VALUE_INT_MISSING) {
-		egg_warning ("using built in default value");
-		timeout = 5;
-	}
-
-	/* close down the dispatcher if it is still open after this much time */
-	backend_spawn->priv->kill_id = g_timeout_add_seconds (timeout, (GSourceFunc) pk_backend_spawn_exit_timeout_cb, backend_spawn);
-}
-
 /**
  * pk_backend_spawn_helper:
  **/
@@ -725,6 +849,31 @@ pk_backend_spawn_helper (PkBackendSpawn *backend_spawn, const gchar *first_eleme
 	return ret;
 }
 
+/**
+ * pk_backend_spawn_set_allow_sigkill:
+ **/
+gboolean
+pk_backend_spawn_set_allow_sigkill (PkBackendSpawn *backend_spawn, gboolean allow_sigkill)
+{
+	gboolean ret = TRUE;
+
+	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
+
+	/* have we banned this in the config ile */
+	if (!backend_spawn->priv->allow_sigkill && allow_sigkill) {
+		egg_warning ("cannot set allow_cancel TRUE as BackendSpawnAllowSIGKILL is set to FALSE in PackageKit.conf");
+		ret = FALSE;
+		goto out;
+	}
+
+	/* set this property */
+	g_object_set (backend_spawn->priv->spawn,
+		      "allow-sigkill", allow_sigkill,
+		      NULL);
+out:
+	return ret;
+}
+
 /**
  * pk_backend_spawn_finalize:
  **/
@@ -740,7 +889,6 @@ pk_backend_spawn_finalize (GObject *object)
 	if (backend_spawn->priv->kill_id > 0)
 		g_source_remove (backend_spawn->priv->kill_id);
 
-	g_signal_handler_disconnect (backend_spawn->priv->backend, backend_spawn->priv->backend_finished_id);
 	g_free (backend_spawn->priv->name);
 	g_object_unref (backend_spawn->priv->conf);
 	g_object_unref (backend_spawn->priv->spawn);
@@ -774,9 +922,6 @@ pk_backend_spawn_init (PkBackendSpawn *backend_spawn)
 	backend_spawn->priv->finished = FALSE;
 	backend_spawn->priv->conf = pk_conf_new ();
 	backend_spawn->priv->backend = pk_backend_new ();
-	backend_spawn->priv->backend_finished_id =
-		g_signal_connect (backend_spawn->priv->backend, "finished",
-			  G_CALLBACK (pk_backend_spawn_finished_cb), backend_spawn);
 	backend_spawn->priv->spawn = pk_spawn_new ();
 	g_signal_connect (backend_spawn->priv->spawn, "exit",
 			  G_CALLBACK (pk_backend_spawn_exit_cb), backend_spawn);
@@ -784,6 +929,12 @@ pk_backend_spawn_init (PkBackendSpawn *backend_spawn)
 			  G_CALLBACK (pk_backend_spawn_stdout_cb), backend_spawn);
 	g_signal_connect (backend_spawn->priv->spawn, "stderr",
 			  G_CALLBACK (pk_backend_spawn_stderr_cb), backend_spawn);
+
+	/* set if SIGKILL is allowed */
+	backend_spawn->priv->allow_sigkill = pk_conf_get_bool (backend_spawn->priv->conf, "BackendSpawnAllowSIGKILL");
+	g_object_set (backend_spawn->priv->spawn,
+		      "allow-sigkill", backend_spawn->priv->allow_sigkill,
+		      NULL);
 }
 
 /**
@@ -826,6 +977,20 @@ pk_backend_spawn_test_package_cb (PkBackend *backend, PkInfoEnum info,
 	number_packages++;
 }
 
+static gchar **
+pk_backend_spawn_va_list_to_argv_test (const gchar *first_element, ...)
+{
+	va_list args;
+	gchar **array;
+
+	/* get the argument list */
+	va_start (args, first_element);
+	array = pk_backend_spawn_va_list_to_argv (first_element, &args);
+	va_end (args);
+
+	return array;
+}
+
 void
 pk_backend_test_spawn (EggTest *test)
 {
@@ -834,17 +999,37 @@ pk_backend_test_spawn (EggTest *test)
 	const gchar *text;
 	guint refcount;
 	gboolean ret;
+	gchar *uri;
+	gchar **array;
 
 	loop = g_main_loop_new (NULL, FALSE);
 
 	if (!egg_test_start (test, "PkBackendSpawn"))
 		return;
 
-	/* don't do these when doing make distcheck */
-#ifndef PK_IS_DEVELOPER
-	egg_test_end (test);
-	return;
-#endif
+	/************************************************************
+	 ****************      splitting va_list       **************
+	 ************************************************************/
+	egg_test_title (test, "va_list_to_argv single");
+	array = pk_backend_spawn_va_list_to_argv_test ("richard", NULL);
+	if (g_strcmp0 (array[0], "richard") == 0 &&
+	    array[1] == NULL)
+		egg_test_success (test, NULL);
+	else
+		egg_test_failed (test, "incorrect array '%s'", array[0]);
+	g_strfreev (array);
+
+	/************************************************************/
+	egg_test_title (test, "va_list_to_argv triple");
+	array = pk_backend_spawn_va_list_to_argv_test ("richard", "phillip", "hughes", NULL);
+	if (g_strcmp0 (array[0], "richard") == 0 &&
+	    g_strcmp0 (array[1], "phillip") == 0 &&
+	    g_strcmp0 (array[2], "hughes") == 0 &&
+	    array[3] == NULL)
+		egg_test_success (test, NULL);
+	else
+		egg_test_failed (test, "incorrect array '%s','%s','%s'", array[0], array[1], array[2]);
+	g_strfreev (array);
 
 	/************************************************************/
 	egg_test_title (test, "get an backend_spawn");
@@ -875,7 +1060,7 @@ pk_backend_test_spawn (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "get backend name");
 	text = pk_backend_spawn_get_name (backend_spawn);
-	if (egg_strequal(text, "test_spawn"))
+	if (g_strcmp0 (text, "test_spawn") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "invalid name %s", text);
@@ -936,17 +1121,25 @@ pk_backend_test_spawn (EggTest *test)
 
 	/************************************************************/
 	egg_test_title (test, "test pk_backend_spawn_parse_stdout RequireRestart");
-	ret = pk_backend_spawn_parse_stdout (backend_spawn, "requirerestart\tsystem\tdetails about the restart");
+	ret = pk_backend_spawn_parse_stdout (backend_spawn, "requirerestart\tsystem\tgnome-power-manager;0.0.1;i386;data");
 	egg_test_assert (test, ret);
 
 	/************************************************************/
-	egg_test_title (test, "test pk_backend_spawn_parse_stdout RequireRestart");
-	ret = pk_backend_spawn_parse_stdout (backend_spawn, "requirerestart\tmooville\tdetails about the restart");
+	egg_test_title (test, "test pk_backend_spawn_parse_stdout RequireRestart invalid enum");
+	ret = pk_backend_spawn_parse_stdout (backend_spawn, "requirerestart\tmooville\tgnome-power-manager;0.0.1;i386;data");
 	if (!ret)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "did not detect incorrect enum");
 
+	/************************************************************/
+	egg_test_title (test, "test pk_backend_spawn_parse_stdout RequireRestart invalid PackageId");
+	ret = pk_backend_spawn_parse_stdout (backend_spawn, "requirerestart\tsystem\tdetails about the restart");
+	if (!ret)
+		egg_test_success (test, NULL);
+	else
+		egg_test_failed (test, "did not detect incorrect package id");
+
 	/************************************************************/
 	egg_test_title (test, "test pk_backend_spawn_parse_stdout AllowUpdate1");
 	ret = pk_backend_spawn_parse_stdout (backend_spawn, "allow-cancel\ttrue");
@@ -957,6 +1150,26 @@ pk_backend_test_spawn (EggTest *test)
 	ret = pk_backend_spawn_parse_stdout (backend_spawn, "allow-cancel\tbrian");
 	egg_test_assert (test, !ret);
 
+	/************************************************************
+	 **********         Check uri conversion          ***********
+	 ************************************************************/
+	egg_test_title (test, "convert proxy uri (bare)");
+	uri = pk_backend_spawn_convert_uri ("username:password@server:port");
+	egg_test_assert (test, (g_strcmp0 (uri, "http://username:password@server:port/") == 0));
+	g_free (uri);
+
+	/************************************************************/
+	egg_test_title (test, "convert proxy uri (full)");
+	uri = pk_backend_spawn_convert_uri ("http://username:password@server:port/");
+	egg_test_assert (test, (g_strcmp0 (uri, "http://username:password@server:port/") == 0));
+	g_free (uri);
+
+	/************************************************************/
+	egg_test_title (test, "convert proxy uri (partial)");
+	uri = pk_backend_spawn_convert_uri ("ftp://username:password@server:port");
+	egg_test_assert (test, (g_strcmp0 (uri, "ftp://username:password@server:port/") == 0));
+	g_free (uri);
+
 	/************************************************************
 	 **********        Check parsing common out       ***********
 	 ************************************************************/
