@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __PK_BACKEND_H
@@ -24,9 +24,13 @@
 
 #include <glib.h>
 #include <gmodule.h>
-#include <pk-enum.h>
-#include <pk-bitfield.h>
-#include <pk-package-id.h>
+
+/* these include the includes the backends should be using */
+#include <packagekit-glib2/pk-enum.h>
+#include <packagekit-glib2/pk-common.h>
+#include <packagekit-glib2/pk-bitfield.h>
+#include <packagekit-glib2/pk-package-id.h>
+#include <packagekit-glib2/pk-package-ids.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -43,14 +47,13 @@ G_BEGIN_DECLS
 typedef struct _PkBackend PkBackend;
 
 /* set the state */
-gboolean	 pk_backend_set_current_tid		(PkBackend	*backend,
-							 const gchar	*tid);
 gboolean	 pk_backend_accept_eula			(PkBackend	*backend,
 							 const gchar	*eula_id);
 gboolean	 pk_backend_is_eula_valid		(PkBackend	*backend,
 							 const gchar	*eula_id);
 gboolean	 pk_backend_set_role			(PkBackend	*backend,
 							 PkRoleEnum	 role);
+PkRoleEnum	 pk_backend_get_role			(PkBackend	*backend);
 gboolean	 pk_backend_set_status			(PkBackend	*backend,
 							 PkStatusEnum	 status);
 gboolean	 pk_backend_set_allow_cancel		(PkBackend	*backend,
@@ -63,13 +66,12 @@ gboolean	 pk_backend_set_exit_code		(PkBackend	*backend,
 							 PkExitEnum	 exit);
 gboolean	 pk_backend_set_transaction_data	(PkBackend	*backend,
 							 const gchar	*data);
+gboolean	 pk_backend_set_simultaneous_mode	(PkBackend	*backend,
+							 gboolean	 simultaneous);
 gboolean	 pk_backend_set_locale			(PkBackend	*backend,
 							 const gchar	*code);
 
 /* get the state */
-const gchar	*pk_backend_get_current_tid		(PkBackend	*backend);
-PkRoleEnum	 pk_backend_get_role			(PkBackend	*backend);
-PkStatusEnum	 pk_backend_get_status			(PkBackend	*backend);
 gboolean	 pk_backend_get_allow_cancel		(PkBackend	*backend);
 gboolean	 pk_backend_get_progress		(PkBackend	*backend,
 							 guint		*percentage,
@@ -106,7 +108,7 @@ gboolean	 pk_backend_update_detail		(PkBackend	*backend,
 							 const gchar	*updated);
 gboolean	 pk_backend_require_restart		(PkBackend	*backend,
 							 PkRestartEnum	 restart,
-							 const gchar	*details);
+							 const gchar	*package_id);
 gboolean	 pk_backend_message			(PkBackend	*backend,
 							 PkMessageEnum	 message,
 							 const gchar	*details, ...);
@@ -125,7 +127,7 @@ gboolean 	 pk_backend_distro_upgrade		(PkBackend 	*backend,
 							 const gchar 	*name,
 							 const gchar 	*summary);
 gboolean	 pk_backend_error_code			(PkBackend	*backend,
-							 PkErrorCodeEnum code,
+							 PkErrorEnum code,
 							 const gchar	*details, ...);
 gboolean         pk_backend_repo_signature_required	(PkBackend      *backend,
 							 const gchar	*package_id,
@@ -141,6 +143,17 @@ gboolean         pk_backend_eula_required		(PkBackend      *backend,
 							 const gchar    *package_id,
 							 const gchar    *vendor_name,
 							 const gchar    *license_agreement);
+gboolean         pk_backend_media_change_required	(PkBackend      *backend,
+							 PkMediaTypeEnum media_type,
+							 const gchar    *media_id,
+							 const gchar    *media_text);
+gboolean         pk_backend_category			(PkBackend      *backend,
+							 const gchar	*parent_id,
+							 const gchar	*cat_id,
+							 const gchar    *name,
+							 const gchar    *summary,
+							 const gchar    *icon);
+gboolean         pk_backend_repo_list_changed		(PkBackend      *backend);
 
 /* set backend instance data */
 gboolean	 pk_backend_set_array			(PkBackend	*backend,
@@ -177,12 +190,14 @@ gpointer	 pk_backend_get_pointer			(PkBackend	*backend,
 							 const gchar	*key);
 
 /* helper functions */
+const gchar	*pk_backend_bool_to_text		(gboolean	 value);
 gboolean	 pk_backend_not_implemented_yet		(PkBackend	*backend,
 							 const gchar	*method);
 typedef gboolean (*PkBackendThreadFunc)			(PkBackend	*backend);
 gboolean	 pk_backend_thread_create		(PkBackend	*backend,
 							 PkBackendThreadFunc func);
 gboolean	 pk_backend_is_online			(PkBackend	*backend);
+gboolean	 pk_backend_use_idle_bandwidth		(PkBackend	*backend);
 
 /* config changed functions */
 typedef void	(*PkBackendFileChanged)			(PkBackend	*backend,
@@ -202,11 +217,13 @@ typedef struct {
 	void		(*destroy)			(PkBackend	*backend);
 	PkBitfield	(*get_groups)			(PkBackend	*backend);
 	PkBitfield	(*get_filters)			(PkBackend	*backend);
+	PkBitfield	(*get_roles)			(PkBackend	*backend);
 	gchar		*(*get_mime_types)		(PkBackend	*backend);
 	void		(*cancel)			(PkBackend	*backend);
 	void		(*download_packages)		(PkBackend	*backend,
 							 gchar		**package_ids,
 							 const gchar	*directory);
+	void		(*get_categories)		(PkBackend	*backend);
 	void		(*get_depends)			(PkBackend	*backend,
 							 PkBitfield	 filters,
 							 gchar		**package_ids,
@@ -229,9 +246,10 @@ typedef struct {
 	void		(*get_updates)			(PkBackend	*backend,
 							 PkBitfield	 filters);
 	void		(*install_files)		(PkBackend	*backend,
-							 gboolean	 trusted,
+							 gboolean	 only_trusted,
 							 gchar		**full_paths);
 	void		(*install_packages)		(PkBackend	*backend,
+							 gboolean	 only_trusted,
 							 gchar		**package_ids);
 	void		(*install_signature)		(PkBackend	*backend,
 							 PkSigTypeEnum	 type,
@@ -257,72 +275,87 @@ typedef struct {
 							 const gchar	*transaction_id);
 	void		(*search_details)		(PkBackend	*backend,
 							 PkBitfield	 filters,
-							 const gchar	*search);
+							 const gchar	*values);
 	void		(*search_file)			(PkBackend	*backend,
 							 PkBitfield	 filters,
-							 const gchar	*search);
+							 const gchar	*values);
 	void		(*search_group)			(PkBackend	*backend,
 							 PkBitfield	 filters,
-							 const gchar	*search);
+							 const gchar	*values);
 	void		(*search_name)			(PkBackend	*backend,
 							 PkBitfield	 filters,
-							 const gchar	*search);
-	void		(*service_pack)			(PkBackend	*backend,
-							 const gchar	*location,
-							 gboolean	 enabled);
+							 const gchar	*values);
 	void		(*update_packages)		(PkBackend	*backend,
+							 gboolean	 only_trusted,
 							 gchar		**package_ids);
-	void		(*update_system)		(PkBackend	*backend);
+	void		(*update_system)		(PkBackend	*backend,
+							 gboolean	 only_trusted);
 	void		(*what_provides)		(PkBackend	*backend,
 							 PkBitfield	 filters,
 							 PkProvidesEnum	 provides,
-							 const gchar	*search);
+							 const gchar	*values);
+	void		(*simulate_install_files)	(PkBackend	*backend,
+							 gchar		**full_paths);
+	void		(*simulate_install_packages)	(PkBackend	*backend,
+							 gchar		**package_ids);
+	void		(*simulate_remove_packages)	(PkBackend	*backend,
+							 gchar		**package_ids);
+	void		(*simulate_update_packages)	(PkBackend	*backend,
+							 gchar		**package_ids);
 	gpointer	padding[10];
 } PkBackendDesc;
 
-#define PK_BACKEND_OPTIONS(description, author, initialize, destroy, get_groups, get_filters, get_mime_types, cancel, download_packages, \
-			   get_depends, get_details, get_distro_upgrades, get_files, get_packages, get_repo_list, get_requires,	\
-			   get_update_detail, get_updates, install_files, install_packages,		\
-			   install_signature, refresh_cache, remove_packages, repo_enable,		\
-			   repo_set_data, resolve, rollback, search_details, search_file, search_group,	\
-			   search_name, service_pack, update_packages, update_system, what_provides)	\
+#define PK_BACKEND_OPTIONS(description, author, initialize, destroy, get_groups, get_filters, get_roles, \
+			   get_mime_types, cancel, download_packages, get_categories, get_depends,	\
+			   get_details, get_distro_upgrades, get_files, get_packages, get_repo_list,	\
+			   get_requires, get_update_detail, get_updates, install_files,			\
+			   install_packages, install_signature, refresh_cache, remove_packages,		\
+			   repo_enable, repo_set_data, resolve, rollback, search_details, search_file,	\
+			   search_group, search_name, update_packages, update_system, what_provides,	\
+			   simulate_install_files, simulate_install_packages, simulate_remove_packages,	\
+			   simulate_update_packages )							\
 	G_MODULE_EXPORT const PkBackendDesc pk_backend_desc = { 					\
-		description,		\
-		author,			\
-		initialize,		\
-		destroy,		\
-		get_groups,		\
-		get_filters,		\
-		get_mime_types,		\
-		cancel,			\
-		download_packages,	\
-		get_depends,		\
-		get_details,		\
-		get_distro_upgrades,	\
-		get_files,		\
-		get_packages,		\
-		get_repo_list,		\
-		get_requires,		\
-		get_update_detail,	\
-		get_updates,		\
-		install_files,		\
-		install_packages,	\
-		install_signature,	\
-		refresh_cache,		\
-		remove_packages,	\
-		repo_enable,		\
-		repo_set_data,		\
-		resolve,		\
-		rollback,		\
-		search_details,		\
-		search_file,		\
-		search_group,		\
-		search_name,		\
-		service_pack,		\
-		update_packages,	\
-		update_system,		\
-		what_provides,		\
-		{0} 			\
+		description,			\
+		author,				\
+		initialize,			\
+		destroy,			\
+		get_groups,			\
+		get_filters,			\
+		get_roles,			\
+		get_mime_types,			\
+		cancel,				\
+		download_packages,		\
+		get_categories,			\
+		get_depends,			\
+		get_details,			\
+		get_distro_upgrades,		\
+		get_files,			\
+		get_packages,			\
+		get_repo_list,			\
+		get_requires,			\
+		get_update_detail,		\
+		get_updates,			\
+		install_files,			\
+		install_packages,		\
+		install_signature,		\
+		refresh_cache,			\
+		remove_packages,		\
+		repo_enable,			\
+		repo_set_data,			\
+		resolve,			\
+		rollback,			\
+		search_details,			\
+		search_file,			\
+		search_group,			\
+		search_name,			\
+		update_packages,		\
+		update_system,			\
+		what_provides,			\
+		simulate_install_files,		\
+		simulate_install_packages,	\
+		simulate_remove_packages,	\
+		simulate_update_packages,	\
+		{0} 				\
 	}
 
 G_END_DECLS
