@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -27,16 +27,18 @@
 
 #include <glib/gi18n.h>
 #include <glib.h>
-#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "pk-cache.h"
+#include "pk-conf.h"
 
 #define PK_CACHE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_CACHE, PkCachePrivate))
 
 struct PkCachePrivate
 {
-	PkPackageList		*updates_cache;
+	PkConf			*conf;
+	gboolean		 use_update_cache;
+	GPtrArray		*updates_cache;
 };
 
 G_DEFINE_TYPE (PkCache, pk_cache, G_TYPE_OBJECT)
@@ -45,10 +47,17 @@ static gpointer pk_cache_object = NULL;
 /**
  * pk_cache_get_updates:
  **/
-PkPackageList *
+GPtrArray *
 pk_cache_get_updates (PkCache *cache)
 {
 	g_return_val_if_fail (PK_IS_CACHE (cache), NULL);
+
+	/* do not use */
+	if (!cache->priv->use_update_cache) {
+		egg_debug ("not using cache");
+		return NULL;
+	}
+
 	return cache->priv->updates_cache;
 }
 
@@ -56,18 +65,22 @@ pk_cache_get_updates (PkCache *cache)
  * pk_cache_set_updates:
  **/
 gboolean
-pk_cache_set_updates (PkCache *cache, PkPackageList *list)
+pk_cache_set_updates (PkCache *cache, GPtrArray *list)
 {
 	g_return_val_if_fail (PK_IS_CACHE (cache), FALSE);
 	g_return_val_if_fail (list != NULL, FALSE);
 
+	/* do not use */
+	if (!cache->priv->use_update_cache) {
+		egg_debug ("not using cache");
+		return FALSE;
+	}
+
 	/* do this in case we have old data */
 	pk_cache_invalidate (cache);
 
-	cache->priv->updates_cache = list;
 	egg_debug ("reffing updates cache");
-	g_object_ref (cache->priv->updates_cache);
-	g_object_add_weak_pointer (G_OBJECT (cache->priv->updates_cache), (gpointer) &cache->priv->updates_cache);
+	cache->priv->updates_cache = g_ptr_array_ref (list);
 	return TRUE;
 }
 
@@ -81,7 +94,7 @@ pk_cache_invalidate (PkCache *cache)
 
 	egg_debug ("unreffing updates cache");
 	if (cache->priv->updates_cache != NULL) {
-		g_object_unref (cache->priv->updates_cache);
+		g_ptr_array_unref (cache->priv->updates_cache);
 		cache->priv->updates_cache = NULL;
 	}
 	return TRUE;
@@ -97,9 +110,8 @@ pk_cache_finalize (GObject *object)
 	g_return_if_fail (PK_IS_CACHE (object));
 	cache = PK_CACHE (object);
 
-	if (cache->priv->updates_cache != NULL) {
-		g_object_unref (cache->priv->updates_cache);
-	}
+	if (cache->priv->updates_cache != NULL)
+		g_ptr_array_unref (cache->priv->updates_cache);
 
 	G_OBJECT_CLASS (pk_cache_parent_class)->finalize (object);
 }
@@ -127,6 +139,8 @@ pk_cache_init (PkCache *cache)
 {
 	cache->priv = PK_CACHE_GET_PRIVATE (cache);
 	cache->priv->updates_cache = NULL;
+	cache->priv->conf = pk_conf_new ();
+	cache->priv->use_update_cache = pk_conf_get_bool (cache->priv->conf, "UseUpdateCache");
 }
 
 /**
