@@ -16,14 +16,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __PK_CACHE_H
 #define __PK_CACHE_H
 
 #include <glib-object.h>
-#include <packagekit-glib/packagekit.h>
 
 G_BEGIN_DECLS
 
@@ -50,9 +49,9 @@ typedef struct
 GType		 pk_cache_get_type		(void);
 PkCache		*pk_cache_new			(void);
 
-PkPackageList	*pk_cache_get_updates		(PkCache	*cache);
+GPtrArray	*pk_cache_get_updates		(PkCache	*cache);
 gboolean	 pk_cache_set_updates		(PkCache	*cache,
-						 PkPackageList	*list);
+						 GPtrArray	*list);
 gboolean	 pk_cache_invalidate		(PkCache	*cache);
 
 G_END_DECLS
