@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,7 +31,6 @@
 
 #include <glib/gi18n.h>
 #include <glib.h>
-#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "pk-conf.h"
@@ -68,6 +67,28 @@ pk_conf_get_string (PkConf *conf, const gchar *key)
 	return value;
 }
 
+/**
+ * pk_conf_get_strv:
+ **/
+gchar **
+pk_conf_get_strv (PkConf *conf, const gchar *key)
+{
+	gchar **value = NULL;
+	GError *error = NULL;
+
+	g_return_val_if_fail (PK_IS_CONF (conf), NULL);
+	g_return_val_if_fail (key != NULL, NULL);
+
+	value = g_key_file_get_string_list (conf->priv->keyfile, "Daemon", key, NULL, &error);
+	if (error != NULL) {
+		/* set to missing value */
+		value = PK_CONF_VALUE_STRING_MISSING;
+		egg_debug ("%s read error: %s", key, error->message);
+		g_error_free (error);
+	}
+	return value;
+}
+
 /**
  * pk_conf_get_int:
  **/
