@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __PK_ENGINE_H
@@ -60,6 +60,8 @@ typedef enum
 	PK_ENGINE_ERROR_REFUSED_BY_POLICY,
 	PK_ENGINE_ERROR_CANNOT_SET_PROXY,
 	PK_ENGINE_ERROR_NOT_SUPPORTED,
+	PK_ENGINE_ERROR_CANNOT_ALLOCATE_TID,
+	PK_ENGINE_ERROR_CANNOT_CHECK_AUTH,
 	PK_ENGINE_ERROR_LAST
 } PkEngineError;
 
@@ -74,7 +76,7 @@ guint		 pk_engine_get_seconds_idle		(PkEngine	*engine);
 
 /* dbus methods */
 gboolean	 pk_engine_get_actions			(PkEngine	*engine,
-							 gchar		**actions,
+							 gchar		**roles,
 							 GError		**error);
 gboolean	 pk_engine_get_backend_detail		(PkEngine	*engine,
 							 gchar		**name,
@@ -113,6 +115,9 @@ void		 pk_engine_set_proxy			(PkEngine	*engine,
 							 const gchar	*proxy_http,
 							 const gchar	*proxy_ftp,
 							 DBusGMethodInvocation *context);
+void		 pk_engine_can_authorize		(PkEngine	*engine,
+							 const gchar	*action_id,
+							 DBusGMethodInvocation *context);
 
 G_END_DECLS
 
