@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <glib.h>
@@ -26,13 +26,14 @@
 
 /* prototypes */
 void egg_string_test (EggTest *test);
+void pk_lsof_test (EggTest *test);
+void pk_proc_test (EggTest *test);
 void pk_conf_test (EggTest *test);
 void pk_store_test (EggTest *test);
 void pk_inhibit_test (EggTest *test);
 void pk_spawn_test (EggTest *test);
 void pk_transaction_list_test (EggTest *test);
 void pk_transaction_db_test (EggTest *test);
-void pk_security_test (EggTest *test);
 void pk_time_test (EggTest *test);
 void pk_backend_test (EggTest *test);
 void pk_backend_test_spawn (EggTest *test);
@@ -48,14 +49,15 @@ main (int argc, char **argv)
 		g_thread_init (NULL);
 	g_type_init ();
 	test = egg_test_init ();
-	egg_debug_init (TRUE);
+	egg_debug_init (&argc, &argv);
 
 	/* egg */
 	egg_string_test (test);
 
 	/* components */
+	pk_proc_test (test);
+	pk_lsof_test (test);
 	pk_file_monitor_test (test);
-	pk_security_test (test);
 	pk_time_test (test);
 	pk_conf_test (test);
 	pk_store_test (test);
