@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -41,7 +41,6 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -67,6 +66,7 @@ struct PkSpawnPrivate
 	guint			 poll_id;
 	guint			 kill_id;
 	gboolean		 finished;
+	gboolean		 background;
 	gboolean		 is_sending_exit;
 	gboolean		 is_changing_dispatcher;
 	gboolean		 allow_sigkill;
@@ -79,13 +79,20 @@ struct PkSpawnPrivate
 };
 
 enum {
-	PK_SPAWN_EXIT,
-	PK_SPAWN_STDOUT,
-	PK_SPAWN_STDERR,
-	PK_SPAWN_LAST_SIGNAL
+	SIGNAL_EXIT,
+	SIGNAL_STDOUT,
+	SIGNAL_STDERR,
+	SIGNAL_LAST
 };
 
-static guint	     signals [PK_SPAWN_LAST_SIGNAL] = { 0 };
+enum {
+	PROP_0,
+	PROP_BACKGROUND,
+	PROP_ALLOW_SIGKILL,
+	PROP_LAST
+};
+
+static guint signals [SIGNAL_LAST] = { 0 };
 
 G_DEFINE_TYPE (PkSpawn, pk_spawn, G_TYPE_OBJECT)
 
@@ -133,7 +140,7 @@ pk_spawn_emit_whole_lines (PkSpawn *spawn, GString *string)
 	bytes_processed = 0;
 	/* we only emit n-1 strings */
 	for (i=0; i<(size-1); i++) {
-		g_signal_emit (spawn, signals [PK_SPAWN_STDOUT], 0, lines[i]);
+		g_signal_emit (spawn, signals [SIGNAL_STDOUT], 0, lines[i]);
 		/* ITS4: ignore, g_strsplit always NULL terminates */
 		bytes_processed += strlen (lines[i]) + 1;
 	}
@@ -187,7 +194,7 @@ pk_spawn_check_child (PkSpawn *spawn)
 	/* emit all lines on standard out in one callback, as it's all probably
 	* related to the error that just happened */
 	if (spawn->priv->stderr_buf->len != 0) {
-		g_signal_emit (spawn, signals [PK_SPAWN_STDERR], 0, spawn->priv->stderr_buf->str);
+		g_signal_emit (spawn, signals [SIGNAL_STDERR], 0, spawn->priv->stderr_buf->str);
 		g_string_set_size (spawn->priv->stderr_buf, 0);
 	}
 
@@ -243,7 +250,7 @@ pk_spawn_check_child (PkSpawn *spawn)
 
 	/* don't emit if we just closed an invalid dispatcher */
 	egg_debug ("emitting exit %s", pk_spawn_exit_type_enum_to_text (spawn->priv->exit));
-	g_signal_emit (spawn, signals [PK_SPAWN_EXIT], 0, spawn->priv->exit);
+	g_signal_emit (spawn, signals [SIGNAL_EXIT], 0, spawn->priv->exit);
 
 	return FALSE;
 }
@@ -330,24 +337,6 @@ pk_spawn_kill (PkSpawn *spawn)
 	return TRUE;
 }
 
-/**
- * pk_spawn_set_allow_sigkill:
- *
- * Set whether the spawned backends are allowed to be SIGKILLed if they do not
- * respond to SIGQUIT. This ensures that Cancel() works as expected, but
- * somtimes can corrupt databases if they are open.
- **/
-gboolean
-pk_spawn_set_allow_sigkill (PkSpawn *spawn, gboolean allow_sigkill)
-{
-	g_return_val_if_fail (PK_IS_SPAWN (spawn), FALSE);
-
-	egg_debug ("setting SIGKILL: %i", allow_sigkill);
-	spawn->priv->allow_sigkill = allow_sigkill;
-
-	return TRUE;
-}
-
 /**
  * pk_spawn_send_stdin:
  *
@@ -449,6 +438,7 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 	guint len;
 	gint nice_value;
 	gchar *command;
+	const gchar *key;
 
 	g_return_val_if_fail (PK_IS_SPAWN (spawn), FALSE);
 	g_return_val_if_fail (argv != NULL, FALSE);
@@ -473,7 +463,7 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 	 *  - argv[0] (executable name is the same)
 	 *  - all of envp are the same (proxy and locale settings) */
 	if (spawn->priv->stdin_fd != -1) {
-		if (!egg_strequal (spawn->priv->last_argv0, argv[0])) {
+		if (g_strcmp0 (spawn->priv->last_argv0, argv[0]) != 0) {
 			egg_debug ("argv did not match, not reusing");
 		} else if (!egg_strvequal (spawn->priv->last_envp, envp)) {
 			egg_debug ("envp did not match, not reusing");
@@ -519,7 +509,10 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 				 NULL);
 
 	/* get the nice value and ensure we are in the valid range */
-	nice_value = pk_conf_get_int (spawn->priv->conf, "BackendSpawnNiceValue");
+	key = "BackendSpawnNiceValue";
+	if (spawn->priv->background)
+		key = "BackendSpawnNiceValueBackground";
+	nice_value = pk_conf_get_int (spawn->priv->conf, key);
 	nice_value = CLAMP(nice_value, -20, 19);
 
 	/* don't completely bog the system down */
@@ -529,7 +522,10 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 	}
 
 	/* perhaps set idle IO priority */
-	idleio = pk_conf_get_bool (spawn->priv->conf, "BackendSpawnIdleIO");
+	key = "BackendSpawnIdleIO";
+	if (spawn->priv->background)
+		key = "BackendSpawnIdleIOBackground";
+	idleio = pk_conf_get_bool (spawn->priv->conf, key);
 	if (idleio) {
 		egg_debug ("setting ioprio class to idle");
 		pk_ioprio_set_idle (spawn->priv->child_pid);
@@ -563,6 +559,50 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 	return TRUE;
 }
 
+/**
+ * pk_spawn_get_property:
+ **/
+static void
+pk_spawn_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+{
+	PkSpawn *spawn = PK_SPAWN (object);
+	PkSpawnPrivate *priv = spawn->priv;
+
+	switch (prop_id) {
+	case PROP_BACKGROUND:
+		g_value_set_boolean (value, priv->background);
+		break;
+	case PROP_ALLOW_SIGKILL:
+		g_value_set_boolean (value, priv->allow_sigkill);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+/**
+ * pk_spawn_set_property:
+ **/
+static void
+pk_spawn_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+{
+	PkSpawn *spawn = PK_SPAWN (object);
+	PkSpawnPrivate *priv = spawn->priv;
+
+	switch (prop_id) {
+	case PROP_BACKGROUND:
+		priv->background = g_value_get_boolean (value);
+		break;
+	case PROP_ALLOW_SIGKILL:
+		priv->allow_sigkill = g_value_get_boolean (value);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
 /**
  * pk_spawn_class_init:
  * @klass: The PkSpawnClass
@@ -570,21 +610,43 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp)
 static void
 pk_spawn_class_init (PkSpawnClass *klass)
 {
+	GParamSpec *pspec;
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = pk_spawn_finalize;
+	object_class->get_property = pk_spawn_get_property;
+	object_class->set_property = pk_spawn_set_property;
 
-	signals [PK_SPAWN_EXIT] =
+	/**
+	 * PkSpawn:background:
+	 */
+	pspec = g_param_spec_boolean ("background", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_BACKGROUND, pspec);
+
+	/**
+	 * PkSpawn:allow-sigkill:
+	 * Set whether the spawned backends are allowed to be SIGKILLed if they do not
+	 * respond to SIGQUIT. This ensures that Cancel() works as expected, but
+	 * sometimes can corrupt databases if they are open.
+	 */
+	pspec = g_param_spec_boolean ("allow-sigkill", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_ALLOW_SIGKILL, pspec);
+
+	signals [SIGNAL_EXIT] =
 		g_signal_new ("exit",
 			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
 			      0, NULL, NULL, g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
-	signals [PK_SPAWN_STDOUT] =
+	signals [SIGNAL_STDOUT] =
 		g_signal_new ("stdout",
 			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
 			      0, NULL, NULL, g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
-	signals [PK_SPAWN_STDERR] =
+	signals [SIGNAL_STDERR] =
 		g_signal_new ("stderr",
 			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
 			      0, NULL, NULL, g_cclosure_marshal_VOID__STRING,
@@ -614,6 +676,7 @@ pk_spawn_init (PkSpawn *spawn)
 	spawn->priv->allow_sigkill = TRUE;
 	spawn->priv->last_argv0 = NULL;
 	spawn->priv->last_envp = NULL;
+	spawn->priv->background = FALSE;
 	spawn->priv->exit = PK_SPAWN_EXIT_TYPE_UNKNOWN;
 
 	spawn->priv->stdout_buf = g_string_new ("");
@@ -887,7 +950,9 @@ pk_spawn_test (EggTest *test)
 	mexit = PK_SPAWN_EXIT_TYPE_UNKNOWN;
 	path = egg_test_get_data_file ("pk-spawn-test.sh");
 	argv = g_strsplit (path, " ", 0);
-	pk_spawn_set_allow_sigkill (spawn, FALSE);
+	g_object_set (spawn,
+		      "allow-sigkill", FALSE,
+		      NULL);
 	ret = pk_spawn_argv (spawn, argv, NULL);
 	g_free (path);
 	g_strfreev (argv);
@@ -959,7 +1024,7 @@ pk_spawn_test (EggTest *test)
 	file = egg_test_get_data_file ("pk-spawn-dispatcher.py");
 	path = g_strdup_printf ("%s\tsearch-name\tnone\tpower manager", file);
 	argv = g_strsplit (path, "\t", 0);
-	envp = g_strsplit ("NETWORK=TRUE LANG=C", " ", 0);
+	envp = g_strsplit ("NETWORK=TRUE LANG=C BACKGROUND=TRUE", " ", 0);
 	ret = pk_spawn_argv (spawn, argv, envp);
 	g_free (file);
 	g_free (path);
