@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -252,7 +252,7 @@ pk_store_get_uint (const PkStore *store, const gchar *key)
 	value = g_hash_table_lookup (store->priv->hash_pointer, (gpointer) key);
 	if (value == NULL) {
 		egg_warning ("not set data for %s", key);
-		return FALSE;
+		return 0;
 	}
 	/* we do the +1/-1 as NULL also means missing in the hash table */
 	return GPOINTER_TO_INT (value)-1;
@@ -418,7 +418,7 @@ pk_store_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "get a blank string");
 	data_string = pk_store_get_string (store, "dave2");
-	if (egg_strequal (data_string, ""))
+	if (g_strcmp0 (data_string, "") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "data was %s", data_string);
@@ -457,7 +457,7 @@ pk_store_test (EggTest *test)
 	/************************************************************/
 	egg_test_title (test, "get a string");
 	data_string = pk_store_get_string (store, "dave");
-	if (egg_strequal (data_string, "ania"))
+	if (g_strcmp0 (data_string, "ania") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "data was %s", data_string);
