@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -37,27 +37,19 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/pk-common.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
 
-#include "pk-transaction-id.h"
+#include "pk-conf.h"
 #include "pk-transaction-list.h"
 #include "org.freedesktop.PackageKit.Transaction.h"
 
-static void     pk_transaction_list_class_init	(PkTransactionListClass *klass);
-static void     pk_transaction_list_init	(PkTransactionList      *tlist);
 static void     pk_transaction_list_finalize	(GObject        *object);
 
 #define PK_TRANSACTION_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_TRANSACTION_LIST, PkTransactionListPrivate))
 
-/* how long the transaction should be queriable after it is finished, in seconds */
-#define PK_TRANSACTION_LIST_KEEP_FINISHED_TIMEOUT	5
-
-/* how long the tid is valid before it's destroyed, in seconds */
-#define PK_TRANSACTION_LIST_CREATE_COMMIT_TIMEOUT	30
-
 /* the interval between each CST, in seconds */
 #define PK_TRANSACTION_WEDGE_CHECK			10
 
@@ -66,6 +58,7 @@ struct PkTransactionListPrivate
 	GPtrArray		*array;
 	guint			 unwedge1_id;
 	guint			 unwedge2_id;
+	PkConf			*conf;
 };
 
 typedef struct {
@@ -78,6 +71,9 @@ typedef struct {
 	guint			 remove_id;
 	guint			 idle_id;
 	guint			 commit_id;
+	gulong			 finished_id;
+	guint			 uid;
+	gboolean		 background;
 } PkTransactionItem;
 
 enum {
@@ -109,7 +105,7 @@ pk_transaction_list_get_from_tid (PkTransactionList *tlist, const gchar *tid)
 	for (i=0; i<array->len; i++) {
 		item = (PkTransactionItem *) g_ptr_array_index (array, i);
 		tmptid = pk_transaction_get_tid (item->transaction);
-		if (egg_strequal (tmptid, tid))
+		if (g_strcmp0 (tmptid, tid) == 0)
 			return item;
 	}
 	return NULL;
@@ -151,10 +147,12 @@ pk_transaction_list_role_present (PkTransactionList *tlist, PkRoleEnum role)
 /**
  * pk_transaction_list_item_free:
  **/
-void
+static void
 pk_transaction_list_item_free (PkTransactionItem *item)
 {
 	g_return_if_fail (item != NULL);
+	if (item->finished_id != 0)
+		g_signal_handler_disconnect (item->transaction, item->finished_id);
 	g_object_unref (item->transaction);
 	if (item->commit_id != 0)
 		g_source_remove (item->commit_id);
@@ -170,7 +168,7 @@ pk_transaction_list_item_free (PkTransactionItem *item)
 /**
  * pk_transaction_list_remove_internal:
  **/
-gboolean
+static gboolean
 pk_transaction_list_remove_internal (PkTransactionList *tlist, PkTransactionItem *item)
 {
 	gboolean ret;
@@ -233,6 +231,31 @@ pk_transaction_list_remove (PkTransactionList *tlist, const gchar *tid)
 	return ret;
 }
 
+/**
+ * pk_transaction_list_set_background:
+ **/
+gboolean
+pk_transaction_list_set_background (PkTransactionList *tlist, const gchar *tid, gboolean background)
+{
+	PkTransactionItem *item;
+
+	g_return_val_if_fail (PK_IS_TRANSACTION_LIST (tlist), FALSE);
+	g_return_val_if_fail (tid != NULL, FALSE);
+
+	item = pk_transaction_list_get_from_tid (tlist, tid);
+	if (item == NULL) {
+		egg_warning ("could not get item");
+		return FALSE;
+	}
+	if (item->finished) {
+		egg_debug ("already finished, so waiting to timeout");
+		return FALSE;
+	}
+	egg_debug ("%s is now background: %i", tid, background);
+	item->background = background;
+	return TRUE;
+}
+
 /**
  * pk_transaction_list_remove_item_cb:
  **/
@@ -276,14 +299,50 @@ pk_transaction_list_run_item (PkTransactionList *tlist, PkTransactionItem *item)
 	item->idle_id = g_idle_add ((GSourceFunc) pk_transaction_list_run_idle_cb, item);
 }
 
+/**
+ * pk_transaction_list_get_next_item:
+ **/
+static PkTransactionItem *
+pk_transaction_list_get_next_item (PkTransactionList *tlist)
+{
+	PkTransactionItem *item = NULL;
+	GPtrArray *array;
+	guint i;
+
+	array = tlist->priv->array;
+
+	/* first try the waiting non-background transactions */
+	for (i=0; i<array->len; i++) {
+		item = (PkTransactionItem *) g_ptr_array_index (array, i);
+		if (item->committed &&
+		    !item->running &&
+		    !item->finished &&
+		    !item->background)
+			goto out;
+	}
+
+	/* then try the other waiting transactions (background tasks) */
+	for (i=0; i<array->len; i++) {
+		item = (PkTransactionItem *) g_ptr_array_index (array, i);
+		if (item->committed &&
+		    !item->running &&
+		    !item->finished)
+			goto out;
+	}
+
+	/* nothing to run */
+	item = NULL;
+out:
+	return item;
+}
+
 /**
  * pk_transaction_list_transaction_finished_cb:
  **/
 static void
-pk_transaction_list_transaction_finished_cb (PkTransaction *transaction, const gchar *exit_text, guint time, PkTransactionList *tlist)
+pk_transaction_list_transaction_finished_cb (PkTransaction *transaction, const gchar *exit_text, guint time_ms, PkTransactionList *tlist)
 {
-	guint i;
-	guint length;
+	guint timeout;
 	PkTransactionItem *item;
 	const gchar *tid;
 
@@ -292,7 +351,7 @@ pk_transaction_list_transaction_finished_cb (PkTransaction *transaction, const g
 	tid = pk_transaction_get_tid (transaction);
 	item = pk_transaction_list_get_from_tid (tlist, tid);
 	if (item == NULL)
-		egg_error ("no transaction list item found!");
+		egg_error ("no transaction list item '%s' found!", tid);
 
 	/* transaction is already finished? */
 	if (item->finished) {
@@ -318,20 +377,14 @@ pk_transaction_list_transaction_finished_cb (PkTransaction *transaction, const g
 	g_signal_emit (tlist, signals [PK_TRANSACTION_LIST_CHANGED], 0);
 
 	/* give the client a few seconds to still query the runner */
-	item->remove_id = g_timeout_add_seconds (PK_TRANSACTION_LIST_KEEP_FINISHED_TIMEOUT,
-						 (GSourceFunc) pk_transaction_list_remove_item_cb, item);
+	timeout = pk_conf_get_int (tlist->priv->conf, "TransactionKeepFinishedTimeout");
+	item->remove_id = g_timeout_add_seconds (timeout, (GSourceFunc) pk_transaction_list_remove_item_cb, item);
 
 	/* do the next transaction now if we have another queued */
-	length = tlist->priv->array->len;
-	for (i=0; i<length; i++) {
-		item = (PkTransactionItem *) g_ptr_array_index (tlist->priv->array, i);
-		if (item->committed &&
-		    !item->running &&
-		    !item->finished) {
-			egg_debug ("running %s as previous one finished", item->tid);
-			pk_transaction_list_run_item (tlist, item);
-			break;
-		}
+	item = pk_transaction_list_get_next_item (tlist);
+	if (item != NULL) {
+		egg_debug ("running %s as previous one finished", item->tid);
+		pk_transaction_list_run_item (tlist, item);
 	}
 }
 
@@ -341,21 +394,46 @@ pk_transaction_list_transaction_finished_cb (PkTransaction *transaction, const g
 static gboolean
 pk_transaction_list_no_commit_cb (PkTransactionItem *item)
 {
-	egg_warning ("ID %s was not committed in %i seconds!",
-		     item->tid, PK_TRANSACTION_LIST_CREATE_COMMIT_TIMEOUT);
+	egg_warning ("ID %s was not committed in time!", item->tid);
 	pk_transaction_list_remove_internal (item->list, item);
 
 	/* never repeat */
 	return FALSE;
 }
 
+/**
+ * pk_transaction_list_get_number_transactions_for_uid:
+ *
+ * Find all the transactions that are pending from this uid.
+ **/
+static guint
+pk_transaction_list_get_number_transactions_for_uid (PkTransactionList *tlist, guint uid)
+{
+	guint i;
+	GPtrArray *array;
+	PkTransactionItem *item;
+	guint count = 0;
+
+	/* find all the transactions in progress */
+	array = tlist->priv->array;
+	for (i=0; i<array->len; i++) {
+		item = (PkTransactionItem *) g_ptr_array_index (array, i);
+		if (item->uid == uid)
+			count++;
+	}
+	return count;
+}
+
 /**
  * pk_transaction_list_create:
  **/
 gboolean
-pk_transaction_list_create (PkTransactionList *tlist, const gchar *tid)
+pk_transaction_list_create (PkTransactionList *tlist, const gchar *tid, const gchar *sender, GError **error)
 {
-	gboolean ret;
+	guint count;
+	guint max_count;
+	guint timeout;
+	gboolean ret = FALSE;
 	PkTransactionItem *item;
 	DBusGConnection *connection;
 
@@ -365,8 +443,10 @@ pk_transaction_list_create (PkTransactionList *tlist, const gchar *tid)
 	/* already added? */
 	item = pk_transaction_list_get_from_tid (tlist, tid);
 	if (item != NULL) {
+		if (error != NULL)
+			*error = g_error_new (1, 0, "already added %s to list", tid);
 		egg_warning ("already added %s to list", tid);
-		return FALSE;
+		goto out;
 	}
 
 	/* add to the array */
@@ -375,9 +455,11 @@ pk_transaction_list_create (PkTransactionList *tlist, const gchar *tid)
 	item->running = FALSE;
 	item->finished = FALSE;
 	item->transaction = NULL;
+	item->background = FALSE;
 	item->commit_id = 0;
 	item->remove_id = 0;
 	item->idle_id = 0;
+	item->finished_id = 0;
 	item->list = g_object_ref (tlist);
 	item->tid = g_strdup (tid);
 
@@ -387,25 +469,61 @@ pk_transaction_list_create (PkTransactionList *tlist, const gchar *tid)
 		egg_error ("no connection");
 
 	item->transaction = pk_transaction_new ();
-	g_signal_connect_after (item->transaction, "finished",
-				G_CALLBACK (pk_transaction_list_transaction_finished_cb), tlist);
+	item->finished_id =
+		g_signal_connect_after (item->transaction, "finished",
+					G_CALLBACK (pk_transaction_list_transaction_finished_cb), tlist);
 
 	/* set the TID on the transaction */
 	ret = pk_transaction_set_tid (item->transaction, item->tid);
-	if (!ret)
-		egg_error ("failed to set TID");
+	if (!ret) {
+		if (error != NULL)
+			*error = g_error_new (1, 0, "failed to set TID: %s", tid);
+		goto out;
+	}
+
+	/* set the DBUS sender on the transaction */
+	ret = pk_transaction_set_sender (item->transaction, sender);
+	if (!ret) {
+		if (error != NULL)
+			*error = g_error_new (1, 0, "failed to set sender: %s", tid);
+		goto out;
+	}
+
+	/* get the uid for the transaction */
+	g_object_get (item->transaction,
+		      "uid", &item->uid,
+		      NULL);
+
+	/* find out the number of transactions this uid already has in progress */
+	count = pk_transaction_list_get_number_transactions_for_uid (tlist, item->uid);
+	egg_debug ("uid=%i, count=%i", item->uid, count);
+
+	/* would this take us over the maximum number of requests allowed */
+	max_count = pk_conf_get_int (tlist->priv->conf, "SimultaneousTransactionsForUid");
+	if (count > max_count) {
+		if (error != NULL)
+			*error = g_error_new (1, 0, "failed to allocate %s as uid %i already has %i transactions in progress", tid, item->uid, count);
+
+		/* free transaction, as it's never going to be added */
+		pk_transaction_list_item_free (item);
+
+		/* failure */
+		ret = FALSE;
+		goto out;
+	}
 
 	/* put on the bus */
 	dbus_g_object_type_install_info (PK_TYPE_TRANSACTION, &dbus_glib_pk_transaction_object_info);
 	dbus_g_connection_register_g_object (connection, item->tid, G_OBJECT (item->transaction));
 
 	/* the client only has a finite amount of time to use the object, else it's destroyed */
-	item->commit_id = g_timeout_add_seconds (PK_TRANSACTION_LIST_CREATE_COMMIT_TIMEOUT,
-					      (GSourceFunc) pk_transaction_list_no_commit_cb, item);
+	timeout = pk_conf_get_int (tlist->priv->conf, "TransactionCreateCommitTimeout");
+	item->commit_id = g_timeout_add_seconds (timeout, (GSourceFunc) pk_transaction_list_no_commit_cb, item);
 
 	egg_debug ("adding transaction %p, item %p", item->transaction, item);
 	g_ptr_array_add (tlist->priv->array, item);
-	return TRUE;
+out:
+	return ret;
 }
 
 /**
@@ -491,7 +609,7 @@ pk_transaction_list_get_array (PkTransactionList *tlist)
 	g_return_val_if_fail (PK_IS_TRANSACTION_LIST (tlist), NULL);
 
 	/* use a temp array, as not all are in progress */
-	parray = g_ptr_array_new ();
+	parray = g_ptr_array_new_with_free_func (g_free);
 
 	/* find all the transactions in progress */
 	length = tlist->priv->array->len;
@@ -501,10 +619,9 @@ pk_transaction_list_get_array (PkTransactionList *tlist)
 		if (item->committed && !item->finished)
 			g_ptr_array_add (parray, g_strdup (item->tid));
 	}
-	egg_debug ("%i transactions in list, %i active", length, parray->len);
+	egg_debug ("%i transactions in list, %i committed but not finished", length, parray->len);
 	array = pk_ptr_array_to_strv (parray);
-	g_ptr_array_foreach (parray, (GFunc) g_free, NULL);
-	g_ptr_array_free (parray, TRUE);
+	g_ptr_array_unref (parray);
 
 	return array;
 }
@@ -519,27 +636,71 @@ pk_transaction_list_get_size (PkTransactionList *tlist)
 	return tlist->priv->array->len;
 }
 
+/**
+ * pk_transaction_list_get_state:
+ **/
+gchar *
+pk_transaction_list_get_state (PkTransactionList *tlist)
+{
+	guint i;
+	guint length;
+	guint running = 0;
+	guint waiting = 0;
+	guint wrong = 0;
+	guint no_commit = 0;
+	PkRoleEnum role;
+	PkTransactionItem *item;
+	GString *string;
+
+	length = tlist->priv->array->len;
+	string = g_string_new ("State:\n");
+	if (length == 0)
+		goto out;
+
+	/* iterate tasks */
+	for (i=0; i<length; i++) {
+		item = (PkTransactionItem *) g_ptr_array_index (tlist->priv->array, i);
+		if (item->running)
+			running++;
+		if (item->committed && !item->finished && !item->running)
+			waiting++;
+		if (!item->committed && !item->finished && !item->running)
+			no_commit++;
+		if (!item->committed && item->finished)
+			wrong++;
+		if (item->running && item->finished)
+			wrong++;
+		role = pk_transaction_priv_get_role (item->transaction);
+		g_string_append_printf (string, "%0i\t%s\t%s\trunning[%i] committed[%i] finished[%i] background[%i]\n", i,
+					pk_role_enum_to_text (role), item->tid, item->running,
+					item->committed, item->finished, item->background);
+	}
+
+	/* wrong flags */
+	if (wrong != 0)
+		g_string_append_printf (string, "ERROR: %i have inconsistent flags\n", wrong);
+
+	/* more than one running */
+	if (running > 1)
+		g_string_append_printf (string, "ERROR: %i are running\n", running);
+
+	/* nothing running */
+	if (waiting == length)
+		g_string_append_printf (string, "WARNING: everything is waiting!\n");
+out:
+	return g_string_free (string, FALSE);
+}
+
 /**
  * pk_transaction_list_print:
  **/
 static void
 pk_transaction_list_print (PkTransactionList *tlist)
 {
-	guint i;
-	guint length;
-	PkRoleEnum role;
-	PkTransactionItem *item;
-
-	length = tlist->priv->array->len;
-	if (length == 0)
-		return;
-	for (i=0; i<length; i++) {
-		item = (PkTransactionItem *) g_ptr_array_index (tlist->priv->array, i);
-		role = pk_transaction_priv_get_role (item->transaction);
-		g_print ("%0i\t%s\t%s\trunning[%i] committed[%i] finished[%i]\n", i,
-			 pk_role_enum_to_text (role), item->tid, item->running,
-			 item->committed, item->finished);
-	}
+	gchar *state;
+	state = pk_transaction_list_get_state (tlist);
+	egg_debug ("%s", state);
+	g_free (state);
 }
 
 /**
@@ -558,7 +719,9 @@ pk_transaction_list_is_consistent (PkTransactionList *tlist)
 	guint wrong = 0;
 	guint no_commit = 0;
 	guint length;
+	guint unknown_role = 0;
 	PkTransactionItem *item;
+	PkRoleEnum role;
 
 	g_return_val_if_fail (PK_IS_TRANSACTION_LIST (tlist), 0);
 
@@ -581,6 +744,9 @@ pk_transaction_list_is_consistent (PkTransactionList *tlist)
 			wrong++;
 		if (item->running && item->finished)
 			wrong++;
+		role = pk_transaction_priv_get_role (item->transaction);
+		if (role == PK_ROLE_ENUM_UNKNOWN)
+			unknown_role++;
 	}
 
 	/* debug */
@@ -592,9 +758,13 @@ pk_transaction_list_is_consistent (PkTransactionList *tlist)
 		ret = FALSE;
 	}
 
+	/* role not set */
+	if (unknown_role != 0)
+		egg_debug ("%i have an unknown role (GetTid then nothing?)", unknown_role);
+
 	/* some are not committed */
 	if (no_commit != 0)
-		egg_debug ("%i have not been committed", no_commit);
+		egg_debug ("%i have not been committed and may be pending auth", no_commit);
 
 	/* more than one running */
 	if (running > 1) {
@@ -685,6 +855,7 @@ static void
 pk_transaction_list_init (PkTransactionList *tlist)
 {
 	tlist->priv = PK_TRANSACTION_LIST_GET_PRIVATE (tlist);
+	tlist->priv->conf = pk_conf_new ();
 	tlist->priv->array = g_ptr_array_new ();
 	tlist->priv->unwedge2_id = 0;
 	tlist->priv->unwedge1_id = g_timeout_add_seconds (PK_TRANSACTION_WEDGE_CHECK, (GSourceFunc) pk_transaction_list_wedge_check1, tlist);
@@ -712,6 +883,7 @@ pk_transaction_list_finalize (GObject *object)
 
 	g_ptr_array_foreach (tlist->priv->array, (GFunc) pk_transaction_list_item_free, NULL);
 	g_ptr_array_free (tlist->priv->array, TRUE);
+	g_object_unref (tlist->priv->conf);
 
 	G_OBJECT_CLASS (pk_transaction_list_parent_class)->finalize (object);
 }
@@ -740,6 +912,9 @@ pk_transaction_list_new (void)
 #include "egg-test.h"
 #include "pk-backend-internal.h"
 #include "pk-cache.h"
+#include "pk-transaction-db.h"
+
+static PkTransactionDb *db = NULL;
 
 /**
  * pk_transaction_list_test_finished_cb:
@@ -770,10 +945,10 @@ pk_transaction_list_test_get_item (PkTransactionList *tlist)
 	gchar *tid;
 
 	/* get tid */
-	tid = pk_transaction_id_generate ();
+	tid = pk_transaction_db_generate_id (db);
 
 	/* create PkTransaction instance */
-	pk_transaction_list_create (tlist, tid);
+	pk_transaction_list_create (tlist, tid, ":0", NULL);
 	item = pk_transaction_list_get_from_tid (tlist, tid);
 	g_free (tid);
 
@@ -798,8 +973,20 @@ pk_transaction_list_test (EggTest *test)
 	if (!egg_test_start (test, "PkTransactionList"))
 		return;
 
+	/* remove the self check file */
+#if PK_BUILD_LOCAL
+	ret = g_file_test ("./transactions.db", G_FILE_TEST_EXISTS);
+	if (ret) {
+		egg_test_title (test, "remove old local database");
+		egg_warning ("Removing %s", "./transactions.db");
+		size = g_unlink ("./transactions.db");
+		egg_test_assert (test, (size == 0));
+	}
+#endif
+
 	/* we get a cache object to reproduce the engine having it ref'd */
 	cache = pk_cache_new ();
+	db = pk_transaction_db_new ();
 
 	/************************************************************/
 	egg_test_title (test, "get a transaction list object");
@@ -808,7 +995,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/************************************************************/
 	egg_test_title (test, "make sure we get a valid tid");
-	tid = pk_transaction_id_generate ();
+	tid = pk_transaction_db_generate_id (db);
 	if (tid != NULL)
 		egg_test_success (test, "got tid %s", tid);
 	else
@@ -816,7 +1003,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/************************************************************/
 	egg_test_title (test, "create a transaction object");
-	ret = pk_transaction_list_create (tlist, tid);
+	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
 	if (ret)
 		egg_test_success (test, "created transaction %s", tid);
 	else
@@ -826,7 +1013,7 @@ pk_transaction_list_test (EggTest *test)
 	egg_test_title (test, "make sure we get the right object back");
 	item = pk_transaction_list_get_from_tid (tlist, tid);
 	if (item != NULL &&
-	    egg_strequal (item->tid, tid) &&
+	    (g_strcmp0 (item->tid, tid) == 0) &&
 	    item->transaction != NULL)
 		egg_test_success (test, NULL);
 	else
@@ -860,7 +1047,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/************************************************************/
 	egg_test_title (test, "add again the same tid (should fail)");
-	ret = pk_transaction_list_create (tlist, tid);
+	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
 	if (!ret)
 		egg_test_success (test, NULL);
 	else
@@ -884,11 +1071,11 @@ pk_transaction_list_test (EggTest *test)
 
 	/* get a new tid */
 	g_free (tid);
-	tid = pk_transaction_id_generate ();
+	tid = pk_transaction_db_generate_id (db);
 
 	/************************************************************/
 	egg_test_title (test, "create another item");
-	ret = pk_transaction_list_create (tlist, tid);
+	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
 	if (ret)
 		egg_test_success (test, "created transaction %s", tid);
 	else
@@ -913,7 +1100,7 @@ pk_transaction_list_test (EggTest *test)
 	egg_test_title (test, "get from db");
 	item = pk_transaction_list_get_from_tid (tlist, tid);
 	if (item != NULL &&
-	    egg_strequal (item->tid, tid) &&
+	    (g_strcmp0 (item->tid, tid) == 0) &&
 	    item->transaction != NULL)
 		egg_test_success (test, NULL);
 	else
@@ -1289,6 +1476,7 @@ pk_transaction_list_test (EggTest *test)
 	g_object_unref (tlist);
 	g_object_unref (backend);
 	g_object_unref (cache);
+	g_object_unref (db);
 
 	egg_test_end (test);
 }
