@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __PK_TRANSACTION_LIST_H
 #define __PK_TRANSACTION_LIST_H
 
 #include <glib-object.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/pk-enum.h>
 
 #include "pk-transaction.h"
 
@@ -56,9 +56,13 @@ PkTransactionList *pk_transaction_list_new		(void);
 
 gboolean	 pk_transaction_list_create		(PkTransactionList	*tlist,
 							 const gchar		*tid,
-							 const gchar		*sender);
+							 const gchar		*sender,
+							 GError			**error);
 gboolean	 pk_transaction_list_remove		(PkTransactionList	*tlist,
 							 const gchar		*tid);
+gboolean	 pk_transaction_list_set_background		(PkTransactionList	*tlist,
+							 const gchar		*tid,
+							 gboolean		 background);
 gboolean	 pk_transaction_list_commit		(PkTransactionList	*tlist,
 							 const gchar		*tid)
 							 G_GNUC_WARN_UNUSED_RESULT;
